"""Response schemas for the Meraki API.

This module is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from meraki_client.schemas._administered import (
    AdministeredAuthenticationApi,
    AdministeredAuthenticationTwoFactor,
    AdministeredKey,
    GenerateAdministeredIdentitiesMeApiKeysResponse,
    GetAdministeredIdentitiesMeApiKeysResponse,
    GetAdministeredIdentitiesMeApiKeysResponseItem,
    GetAdministeredIdentitiesMeResponse,
    GetAdministeredIdentitiesMeResponseAuthentication,
)
from meraki_client.schemas._appliance import (
    Appliance1,
    ApplianceApplicationCategoriesItem,
    ApplianceApplicationsItem,
    ApplianceAssignedFiveGhzSettings,
    ApplianceAssignedPerSsidSettings,
    ApplianceAssignedTwoFourGhzSettings,
    ApplianceAuthentication,
    ApplianceAuthentication2,
    ApplianceBandwidthLimits,
    ApplianceByInterfaceItem,
    ApplianceByUplinkItem,
    ApplianceCountsByStatus,
    ApplianceDestination,
    ApplianceDestination2,
    ApplianceDestination3,
    ApplianceDhcpOptionsItem,
    ApplianceExportedSubnetsItem,
    ApplianceFailover,
    ApplianceFailoverAndFailbackImmediate,
    ApplianceHighAvailability,
    ApplianceInterfacesWan1,
    ApplianceIpsec,
    ApplianceIpv4,
    ApplianceIpv6PrefixAssignmentsItem,
    ApplianceItems,
    ApplianceJitterSummariesItem,
    ApplianceLatencySummariesItem,
    ApplianceLossPercentageSummariesItem,
    ApplianceMerakiVpnPeersItem,
    ApplianceMerakiVpnPeersItem2,
    ApplianceMetaCounts,
    ApplianceMosSummariesItem,
    ApplianceNameservers,
    ApplianceNeighborsAuthentication,
    ApplianceNeighborsIpv6,
    ApplianceNetwork,
    ApplianceOrigin,
    ApplianceOrigin2,
    ApplianceOrigin3,
    AppliancePeersEbgpNeighbor,
    AppliancePeersGroup,
    AppliancePeersIpsecPolicies,
    AppliancePeersNetwork,
    AppliancePerformanceClass,
    AppliancePerformanceClass2,
    AppliancePppoe,
    AppliancePppoe2,
    ApplianceRadiusServersItem,
    ApplianceReservedIpRangesItem,
    ApplianceSource,
    ApplianceSource2,
    ApplianceSubnetNat,
    ApplianceSubnetsNat,
    ApplianceSvis,
    ApplianceThirdPartyVpnPeersItem,
    ApplianceTrafficFiltersItem,
    ApplianceTrafficFiltersItem2,
    ApplianceTrafficFiltersItem3,
    ApplianceTrafficFiltersItem4,
    ApplianceUplinksItem,
    ApplianceUplinksItem2,
    ApplianceUsageSummary,
    ApplianceValue,
    ApplianceValue2,
    ApplianceValue3,
    ApplianceVlanTagging,
    ApplianceVpnTrafficUplinkPreferencesItem,
    ApplianceWanTrafficUplinkPreferencesItem,
    ApplianceWanTrafficUplinkPreferencesItem2,
    BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateItemsItem,
    BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateResponse,
    BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateResponseItemsItem,
    CreateDeviceApplianceVmxAuthenticationTokenResponse,
    CreateNetworkAppliancePrefixesDelegatedStaticOrigin,
    CreateNetworkApplianceRfProfileFiveGhzSettings,
    CreateNetworkApplianceRfProfilePerSsidSettings,
    CreateNetworkApplianceRfProfilePerSsidSettings1,
    CreateNetworkApplianceRfProfileResponse,
    CreateNetworkApplianceRfProfileTwoFourGhzSettings,
    CreateNetworkApplianceStaticRouteResponse,
    CreateNetworkApplianceTrafficShapingCustomPerformanceClassResponse,
    CreateNetworkApplianceVlanDhcpOptionsItem,
    CreateNetworkApplianceVlanIpv6,
    CreateNetworkApplianceVlanMandatoryDhcp,
    CreateNetworkApplianceVlanResponse,
    CreateOrganizationApplianceDnsLocalProfileResponse,
    CreateOrganizationApplianceDnsLocalProfilesAssignmentsBulkDeleteItemsItem,
    CreateOrganizationApplianceDnsLocalProfilesAssignmentsBulkDeleteResponse,
    CreateOrganizationApplianceDnsLocalRecordProfile,
    CreateOrganizationApplianceDnsLocalRecordResponse,
    CreateOrganizationApplianceDnsLocalRecordResponseItem,
    CreateOrganizationApplianceDnsSplitProfileNameservers,
    CreateOrganizationApplianceDnsSplitProfileResponse,
    CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkCreateItemsItem,
    CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkCreateResponse,
    CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkDeleteItemsItem,
    CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkDeleteResponse,
    GetDeviceApplianceDhcpSubnetsResponse,
    GetDeviceApplianceDhcpSubnetsResponseItem,
    GetDeviceAppliancePerformanceResponse,
    GetDeviceAppliancePrefixesDelegatedResponse,
    GetDeviceAppliancePrefixesDelegatedVlanAssignmentsResponse,
    GetDeviceApplianceRadioSettingsResponse,
    GetDeviceApplianceRadioSettingsResponseFiveGhzSettings,
    GetDeviceApplianceRadioSettingsResponseTwoFourGhzSettings,
    GetDeviceApplianceUplinksSettingsResponse,
    GetDeviceApplianceUplinksSettingsResponseInterfaces,
    GetNetworkApplianceClientSecurityEventsResponse,
    GetNetworkApplianceConnectivityMonitoringDestinationsResponse,
    GetNetworkApplianceConnectivityMonitoringDestinationsResponseDestinationsItem,
    GetNetworkApplianceContentFilteringResponse,
    GetNetworkApplianceContentFilteringResponseBlockedUrlCategoriesItem,
    GetNetworkApplianceFirewallFirewalledServiceResponse,
    GetNetworkApplianceFirewallFirewalledServicesResponse,
    GetNetworkApplianceFirewallFirewalledServicesResponseItem,
    GetNetworkApplianceFirewallInboundCellularFirewallRulesResponse,
    GetNetworkApplianceFirewallInboundCellularFirewallRulesResponseRulesItem,
    GetNetworkApplianceFirewallInboundFirewallRulesResponse,
    GetNetworkApplianceFirewallL7FirewallRulesApplicationCategoriesResponse,
    GetNetworkApplianceFirewallPortForwardingRulesResponse,
    GetNetworkApplianceFirewallPortForwardingRulesResponseRulesItem,
    GetNetworkAppliancePortResponse,
    GetNetworkAppliancePortsResponse,
    GetNetworkAppliancePortsResponseItem,
    GetNetworkAppliancePrefixesDelegatedStaticResponse,
    GetNetworkAppliancePrefixesDelegatedStaticsResponse,
    GetNetworkAppliancePrefixesDelegatedStaticsResponseItem,
    GetNetworkApplianceRfProfileResponse,
    GetNetworkApplianceRfProfilesResponse,
    GetNetworkApplianceRfProfilesResponseAssignedItem,
    GetNetworkApplianceSecurityEventsResponse,
    GetNetworkApplianceSecurityIntrusionResponse,
    GetNetworkApplianceSecurityIntrusionResponseProtectedNetworks,
    GetNetworkApplianceSecurityMalwareResponse,
    GetNetworkApplianceSecurityMalwareResponseAllowedFilesItem,
    GetNetworkApplianceSecurityMalwareResponseAllowedUrlsItem,
    GetNetworkApplianceSettingsResponse,
    GetNetworkApplianceSettingsResponseDynamicDns,
    GetNetworkApplianceSingleLanResponse,
    GetNetworkApplianceSingleLanResponseIpv6,
    GetNetworkApplianceSingleLanResponseMandatoryDhcp,
    GetNetworkApplianceSsidResponse,
    GetNetworkApplianceSsidsResponse,
    GetNetworkApplianceSsidsResponseItem,
    GetNetworkApplianceStaticRouteResponse,
    GetNetworkApplianceStaticRoutesResponse,
    GetNetworkApplianceStaticRoutesResponseItem,
    GetNetworkApplianceTrafficShapingCustomPerformanceClassesResponse,
    GetNetworkApplianceTrafficShapingCustomPerformanceClassesResponseItem,
    GetNetworkApplianceTrafficShapingCustomPerformanceClassResponse,
    GetNetworkApplianceTrafficShapingUplinkBandwidthResponse,
    GetNetworkApplianceTrafficShapingUplinkBandwidthResponseBandwidthLimits,
    GetNetworkApplianceTrafficShapingUplinkSelectionResponse,
    GetNetworkApplianceTrafficShapingUplinkSelectionResponseFailoverAndFailback,
    GetNetworkApplianceUplinksUsageHistoryResponse,
    GetNetworkApplianceUplinksUsageHistoryResponseItem,
    GetNetworkApplianceVlanResponse,
    GetNetworkApplianceVlansResponse,
    GetNetworkApplianceVlansResponseItem,
    GetNetworkApplianceVlansSettingsResponse,
    GetNetworkApplianceVpnBgpResponse,
    GetNetworkApplianceVpnBgpResponseNeighborsItem,
    GetNetworkApplianceVpnSiteToSiteVpnResponse,
    GetNetworkApplianceVpnSiteToSiteVpnResponseHubsItem,
    GetNetworkApplianceVpnSiteToSiteVpnResponseSubnet,
    GetNetworkApplianceVpnSiteToSiteVpnResponseSubnetsItem,
    GetNetworkApplianceWarmSpareResponse,
    GetNetworkApplianceWarmSpareResponseWan1,
    GetOrganizationApplianceDnsLocalProfilesAssignmentsResponseItemsItem,
    GetOrganizationApplianceDnsLocalProfilesResponse,
    GetOrganizationApplianceDnsLocalProfilesResponseItem,
    GetOrganizationApplianceDnsLocalRecordsResponse,
    GetOrganizationApplianceDnsLocalRecordsResponseItem,
    GetOrganizationApplianceDnsSplitProfilesAssignmentsResponseItemsItem,
    GetOrganizationApplianceDnsSplitProfilesResponse,
    GetOrganizationApplianceDnsSplitProfilesResponseItem,
    GetOrganizationApplianceFirewallMulticastForwardingByNetworkResponseItemsItem,
    GetOrganizationApplianceSecurityEventsResponse,
    GetOrganizationApplianceTrafficShapingVpnExclusionsByNetworkResponseItemsItem,
    GetOrganizationApplianceUplinksStatusesOverviewResponse,
    GetOrganizationApplianceUplinksStatusesOverviewResponseCounts,
    GetOrganizationApplianceUplinkStatusesResponse,
    GetOrganizationApplianceUplinkStatusesResponseItem,
    GetOrganizationApplianceUplinksUsageByNetworkResponse,
    GetOrganizationApplianceUplinksUsageByNetworkResponseItem,
    GetOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseItemsItem,
    GetOrganizationApplianceVpnStatsResponse,
    GetOrganizationApplianceVpnStatsResponseItem,
    GetOrganizationApplianceVpnStatusesResponse,
    GetOrganizationApplianceVpnStatusesResponseItem,
    GetOrganizationApplianceVpnThirdPartyVPNPeersResponse,
    GetOrganizationApplianceVpnThirdPartyVPNPeersResponsePeersItem,
    GetOrganizationApplianceVpnVpnFirewallRulesResponse,
    SwapNetworkApplianceWarmSpareResponse,
    UpdateDeviceApplianceRadioSettingsFiveGhzSettings,
    UpdateDeviceApplianceRadioSettingsResponse,
    UpdateDeviceApplianceRadioSettingsTwoFourGhzSettings,
    UpdateDeviceApplianceUplinksSettingsInterfaces,
    UpdateDeviceApplianceUplinksSettingsInterfacesWan1,
    UpdateDeviceApplianceUplinksSettingsResponse,
    UpdateNetworkApplianceConnectivityMonitoringDestinationsDestinationsItem,
    UpdateNetworkApplianceConnectivityMonitoringDestinationsResponse,
    UpdateNetworkApplianceContentFilteringResponse,
    UpdateNetworkApplianceFirewallCellularFirewallRulesRulesItem,
    UpdateNetworkApplianceFirewallFirewalledServiceResponse,
    UpdateNetworkApplianceFirewallInboundCellularFirewallRulesResponse,
    UpdateNetworkApplianceFirewallInboundCellularFirewallRulesRulesItem,
    UpdateNetworkApplianceFirewallInboundFirewallRulesResponse,
    UpdateNetworkApplianceFirewallInboundFirewallRulesRulesItem,
    UpdateNetworkApplianceFirewallL3FirewallRulesRulesItem,
    UpdateNetworkApplianceFirewallL7FirewallRulesRulesItem,
    UpdateNetworkApplianceFirewallMulticastForwardingResponse,
    UpdateNetworkApplianceFirewallMulticastForwardingResponseNetwork,
    UpdateNetworkApplianceFirewallMulticastForwardingResponseRulesItem,
    UpdateNetworkApplianceFirewallMulticastForwardingRulesItem,
    UpdateNetworkApplianceFirewallOneToManyNatRulesRulesItem,
    UpdateNetworkApplianceFirewallOneToManyNatRulesRulesItemPortRulesItem,
    UpdateNetworkApplianceFirewallOneToOneNatRulesRulesItem,
    UpdateNetworkApplianceFirewallOneToOneNatRulesRulesItemAllowedInboundItem,
    UpdateNetworkApplianceFirewallPortForwardingRulesResponse,
    UpdateNetworkApplianceFirewallPortForwardingRulesRulesItem,
    UpdateNetworkApplianceFirewallSettingsSpoofingProtection,
    UpdateNetworkApplianceFirewallSettingsSpoofingProtectionIpSourceGuard,
    UpdateNetworkAppliancePortResponse,
    UpdateNetworkAppliancePrefixesDelegatedStaticOrigin,
    UpdateNetworkApplianceRfProfileFiveGhzSettings,
    UpdateNetworkApplianceRfProfilePerSsidSettings,
    UpdateNetworkApplianceRfProfileResponse,
    UpdateNetworkApplianceRfProfileTwoFourGhzSettings,
    UpdateNetworkApplianceSdwanInternetPoliciesResponse,
    UpdateNetworkApplianceSdwanInternetPoliciesWanTrafficUplinkPreferencesItem,
    UpdateNetworkApplianceSecurityIntrusionProtectedNetworks,
    UpdateNetworkApplianceSecurityIntrusionResponse,
    UpdateNetworkApplianceSecurityMalwareAllowedFilesItem,
    UpdateNetworkApplianceSecurityMalwareAllowedUrlsItem,
    UpdateNetworkApplianceSecurityMalwareResponse,
    UpdateNetworkApplianceSettingsDynamicDns,
    UpdateNetworkApplianceSettingsResponse,
    UpdateNetworkApplianceSingleLanIpv6,
    UpdateNetworkApplianceSingleLanIpv6PrefixAssignmentsItem,
    UpdateNetworkApplianceSingleLanMandatoryDhcp,
    UpdateNetworkApplianceSingleLanResponse,
    UpdateNetworkApplianceSsidDhcpEnforcedDeauthentication,
    UpdateNetworkApplianceSsidDot11w,
    UpdateNetworkApplianceSsidRadiusServersItem,
    UpdateNetworkApplianceSsidResponse,
    UpdateNetworkApplianceStaticRouteFixedIpAssignmentsValue,
    UpdateNetworkApplianceStaticRouteReservedIpRangesItem,
    UpdateNetworkApplianceStaticRouteResponse,
    UpdateNetworkApplianceTrafficShapingCustomPerformanceClassResponse,
    UpdateNetworkApplianceTrafficShapingGlobalBandwidthLimits,
    UpdateNetworkApplianceTrafficShapingRulesRulesItem,
    UpdateNetworkApplianceTrafficShapingRulesRulesItemDefinitionsItem,
    UpdateNetworkApplianceTrafficShapingRulesRulesItemPerClientBandwidthLimits,
    UpdateNetworkApplianceTrafficShapingUplinkBandwidthBandwidthLimits,
    UpdateNetworkApplianceTrafficShapingUplinkSelectionFailoverAndFailback,
    UpdateNetworkApplianceTrafficShapingUplinkSelectionResponse,
    UpdateNetworkApplianceTrafficShapingUplinkSelectionVpnTrafficUplinkPreferencesItem,
    UpdateNetworkApplianceTrafficShapingUplinkSelectionWanTrafficUplinkPreferencesItem,
    UpdateNetworkApplianceTrafficShapingVpnExclusionsCustomItem,
    UpdateNetworkApplianceTrafficShapingVpnExclusionsMajorApplicationsItem,
    UpdateNetworkApplianceTrafficShapingVpnExclusionsResponse,
    UpdateNetworkApplianceTrafficShapingVpnExclusionsResponseCustomItem,
    UpdateNetworkApplianceTrafficShapingVpnExclusionsResponseMajorApplicationsItem,
    UpdateNetworkApplianceVlanDhcpOptionsItem,
    UpdateNetworkApplianceVlanIpv6,
    UpdateNetworkApplianceVlanIpv6PrefixAssignmentsItem,
    UpdateNetworkApplianceVlanMandatoryDhcp,
    UpdateNetworkApplianceVlanReservedIpRangesItem,
    UpdateNetworkApplianceVlanResponse,
    UpdateNetworkApplianceVlansSettingsResponse,
    UpdateNetworkApplianceVpnBgpNeighborsItem,
    UpdateNetworkApplianceVpnBgpNeighborsItemIpv6,
    UpdateNetworkApplianceVpnBgpResponse,
    UpdateNetworkApplianceVpnSiteToSiteVpnHubsItem,
    UpdateNetworkApplianceVpnSiteToSiteVpnResponse,
    UpdateNetworkApplianceVpnSiteToSiteVpnSubnet,
    UpdateNetworkApplianceVpnSiteToSiteVpnSubnetsItem,
    UpdateNetworkApplianceWarmSpareResponse,
    UpdateOrganizationApplianceDnsLocalProfileResponse,
    UpdateOrganizationApplianceDnsLocalRecordProfile,
    UpdateOrganizationApplianceDnsLocalRecordResponse,
    UpdateOrganizationApplianceDnsSplitProfileNameservers,
    UpdateOrganizationApplianceDnsSplitProfileResponse,
    UpdateOrganizationApplianceSecurityIntrusionAllowedRulesItem,
    UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasItemsItem,
    UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponse,
    UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseItemsItem,
    UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseMeta,
    UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItem,
    UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItemEbgpNeighbor,
    UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItemNetwork,
    UpdateOrganizationApplianceVpnThirdPartyVPNPeersResponse,
    UpdateOrganizationApplianceVpnVpnFirewallRulesResponse,
    UpdateOrganizationApplianceVpnVpnFirewallRulesRulesItem,
)
from meraki_client.schemas._base import DictResponse
from meraki_client.schemas._camera import (
    CameraAppliedOnDevicesItem,
    CameraAppliedOrgWideItem,
    CameraBoundaries,
    CameraBoundaries2,
    CameraIdentity,
    CameraRegionOfInterest,
    CameraResults,
    CameraSmartRetention,
    CameraSsid,
    CameraStatus,
    CameraVerticesItem,
    CameraZonesZoneId,
    CreateNetworkCameraQualityRetentionProfileResponse,
    CreateNetworkCameraQualityRetentionProfileSmartRetention,
    CreateNetworkCameraQualityRetentionProfileVideoSettings,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV12MV22MV72,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV13,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV21MV71,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV22XMV72X,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV32,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV33,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV52,
    CreateNetworkCameraQualityRetentionProfileVideoSettingsMV84X,
    CreateNetworkCameraWirelessProfileIdentity,
    CreateNetworkCameraWirelessProfileResponse,
    CreateNetworkCameraWirelessProfileSsid,
    CreateOrganizationCameraCustomAnalyticsArtifactResponse,
    CreateOrganizationCameraRoleAppliedOnDevicesItem,
    CreateOrganizationCameraRoleAppliedOnNetworksItem,
    CreateOrganizationCameraRoleAppliedOrgWideItem,
    CreateOrganizationCameraRoleResponse,
    GenerateDeviceCameraSnapshotResponse,
    GetDeviceCameraAnalyticsLiveResponse,
    GetDeviceCameraAnalyticsLiveResponseZones,
    GetDeviceCameraAnalyticsOverviewResponse,
    GetDeviceCameraAnalyticsOverviewResponseItem,
    GetDeviceCameraAnalyticsRecentResponse,
    GetDeviceCameraAnalyticsRecentResponseItem,
    GetDeviceCameraAnalyticsZoneHistoryResponse,
    GetDeviceCameraAnalyticsZoneHistoryResponseItem,
    GetDeviceCameraAnalyticsZonesResponse,
    GetDeviceCameraAnalyticsZonesResponseItem,
    GetDeviceCameraCustomAnalyticsResponse,
    GetDeviceCameraCustomAnalyticsResponseParametersItem,
    GetDeviceCameraSenseObjectDetectionModelsResponse,
    GetDeviceCameraVideoSettingsResponse,
    GetNetworkCameraQualityRetentionProfileResponse,
    GetNetworkCameraQualityRetentionProfilesResponse,
    GetNetworkCameraQualityRetentionProfilesResponseItem,
    GetNetworkCameraSchedulesResponse,
    GetNetworkCameraSchedulesResponseItem,
    GetNetworkCameraWirelessProfileResponse,
    GetNetworkCameraWirelessProfilesResponse,
    GetNetworkCameraWirelessProfilesResponseItem,
    GetOrganizationCameraBoundariesAreasByDeviceResponse,
    GetOrganizationCameraBoundariesAreasByDeviceResponseItem,
    GetOrganizationCameraBoundariesLinesByDeviceResponse,
    GetOrganizationCameraBoundariesLinesByDeviceResponseItem,
    GetOrganizationCameraCustomAnalyticsArtifactResponse,
    GetOrganizationCameraCustomAnalyticsArtifactsResponse,
    GetOrganizationCameraCustomAnalyticsArtifactsResponseItem,
    GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalResponse,
    GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalResponseItem,
    GetOrganizationCameraOnboardingStatusesResponse,
    GetOrganizationCameraPermissionResponse,
    GetOrganizationCameraPermissionsResponse,
    GetOrganizationCameraPermissionsResponseItem,
    GetOrganizationCameraRoleResponse,
    GetOrganizationCameraRolesResponse,
    GetOrganizationCameraRolesResponseItem,
    UpdateDeviceCameraCustomAnalyticsParametersItem,
    UpdateDeviceCameraCustomAnalyticsResponse,
    UpdateDeviceCameraSenseAudioDetection,
    UpdateDeviceCameraVideoSettingsResponse,
    UpdateDeviceCameraWirelessProfilesIds,
    UpdateNetworkCameraQualityRetentionProfileResponse,
    UpdateNetworkCameraQualityRetentionProfileSmartRetention,
    UpdateNetworkCameraQualityRetentionProfileVideoSettings,
    UpdateNetworkCameraWirelessProfileIdentity,
    UpdateNetworkCameraWirelessProfileResponse,
    UpdateNetworkCameraWirelessProfileSsid,
    UpdateOrganizationCameraRoleAppliedOnDevicesItem,
    UpdateOrganizationCameraRoleAppliedOnNetworksItem,
    UpdateOrganizationCameraRoleAppliedOrgWideItem,
    UpdateOrganizationCameraRoleResponse,
)
from meraki_client.schemas._campus_gateway import (
    CampusGatewayAddressesItem,
    CampusGatewayAddressesItem2,
    CampusGatewayAddressesItem3,
    CampusGatewayAddressesItem4,
    CampusGatewayDevicesUplinksItem,
    CampusGatewayNetwork,
    CampusGatewayTunnelsAddressesItem,
    CampusGatewayTunnelsUplink,
    CampusGatewayUplink,
    CampusGatewayUplinksAddressesItem,
    CreateNetworkCampusGatewayClusterDevicesItem,
    CreateNetworkCampusGatewayClusterDevicesItemUplinksItem,
    CreateNetworkCampusGatewayClusterNameservers,
    CreateNetworkCampusGatewayClusterPortChannelsItem,
    CreateNetworkCampusGatewayClusterResponse,
    CreateNetworkCampusGatewayClusterResponseDevicesItem,
    CreateNetworkCampusGatewayClusterResponseNameservers,
    CreateNetworkCampusGatewayClusterResponsePortChannelsItem,
    CreateNetworkCampusGatewayClusterResponseTunnelsItem,
    CreateNetworkCampusGatewayClusterResponseUplinksItem,
    CreateNetworkCampusGatewayClusterTunnelsItem,
    CreateNetworkCampusGatewayClusterTunnelsItemAddressesItem,
    CreateNetworkCampusGatewayClusterTunnelsItemUplink,
    CreateNetworkCampusGatewayClusterUplinksItem,
    CreateNetworkCampusGatewayClusterUplinksItemAddressesItem,
    GetOrganizationCampusGatewayClustersResponseItemsItem,
    GetOrganizationCampusGatewayDevicesUplinksLocalOverridesByDeviceResponseItemsItem,
    UpdateNetworkCampusGatewayClusterDevicesItem,
    UpdateNetworkCampusGatewayClusterDevicesItemUplinksItem,
    UpdateNetworkCampusGatewayClusterNameservers,
    UpdateNetworkCampusGatewayClusterPortChannelsItem,
    UpdateNetworkCampusGatewayClusterResponse,
    UpdateNetworkCampusGatewayClusterTunnelsItem,
    UpdateNetworkCampusGatewayClusterTunnelsItemAddressesItem,
    UpdateNetworkCampusGatewayClusterUplinksItem,
    UpdateNetworkCampusGatewayClusterUplinksItemAddressesItem,
)
from meraki_client.schemas._cellular_gateway import (
    CellularGatewayApnsItem,
    CellularGatewayDestinationsItem,
    CellularGatewayDevice,
    CellularGatewayLogo,
    CellularGatewayNetwork,
    CellularGatewayPlansItem,
    CellularGatewayProfilesItem,
    CellularGatewayRoaming,
    CellularGatewayServiceProvider,
    CellularGatewayServiceProvider2,
    CellularGatewaySignalStat,
    CellularGatewayTerms,
    CellularGatewayUplinksItem,
    CreateOrganizationCellularGatewayEsimsServiceProvidersAccountResponse,
    CreateOrganizationCellularGatewayEsimsServiceProvidersAccountServiceProvider,
    CreateOrganizationCellularGatewayEsimsSwapResponse,
    CreateOrganizationCellularGatewayEsimsSwapSwapsItem,
    CreateOrganizationCellularGatewayEsimsSwapSwapsItemTarget,
    GetDeviceCellularGatewayLanResponse,
    GetDeviceCellularGatewayLanResponseFixedIpAssignmentsItem,
    GetDeviceCellularGatewayLanResponseReservedIpRangesItem,
    GetDeviceCellularGatewayPortForwardingRulesResponse,
    GetDeviceCellularGatewayPortForwardingRulesResponseRulesItem,
    GetNetworkCellularGatewayConnectivityMonitoringDestinationsResponse,
    GetNetworkCellularGatewayDhcpResponse,
    GetNetworkCellularGatewaySubnetPoolResponse,
    GetNetworkCellularGatewaySubnetPoolResponseSubnetsItem,
    GetNetworkCellularGatewayUplinkResponse,
    GetNetworkCellularGatewayUplinkResponseBandwidthLimits,
    GetOrganizationCellularGatewayEsimsInventoryResponseItemsItem,
    GetOrganizationCellularGatewayEsimsServiceProvidersAccountsCommunicationPlansResponseItemsItem,
    GetOrganizationCellularGatewayEsimsServiceProvidersAccountsRatePlansResponseItemsItem,
    GetOrganizationCellularGatewayEsimsServiceProvidersAccountsResponse,
    GetOrganizationCellularGatewayEsimsServiceProvidersAccountsResponseItem,
    GetOrganizationCellularGatewayEsimsServiceProvidersResponseItemsItem,
    GetOrganizationCellularGatewayUplinkStatusesResponse,
    GetOrganizationCellularGatewayUplinkStatusesResponseItem,
    UpdateDeviceCellularGatewayLanFixedIpAssignmentsItem,
    UpdateDeviceCellularGatewayLanReservedIpRangesItem,
    UpdateDeviceCellularGatewayLanResponse,
    UpdateDeviceCellularGatewayPortForwardingRulesResponse,
    UpdateDeviceCellularGatewayPortForwardingRulesRulesItem,
    UpdateNetworkCellularGatewayConnectivityMonitoringDestinationsDestinationsItem,
    UpdateNetworkCellularGatewayConnectivityMonitoringDestinationsResponse,
    UpdateNetworkCellularGatewayDhcpResponse,
    UpdateNetworkCellularGatewaySubnetPoolResponse,
    UpdateNetworkCellularGatewayUplinkBandwidthLimits,
    UpdateNetworkCellularGatewayUplinkResponse,
    UpdateOrganizationCellularGatewayEsimsInventoryResponse,
    UpdateOrganizationCellularGatewayEsimsServiceProvidersAccountResponse,
    UpdateOrganizationCellularGatewayEsimsSwapResponse,
)
from meraki_client.schemas._devices import (
    BlinkDeviceLedsResponse,
    CreateDeviceLiveToolsArpTableCallback,
    CreateDeviceLiveToolsArpTableCallbackHttpServer,
    CreateDeviceLiveToolsArpTableResponse,
    CreateDeviceLiveToolsArpTableResponseCallback,
    CreateDeviceLiveToolsArpTableResponseRequest,
    CreateDeviceLiveToolsCableTestCallback,
    CreateDeviceLiveToolsCableTestResponse,
    CreateDeviceLiveToolsCableTestResponseRequest,
    CreateDeviceLiveToolsLedsBlinkCallback,
    CreateDeviceLiveToolsLedsBlinkResponse,
    CreateDeviceLiveToolsLedsBlinkResponseRequest,
    CreateDeviceLiveToolsMacTableCallback,
    CreateDeviceLiveToolsMacTableResponse,
    CreateDeviceLiveToolsMulticastRoutingCallback,
    CreateDeviceLiveToolsMulticastRoutingResponse,
    CreateDeviceLiveToolsPingCallback,
    CreateDeviceLiveToolsPingDeviceCallback,
    CreateDeviceLiveToolsPingDeviceResponse,
    CreateDeviceLiveToolsPingDeviceResponseRequest,
    CreateDeviceLiveToolsPingResponse,
    CreateDeviceLiveToolsPingResponseRequest,
    CreateDeviceLiveToolsThroughputTestCallback,
    CreateDeviceLiveToolsThroughputTestResponse,
    CreateDeviceLiveToolsThroughputTestResponseResult,
    CreateDeviceLiveToolsWakeOnLanCallback,
    CreateDeviceLiveToolsWakeOnLanResponse,
    CreateDeviceLiveToolsWakeOnLanResponseRequest,
    DevicesAuthentication,
    DevicesResultsLatencies,
    DevicesResultsLoss,
    DevicesResultsPairsItem,
    DevicesResultSpeeds,
    DevicesResultsRepliesItem,
    DevicesSimsApnsItem,
    DevicesUsage,
    DevicesWan1Vrf,
    GetDeviceCellularSimsResponse,
    GetDeviceCellularSimsResponseSimFailover,
    GetDeviceCellularSimsResponseSimsItem,
    GetDeviceClientsResponse,
    GetDeviceClientsResponseItem,
    GetDeviceLiveToolsArpTableResponse,
    GetDeviceLiveToolsArpTableResponseEntriesItem,
    GetDeviceLiveToolsCableTestResponse,
    GetDeviceLiveToolsCableTestResponseResultsItem,
    GetDeviceLiveToolsLedsBlinkResponse,
    GetDeviceLiveToolsMacTableResponse,
    GetDeviceLiveToolsMacTableResponseEntriesItem,
    GetDeviceLiveToolsMulticastRoutingResponse,
    GetDeviceLiveToolsMulticastRoutingResponseInterfacesItem,
    GetDeviceLiveToolsMulticastRoutingResponseRoutesItem,
    GetDeviceLiveToolsPingDeviceResponse,
    GetDeviceLiveToolsPingResponse,
    GetDeviceLiveToolsPingResponseResults,
    GetDeviceLiveToolsThroughputTestResponse,
    GetDeviceLiveToolsWakeOnLanResponse,
    GetDeviceLldpCdpResponse,
    GetDeviceLossAndLatencyHistoryResponse,
    GetDeviceLossAndLatencyHistoryResponseItem,
    GetDeviceManagementInterfaceResponse,
    GetDeviceManagementInterfaceResponseDdnsHostnames,
    GetDeviceManagementInterfaceResponseWan1,
    GetDeviceResponse,
    GetDeviceResponseBeaconIdParams,
    GetDeviceResponseDetailsItem,
    RebootDeviceResponse,
    UpdateDeviceCellularSimsResponse,
    UpdateDeviceCellularSimsSimFailover,
    UpdateDeviceCellularSimsSimsItem,
    UpdateDeviceManagementInterfaceResponse,
    UpdateDeviceManagementInterfaceWan1,
    UpdateDeviceManagementInterfaceWan2,
    UpdateDeviceResponse,
)
from meraki_client.schemas._insight import (
    CreateOrganizationInsightMonitoredMediaServerResponse,
    GetNetworkInsightApplicationHealthByTimeResponse,
    GetNetworkInsightApplicationHealthByTimeResponseItem,
    GetOrganizationInsightApplicationsResponse,
    GetOrganizationInsightApplicationsResponseItem,
    GetOrganizationInsightMonitoredMediaServerResponse,
    GetOrganizationInsightMonitoredMediaServersResponse,
    GetOrganizationInsightMonitoredMediaServersResponseItem,
    InsightByNetworkItem,
    InsightThresholds,
    UpdateOrganizationInsightMonitoredMediaServerResponse,
)
from meraki_client.schemas._licensing import (
    BindAdministeredLicensingSubscriptionSubscriptionResponse,
    BindAdministeredLicensingSubscriptionSubscriptionResponseNetworksItem,
    ClaimAdministeredLicensingSubscriptionSubscriptionsResponse,
    GetAdministeredLicensingSubscriptionEntitlementsResponse,
    GetAdministeredLicensingSubscriptionEntitlementsResponseItem,
    GetAdministeredLicensingSubscriptionSubscriptionsComplianceStatusesResponse,
    GetAdministeredLicensingSubscriptionSubscriptionsComplianceStatusesResponseItem,
    GetAdministeredLicensingSubscriptionSubscriptionsResponse,
    GetAdministeredLicensingSubscriptionSubscriptionsResponseItem,
    GetOrganizationLicensingCotermLicensesResponse,
    GetOrganizationLicensingCotermLicensesResponseItem,
    LicensingAccount,
    LicensingByProductClassItem,
    LicensingCounts,
    LicensingCountsItem,
    LicensingEditionsItem,
    LicensingEnterpriseAgreement,
    LicensingEntitlementsItem,
    LicensingEntitlementsItem2,
    LicensingMissing,
    LicensingSeats,
    LicensingSmartAccount,
    LicensingSubscription,
    LicensingViolations,
    MoveOrganizationLicensingCotermLicensesDestination,
    MoveOrganizationLicensingCotermLicensesLicensesItem,
    MoveOrganizationLicensingCotermLicensesLicensesItemCountsItem,
    MoveOrganizationLicensingCotermLicensesResponse,
    MoveOrganizationLicensingCotermLicensesResponseRemainderLicensesItem,
    ValidateAdministeredLicensingSubscriptionSubscriptionsClaimKeyResponse,
)
from meraki_client.schemas._networks import (
    BatchNetworkFloorPlansAutoLocateJobsJobsItem,
    BatchNetworkFloorPlansAutoLocateJobsResponse,
    BatchNetworkFloorPlansAutoLocateJobsResponseJobsItem,
    BatchNetworkFloorPlansDevicesUpdateAssignmentsItem,
    BatchNetworkFloorPlansDevicesUpdateResponse,
    BindNetworkResponse,
    ClaimNetworkDevicesDetailsByDeviceItem,
    ClaimNetworkDevicesDetailsByDeviceItemDetailsItem,
    ClaimNetworkDevicesResponse,
    ClaimNetworkDevicesResponseErrorsItem,
    CreateNetworkFirmwareUpgradesRollbackReasonsItem,
    CreateNetworkFirmwareUpgradesRollbackResponse,
    CreateNetworkFirmwareUpgradesRollbackResponseReasonsItem,
    CreateNetworkFirmwareUpgradesRollbackToVersion,
    CreateNetworkFirmwareUpgradesStagedEventProducts,
    CreateNetworkFirmwareUpgradesStagedEventProductsSwitch,
    CreateNetworkFirmwareUpgradesStagedEventResponse,
    CreateNetworkFirmwareUpgradesStagedEventStagesItem,
    CreateNetworkFirmwareUpgradesStagedGroupAssignedDevices,
    CreateNetworkFirmwareUpgradesStagedGroupAssignedDevicesDevicesItem,
    CreateNetworkFirmwareUpgradesStagedGroupAssignedDevicesSwitchStacksItem,
    CreateNetworkFirmwareUpgradesStagedGroupResponse,
    CreateNetworkFloorPlanBottomLeftCorner,
    CreateNetworkFloorPlanBottomRightCorner,
    CreateNetworkFloorPlanCenter,
    CreateNetworkFloorPlanResponse,
    CreateNetworkFloorPlanTopLeftCorner,
    CreateNetworkFloorPlanTopRightCorner,
    CreateNetworkGroupPolicyBandwidth,
    CreateNetworkGroupPolicyBonjourForwarding,
    CreateNetworkGroupPolicyContentFiltering,
    CreateNetworkGroupPolicyFirewallAndTrafficShaping,
    CreateNetworkGroupPolicyResponse,
    CreateNetworkGroupPolicyScheduling,
    CreateNetworkGroupPolicyVlanTagging,
    CreateNetworkMerakiAuthUserAuthorizationsItem,
    CreateNetworkMerakiAuthUserResponse,
    CreateNetworkMqttBrokerAuthentication,
    CreateNetworkMqttBrokerResponse,
    CreateNetworkMqttBrokerSecurity,
    CreateNetworkMqttBrokerSecurityTls,
    CreateNetworkPiiRequestResponse,
    CreateNetworkVlanProfileResponse,
    CreateNetworkVlanProfileVlanGroupsItem,
    CreateNetworkVlanProfileVlanNamesItem,
    CreateNetworkWebhooksHttpServerPayloadTemplate,
    CreateNetworkWebhooksHttpServerResponse,
    CreateNetworkWebhooksPayloadTemplateHeadersItem,
    CreateNetworkWebhooksPayloadTemplateResponse,
    CreateNetworkWebhooksWebhookTestResponse,
    DeferNetworkFirmwareUpgradesStagedEventsResponse,
    DeleteNetworkFloorPlanResponse,
    GetNetworkAlertsHistoryResponse,
    GetNetworkAlertsHistoryResponseItem,
    GetNetworkAlertsSettingsResponse,
    GetNetworkAlertsSettingsResponseAlertsItem,
    GetNetworkAlertsSettingsResponseDefaultDestinations,
    GetNetworkAlertsSettingsResponseMuting,
    GetNetworkBluetoothClientResponse,
    GetNetworkBluetoothClientsResponse,
    GetNetworkBluetoothClientsResponseItem,
    GetNetworkClientPolicyResponse,
    GetNetworkClientPolicyResponsePoliciesBySsidItem,
    GetNetworkClientResponse,
    GetNetworkClientResponseClientVpnConnectionsItem,
    GetNetworkClientsApplicationUsageResponse,
    GetNetworkClientsApplicationUsageResponseItem,
    GetNetworkClientsBandwidthUsageHistoryResponse,
    GetNetworkClientsBandwidthUsageHistoryResponseItem,
    GetNetworkClientsOverviewResponse,
    GetNetworkClientsOverviewResponseCounts,
    GetNetworkClientsOverviewResponseUsages,
    GetNetworkClientsResponse,
    GetNetworkClientsResponseItem,
    GetNetworkClientsUsageHistoriesResponse,
    GetNetworkClientsUsageHistoriesResponseItem,
    GetNetworkClientTrafficHistoryResponse,
    GetNetworkClientTrafficHistoryResponseItem,
    GetNetworkClientUsageHistoryResponse,
    GetNetworkClientUsageHistoryResponseItem,
    GetNetworkDevicesResponse,
    GetNetworkDevicesResponseItem,
    GetNetworkEventsEventTypesResponse,
    GetNetworkEventsEventTypesResponseItem,
    GetNetworkEventsResponse,
    GetNetworkEventsResponseEventsItem,
    GetNetworkFirmwareUpgradesResponse,
    GetNetworkFirmwareUpgradesResponseProducts,
    GetNetworkFirmwareUpgradesResponseUpgradeWindow,
    GetNetworkFirmwareUpgradesStagedEventsResponse,
    GetNetworkFirmwareUpgradesStagedEventsResponseProducts,
    GetNetworkFirmwareUpgradesStagedEventsResponseStagesItem,
    GetNetworkFirmwareUpgradesStagedGroupResponse,
    GetNetworkFirmwareUpgradesStagedGroupsResponse,
    GetNetworkFirmwareUpgradesStagedGroupsResponseItem,
    GetNetworkFirmwareUpgradesStagedStagesResponse,
    GetNetworkFirmwareUpgradesStagedStagesResponseItem,
    GetNetworkFloorPlanResponse,
    GetNetworkFloorPlansResponse,
    GetNetworkFloorPlansResponseItem,
    GetNetworkGroupPoliciesResponse,
    GetNetworkGroupPoliciesResponseItem,
    GetNetworkGroupPolicyResponse,
    GetNetworkHealthAlertsResponse,
    GetNetworkHealthAlertsResponseItem,
    GetNetworkMerakiAuthUserResponse,
    GetNetworkMerakiAuthUsersResponse,
    GetNetworkMerakiAuthUsersResponseItem,
    GetNetworkMqttBrokerResponse,
    GetNetworkMqttBrokersResponse,
    GetNetworkMqttBrokersResponseItem,
    GetNetworkNetflowResponse,
    GetNetworkNetworkHealthChannelUtilizationResponse,
    GetNetworkNetworkHealthChannelUtilizationResponseItem,
    GetNetworkPiiPiiKeysResponse,
    GetNetworkPiiPiiKeysResponseValue,
    GetNetworkPiiRequestResponse,
    GetNetworkPiiRequestsResponse,
    GetNetworkPiiRequestsResponseItem,
    GetNetworkPiiSmDevicesForKeyResponse,
    GetNetworkPiiSmOwnersForKeyResponse,
    GetNetworkPoliciesByClientResponse,
    GetNetworkPoliciesByClientResponseItem,
    GetNetworkResponse,
    GetNetworkSettingsResponse,
    GetNetworkSettingsResponseLocalStatusPage,
    GetNetworkSettingsResponseNamedVlans,
    GetNetworkSnmpResponse,
    GetNetworkSnmpResponseUsersItem,
    GetNetworkSplashLoginAttemptsResponse,
    GetNetworkSplashLoginAttemptsResponseItem,
    GetNetworkSyslogServersResponse,
    GetNetworkSyslogServersResponseServersItem,
    GetNetworkTopologyLinkLayerResponse,
    GetNetworkTopologyLinkLayerResponseLinksItem,
    GetNetworkTopologyLinkLayerResponseNodesItem,
    GetNetworkTrafficAnalysisResponse,
    GetNetworkTrafficAnalysisResponseCustomPieChartItemsItem,
    GetNetworkTrafficResponse,
    GetNetworkTrafficResponseItem,
    GetNetworkTrafficShapingDscpTaggingOptionsResponse,
    GetNetworkVlanProfileResponse,
    GetNetworkVlanProfilesAssignmentsByDeviceResponse,
    GetNetworkVlanProfilesAssignmentsByDeviceResponseItem,
    GetNetworkVlanProfilesResponse,
    GetNetworkVlanProfilesResponseItem,
    GetNetworkWebhooksHttpServerResponse,
    GetNetworkWebhooksHttpServersResponse,
    GetNetworkWebhooksHttpServersResponseItem,
    GetNetworkWebhooksPayloadTemplateResponse,
    GetNetworkWebhooksPayloadTemplatesResponse,
    GetNetworkWebhooksPayloadTemplatesResponseItem,
    GetNetworkWebhooksWebhookTestResponse,
    NetworksAlertsAlertDestinations,
    NetworksAlertsFilters,
    NetworksAllowedUrlPatterns,
    NetworksApplicationsItem,
    NetworksApplicationUsageItem,
    NetworksAssignedDevices,
    NetworksAssignedItem,
    NetworksAuthentication,
    NetworksAuthorizationsItem,
    NetworksBandwidth,
    NetworksBandwidthLimits,
    NetworksBeaconIdParams,
    NetworksBlockedUrlCategories,
    NetworksBonjourForwarding,
    NetworksByNetwork,
    NetworksCdp,
    NetworksCdp2,
    NetworksCenter,
    NetworksClients,
    NetworksClientsItem,
    NetworksConditionsItem,
    NetworksContentFiltering,
    NetworksCounts,
    NetworksCurrentVersion,
    NetworksDefinitionsItem,
    NetworksDestinations,
    NetworksDetailsItem,
    NetworksDevice,
    NetworksDevicesItem,
    NetworksDevicesItem2,
    NetworksDevicesItem3,
    NetworksDiscovered,
    NetworksEmail,
    NetworksEventsEventData,
    NetworksFirewallAndTrafficShaping,
    NetworksHeadersItem,
    NetworksJobsCompleted,
    NetworksJobsErrorsItem,
    NetworksJobsRanging,
    NetworksL3FirewallRulesItem,
    NetworksL7FirewallRulesItem,
    NetworksLastUpgrade,
    NetworksLinksEndsItem,
    NetworksLldp,
    NetworksLldp2,
    NetworksLldp3,
    NetworksLocalStatusPageAuthentication,
    NetworksMonday,
    NetworksMutingByPortSchedules,
    NetworksNextUpgrade,
    NetworksNextUpgrade2,
    NetworksNextUpgrade3,
    NetworksNextUpgrade4,
    NetworksNode,
    NetworksNodesDevice,
    NetworksNodesDiscovered,
    NetworksNodesStack,
    NetworksPayloadTemplate,
    NetworksPeersItem,
    NetworksPerClientBandwidthLimits,
    NetworksProductsSwitch,
    NetworksProductsWireless,
    NetworksRulesItem,
    NetworksScheduling,
    NetworksScope,
    NetworksSecurity,
    NetworksSharing,
    NetworksSsidItem,
    NetworksStagesGroup,
    NetworksStagesMilestones,
    NetworksSwitchStacksItem,
    NetworksTls,
    NetworksToVersion,
    NetworksToVersion2,
    NetworksTrafficShapingRulesItem,
    NetworksUplinksItem,
    NetworksUsage,
    NetworksUsageHistoryItem,
    NetworksVlanGroupsItem,
    NetworksVlanNamesItem,
    NetworksVlanProfile,
    NetworksVlanTagging,
    NetworksWifi0Item,
    ProvisionNetworkClientsClientsItem,
    ProvisionNetworkClientsPoliciesBySecurityAppliance,
    ProvisionNetworkClientsPoliciesBySsid,
    ProvisionNetworkClientsPoliciesBySsid0,
    ProvisionNetworkClientsResponse,
    ProvisionNetworkClientsResponseClientsItem,
    PublishNetworkFloorPlansAutoLocateJobDevicesItem,
    PublishNetworkFloorPlansAutoLocateJobDevicesItemAutoLocate,
    PublishNetworkFloorPlansAutoLocateJobResponse,
    ReassignNetworkVlanProfilesAssignmentsResponse,
    ReassignNetworkVlanProfilesAssignmentsResponseVlanProfile,
    ReassignNetworkVlanProfilesAssignmentsVlanProfile,
    RecalculateNetworkFloorPlansAutoLocateJobDevicesItem,
    RecalculateNetworkFloorPlansAutoLocateJobDevicesItemAutoLocate,
    RecalculateNetworkFloorPlansAutoLocateJobResponse,
    RollbacksNetworkFirmwareUpgradesStagedEventsReasonsItem,
    RollbacksNetworkFirmwareUpgradesStagedEventsResponse,
    RollbacksNetworkFirmwareUpgradesStagedEventsStagesItem,
    SplitNetworkResponse,
    SplitNetworkResponseResultingNetworksItem,
    UnbindNetworkResponse,
    UpdateNetworkAlertsSettingsAlertsItem,
    UpdateNetworkAlertsSettingsDefaultDestinations,
    UpdateNetworkAlertsSettingsMuting,
    UpdateNetworkAlertsSettingsResponse,
    UpdateNetworkClientPolicyResponse,
    UpdateNetworkClientSplashAuthorizationStatusSsids,
    UpdateNetworkClientSplashAuthorizationStatusSsids0,
    UpdateNetworkFirmwareUpgradesProducts,
    UpdateNetworkFirmwareUpgradesProductsWireless,
    UpdateNetworkFirmwareUpgradesResponse,
    UpdateNetworkFirmwareUpgradesStagedEventsResponse,
    UpdateNetworkFirmwareUpgradesStagedEventsStagesItem,
    UpdateNetworkFirmwareUpgradesStagedEventsStagesItemGroup,
    UpdateNetworkFirmwareUpgradesStagedEventsStagesItemMilestones,
    UpdateNetworkFirmwareUpgradesStagedGroupAssignedDevices,
    UpdateNetworkFirmwareUpgradesStagedGroupResponse,
    UpdateNetworkFirmwareUpgradesStagedStagesJsonItem,
    UpdateNetworkFirmwareUpgradesStagedStagesResponse,
    UpdateNetworkFirmwareUpgradesStagedStagesResponseItem,
    UpdateNetworkFirmwareUpgradesUpgradeWindow,
    UpdateNetworkFloorPlanBottomLeftCorner,
    UpdateNetworkFloorPlanBottomRightCorner,
    UpdateNetworkFloorPlanCenter,
    UpdateNetworkFloorPlanResponse,
    UpdateNetworkFloorPlanTopLeftCorner,
    UpdateNetworkFloorPlanTopRightCorner,
    UpdateNetworkGroupPolicyBandwidth,
    UpdateNetworkGroupPolicyBonjourForwarding,
    UpdateNetworkGroupPolicyContentFiltering,
    UpdateNetworkGroupPolicyFirewallAndTrafficShaping,
    UpdateNetworkGroupPolicyResponse,
    UpdateNetworkGroupPolicyScheduling,
    UpdateNetworkGroupPolicyVlanTagging,
    UpdateNetworkMerakiAuthUserAuthorizationsItem,
    UpdateNetworkMerakiAuthUserResponse,
    UpdateNetworkMqttBrokerAuthentication,
    UpdateNetworkMqttBrokerResponse,
    UpdateNetworkMqttBrokerSecurity,
    UpdateNetworkNetflowResponse,
    UpdateNetworkResponse,
    UpdateNetworkSettingsLocalStatusPage,
    UpdateNetworkSettingsLocalStatusPageAuthentication,
    UpdateNetworkSettingsNamedVlans,
    UpdateNetworkSettingsResponse,
    UpdateNetworkSettingsSecurePort,
    UpdateNetworkSnmpResponse,
    UpdateNetworkSnmpUsersItem,
    UpdateNetworkSyslogServersResponse,
    UpdateNetworkSyslogServersServersItem,
    UpdateNetworkTrafficAnalysisCustomPieChartItemsItem,
    UpdateNetworkTrafficAnalysisResponse,
    UpdateNetworkVlanProfileResponse,
    UpdateNetworkVlanProfileVlanGroupsItem,
    UpdateNetworkVlanProfileVlanNamesItem,
    UpdateNetworkWebhooksHttpServerPayloadTemplate,
    UpdateNetworkWebhooksHttpServerResponse,
    UpdateNetworkWebhooksPayloadTemplateHeadersItem,
    UpdateNetworkWebhooksPayloadTemplateResponse,
    VmxNetworkDevicesClaimResponse,
)
from meraki_client.schemas._organizations import (
    AssignOrganizationLicensesSeatsResponse,
    AssignOrganizationLicensesSeatsResponseResultingLicensesItem,
    BulkOrganizationDevicesPacketCaptureCapturesCreateAdvanced,
    BulkOrganizationDevicesPacketCaptureCapturesCreateDevicesItem,
    BulkOrganizationDevicesPacketCaptureCapturesCreateResponse,
    BulkOrganizationDevicesPacketCaptureCapturesCreateResponseItemsItem,
    BulkUpdateOrganizationDevicesDetailsDetailsItem,
    BulkUpdateOrganizationDevicesDetailsResponse,
    ClaimIntoOrganizationInventoryLicensesItem,
    ClaimIntoOrganizationInventoryResponse,
    ClaimIntoOrganizationLicensesItem,
    ClaimIntoOrganizationResponse,
    ClaimIntoOrganizationResponseLicensesItem,
    ClaimOrganizationInventoryOrdersResponse,
    ClaimOrganizationInventoryOrdersResponseSubscriptionsItem,
    ClaimOrganizationInventoryOrdersSubscriptionsItem,
    CloneOrganizationResponse,
    CombineOrganizationNetworksResponse,
    CreateNetworkMoveNetwork,
    CreateNetworkMoveOrganizations,
    CreateNetworkMoveOrganizationsTarget,
    CreateNetworkMoveResponse,
    CreateOrganizationActionBatchActionsItem,
    CreateOrganizationActionBatchCallback,
    CreateOrganizationActionBatchCallbackHttpServer,
    CreateOrganizationActionBatchResponse,
    CreateOrganizationActionBatchResponseCallback,
    CreateOrganizationAdaptivePolicyAclResponse,
    CreateOrganizationAdaptivePolicyAclRulesItem,
    CreateOrganizationAdaptivePolicyGroupPolicyObjectsItem,
    CreateOrganizationAdaptivePolicyGroupResponse,
    CreateOrganizationAdaptivePolicyPolicyAclsItem,
    CreateOrganizationAdaptivePolicyPolicyDestinationGroup,
    CreateOrganizationAdaptivePolicyPolicyResponse,
    CreateOrganizationAdaptivePolicyPolicySourceGroup,
    CreateOrganizationAdminNetworksItem,
    CreateOrganizationAdminResponse,
    CreateOrganizationAdminTagsItem,
    CreateOrganizationAlertsProfileAlertCondition,
    CreateOrganizationAlertsProfileRecipients,
    CreateOrganizationAlertsProfileResponse,
    CreateOrganizationBrandingPolicyAdminSettings,
    CreateOrganizationBrandingPolicyCustomLogo,
    CreateOrganizationBrandingPolicyCustomLogoImage,
    CreateOrganizationBrandingPolicyHelpSettings,
    CreateOrganizationBrandingPolicyResponse,
    CreateOrganizationConfigTemplateResponse,
    CreateOrganizationDevicesControllerMigrationResponse,
    CreateOrganizationDevicesControllerMigrationResponseItem,
    CreateOrganizationDevicesPacketCaptureCaptureAdvanced,
    CreateOrganizationDevicesPacketCaptureCaptureResponse,
    CreateOrganizationDevicesPacketCaptureScheduleDevicesItem,
    CreateOrganizationDevicesPacketCaptureScheduleResponse,
    CreateOrganizationDevicesPacketCaptureScheduleSchedule,
    CreateOrganizationEarlyAccessFeaturesOptInResponse,
    CreateOrganizationInventoryDevicesSwapsBulkResponse,
    CreateOrganizationInventoryDevicesSwapsBulkResponseSwapsItem,
    CreateOrganizationInventoryDevicesSwapsBulkSwapsItem,
    CreateOrganizationInventoryDevicesSwapsBulkSwapsItemDevices,
    CreateOrganizationInventoryOnboardingCloudMonitoringImportDevicesItem,
    CreateOrganizationInventoryOnboardingCloudMonitoringImportResponse,
    CreateOrganizationInventoryOnboardingCloudMonitoringImportResponseItem,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItem,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemTunnel,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemUser,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemVty,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareOptions,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareResponse,
    CreateOrganizationInventoryOnboardingCloudMonitoringPrepareResponseItem,
    CreateOrganizationManagement,
    CreateOrganizationNetworkResponse,
    CreateOrganizationPolicyObjectResponse,
    CreateOrganizationPolicyObjectsGroupResponse,
    CreateOrganizationResponse,
    CreateOrganizationSamlIdpResponse,
    CreateOrganizationSamlIdpResponseItem,
    CreateOrganizationSamlRoleNetworksItem,
    CreateOrganizationSamlRoleResponse,
    CreateOrganizationSamlRoleTagsItem,
    CreateOrganizationSplashThemeAssetResponse,
    CreateOrganizationSplashThemeResponse,
    DisableOrganizationIntegrationsXdrNetworksNetworksItem,
    DisableOrganizationIntegrationsXdrNetworksResponse,
    DisableOrganizationIntegrationsXdrNetworksResponseNetworksItem,
    EnableOrganizationIntegrationsXdrNetworksNetworksItem,
    EnableOrganizationIntegrationsXdrNetworksResponse,
    GenerateOrganizationDevicesPacketCaptureCaptureDownloadUrlResponse,
    GetNetworkMovesResponseItemsItem,
    GetOrganizationActionBatchesResponse,
    GetOrganizationActionBatchesResponseItem,
    GetOrganizationActionBatchResponse,
    GetOrganizationAdaptivePolicyAclResponse,
    GetOrganizationAdaptivePolicyAclsResponse,
    GetOrganizationAdaptivePolicyAclsResponseItem,
    GetOrganizationAdaptivePolicyGroupResponse,
    GetOrganizationAdaptivePolicyGroupsResponse,
    GetOrganizationAdaptivePolicyGroupsResponseItem,
    GetOrganizationAdaptivePolicyOverviewResponse,
    GetOrganizationAdaptivePolicyOverviewResponseCounts,
    GetOrganizationAdaptivePolicyOverviewResponseLimits,
    GetOrganizationAdaptivePolicyPoliciesResponse,
    GetOrganizationAdaptivePolicyPoliciesResponseItem,
    GetOrganizationAdaptivePolicyPolicyResponse,
    GetOrganizationAdaptivePolicySettingsResponse,
    GetOrganizationAdminsResponse,
    GetOrganizationAdminsResponseItem,
    GetOrganizationAlertsProfilesResponse,
    GetOrganizationAlertsProfilesResponseItem,
    GetOrganizationApiRequestsOverviewResponse,
    GetOrganizationApiRequestsOverviewResponseCodesByIntervalResponse,
    GetOrganizationApiRequestsOverviewResponseCodesByIntervalResponseItem,
    GetOrganizationApiRequestsOverviewResponseResponseCodeCounts,
    GetOrganizationApiRequestsResponse,
    GetOrganizationApiRequestsResponseItem,
    GetOrganizationAssuranceAlertResponse,
    GetOrganizationAssuranceAlertsOverviewByNetworkResponseItemsItem,
    GetOrganizationAssuranceAlertsOverviewByTypeResponseItemsItem,
    GetOrganizationAssuranceAlertsOverviewHistoricalResponseItemsItem,
    GetOrganizationAssuranceAlertsOverviewResponse,
    GetOrganizationAssuranceAlertsOverviewResponseCounts,
    GetOrganizationAssuranceAlertsResponse,
    GetOrganizationAssuranceAlertsResponseItem,
    GetOrganizationAssuranceAlertsTaxonomyCategoriesResponse,
    GetOrganizationAssuranceAlertsTaxonomyCategoriesResponseItem,
    GetOrganizationAssuranceAlertsTaxonomyTypesResponse,
    GetOrganizationAssuranceAlertsTaxonomyTypesResponseItem,
    GetOrganizationBrandingPoliciesPrioritiesResponse,
    GetOrganizationBrandingPoliciesResponse,
    GetOrganizationBrandingPoliciesResponseItem,
    GetOrganizationBrandingPolicyResponse,
    GetOrganizationClientsBandwidthUsageHistoryResponse,
    GetOrganizationClientsBandwidthUsageHistoryResponseItem,
    GetOrganizationClientsOverviewResponse,
    GetOrganizationClientsOverviewResponseCounts,
    GetOrganizationClientsOverviewResponseUsage,
    GetOrganizationClientsSearchResponse,
    GetOrganizationClientsSearchResponseRecordsItem,
    GetOrganizationConfigTemplateResponse,
    GetOrganizationConfigTemplatesResponse,
    GetOrganizationConfigTemplatesResponseItem,
    GetOrganizationConfigurationChangesResponse,
    GetOrganizationConfigurationChangesResponseItem,
    GetOrganizationDevicesAvailabilitiesChangeHistoryResponse,
    GetOrganizationDevicesAvailabilitiesChangeHistoryResponseItem,
    GetOrganizationDevicesAvailabilitiesResponse,
    GetOrganizationDevicesAvailabilitiesResponseItem,
    GetOrganizationDevicesControllerMigrationsResponseItemsItem,
    GetOrganizationDevicesOverviewByModelResponse,
    GetOrganizationDevicesOverviewByModelResponseCountsItem,
    GetOrganizationDevicesPacketCaptureCapturesResponseItemsItem,
    GetOrganizationDevicesPacketCaptureSchedulesResponseItemsItem,
    GetOrganizationDevicesPowerModulesStatusesByDeviceResponse,
    GetOrganizationDevicesPowerModulesStatusesByDeviceResponseItem,
    GetOrganizationDevicesProvisioningStatusesResponse,
    GetOrganizationDevicesProvisioningStatusesResponseItem,
    GetOrganizationDevicesResponse,
    GetOrganizationDevicesResponseItem,
    GetOrganizationDevicesStatusesOverviewResponse,
    GetOrganizationDevicesStatusesOverviewResponseCounts,
    GetOrganizationDevicesStatusesResponse,
    GetOrganizationDevicesStatusesResponseItem,
    GetOrganizationDevicesSystemMemoryUsageHistoryByIntervalResponseItemsItem,
    GetOrganizationDevicesUplinksAddressesByDeviceResponse,
    GetOrganizationDevicesUplinksAddressesByDeviceResponseItem,
    GetOrganizationDevicesUplinksLossAndLatencyResponse,
    GetOrganizationDevicesUplinksLossAndLatencyResponseItem,
    GetOrganizationEarlyAccessFeaturesOptInResponse,
    GetOrganizationEarlyAccessFeaturesOptInsResponse,
    GetOrganizationEarlyAccessFeaturesOptInsResponseOptOutEligibility,
    GetOrganizationEarlyAccessFeaturesResponse,
    GetOrganizationEarlyAccessFeaturesResponseItem,
    GetOrganizationFirmwareUpgradesByDeviceResponse,
    GetOrganizationFirmwareUpgradesByDeviceResponseItem,
    GetOrganizationFirmwareUpgradesResponse,
    GetOrganizationFirmwareUpgradesResponseItem,
    GetOrganizationFloorPlansAutoLocateDevicesResponse,
    GetOrganizationFloorPlansAutoLocateDevicesResponseItem,
    GetOrganizationFloorPlansAutoLocateStatusesResponse,
    GetOrganizationFloorPlansAutoLocateStatusesResponseItem,
    GetOrganizationIntegrationsXdrNetworksResponseItemsItem,
    GetOrganizationInventoryDeviceResponse,
    GetOrganizationInventoryDevicesEoxOverviewResponse,
    GetOrganizationInventoryDevicesEoxOverviewResponseCounts,
    GetOrganizationInventoryDevicesResponse,
    GetOrganizationInventoryDevicesResponseItem,
    GetOrganizationInventoryDevicesSwapsBulkResponse,
    GetOrganizationInventoryOnboardingCloudMonitoringImportsResponse,
    GetOrganizationInventoryOnboardingCloudMonitoringImportsResponseItem,
    GetOrganizationInventoryOnboardingCloudMonitoringNetworksResponse,
    GetOrganizationInventoryOnboardingCloudMonitoringNetworksResponseItem,
    GetOrganizationLicenseResponse,
    GetOrganizationLicensesOverviewResponse,
    GetOrganizationLicensesOverviewResponseLicenseTypesItem,
    GetOrganizationLicensesOverviewResponseStates,
    GetOrganizationLicensesOverviewResponseSystemsManager,
    GetOrganizationLicensesResponse,
    GetOrganizationLicensesResponseItem,
    GetOrganizationLoginSecurityResponse,
    GetOrganizationLoginSecurityResponseApiAuthentication,
    GetOrganizationNetworksResponse,
    GetOrganizationNetworksResponseItem,
    GetOrganizationPoliciesAssignmentsByClientResponse,
    GetOrganizationPoliciesAssignmentsByClientResponseItem,
    GetOrganizationPolicyObjectResponse,
    GetOrganizationPolicyObjectsGroupResponse,
    GetOrganizationPolicyObjectsGroupsResponse,
    GetOrganizationPolicyObjectsGroupsResponseItem,
    GetOrganizationPolicyObjectsResponse,
    GetOrganizationPolicyObjectsResponseItem,
    GetOrganizationResponse,
    GetOrganizationSamlIdpResponse,
    GetOrganizationSamlIdpsResponse,
    GetOrganizationSamlIdpsResponseItem,
    GetOrganizationSamlResponse,
    GetOrganizationSamlResponseSpInitiated,
    GetOrganizationSamlRoleResponse,
    GetOrganizationSamlRolesResponse,
    GetOrganizationSamlRolesResponseItem,
    GetOrganizationSnmpResponse,
    GetOrganizationSplashAssetResponse,
    GetOrganizationSplashThemesResponse,
    GetOrganizationSplashThemesResponseItem,
    GetOrganizationsResponse,
    GetOrganizationsResponseItem,
    GetOrganizationSummaryTopAppliancesByUtilizationResponse,
    GetOrganizationSummaryTopAppliancesByUtilizationResponseItem,
    GetOrganizationSummaryTopApplicationsByUsageResponse,
    GetOrganizationSummaryTopApplicationsByUsageResponseItem,
    GetOrganizationSummaryTopApplicationsCategoriesByUsageResponse,
    GetOrganizationSummaryTopApplicationsCategoriesByUsageResponseItem,
    GetOrganizationSummaryTopClientsByUsageResponse,
    GetOrganizationSummaryTopClientsByUsageResponseItem,
    GetOrganizationSummaryTopClientsManufacturersByUsageResponse,
    GetOrganizationSummaryTopClientsManufacturersByUsageResponseItem,
    GetOrganizationSummaryTopDevicesByUsageResponse,
    GetOrganizationSummaryTopDevicesByUsageResponseItem,
    GetOrganizationSummaryTopDevicesModelsByUsageResponse,
    GetOrganizationSummaryTopDevicesModelsByUsageResponseItem,
    GetOrganizationSummaryTopNetworksByStatusResponse,
    GetOrganizationSummaryTopNetworksByStatusResponseItem,
    GetOrganizationSummaryTopSsidsByUsageResponse,
    GetOrganizationSummaryTopSsidsByUsageResponseItem,
    GetOrganizationSummaryTopSwitchesByEnergyUsageResponse,
    GetOrganizationSummaryTopSwitchesByEnergyUsageResponseItem,
    GetOrganizationUplinksStatusesResponse,
    GetOrganizationUplinksStatusesResponseItem,
    GetOrganizationWebhooksAlertTypesResponse,
    GetOrganizationWebhooksAlertTypesResponseExample,
    GetOrganizationWebhooksCallbacksStatusResponse,
    GetOrganizationWebhooksCallbacksStatusResponseCreatedBy,
    GetOrganizationWebhooksCallbacksStatusResponseWebhook,
    GetOrganizationWebhooksLogsResponse,
    GetOrganizationWebhooksLogsResponseItem,
    MoveOrganizationLicensesResponse,
    MoveOrganizationLicensesSeatsResponse,
    OrganizationsAccessList,
    OrganizationsActionsItem,
    OrganizationsAddressesItem,
    OrganizationsAdminSettings,
    OrganizationsAlertCondition,
    OrganizationsApi,
    OrganizationsApiAuthenticationIpRestrictionsForKeys,
    OrganizationsAssignedItem,
    OrganizationsAuthentication,
    OrganizationsAutoLocate,
    OrganizationsAverage,
    OrganizationsByAlertTypeItem,
    OrganizationsByProductTypeItem,
    OrganizationsByProductTypeItem2,
    OrganizationsCameraItem,
    OrganizationsClient,
    OrganizationsClient2,
    OrganizationsClient3,
    OrganizationsClients,
    OrganizationsClients2,
    OrganizationsCloud,
    OrganizationsCodesByIntervalResponseCountsItem,
    OrganizationsCompleted,
    OrganizationsComponents,
    OrganizationsConfigParams,
    OrganizationsCounts,
    OrganizationsCounts2,
    OrganizationsCountsBySeverityItem,
    OrganizationsCountsByStatus,
    OrganizationsCountsByStatus2,
    OrganizationsCreatedResourcesItem,
    OrganizationsCritical,
    OrganizationsCustomLogo,
    OrganizationsDescriptions,
    OrganizationsDetails,
    OrganizationsDetailsItem,
    OrganizationsDetailsItem2,
    OrganizationsDevice,
    OrganizationsDevice2,
    OrganizationsDevice3,
    OrganizationsDevice4,
    OrganizationsDevices,
    OrganizationsDevicesItem,
    OrganizationsDevicesItem2,
    OrganizationsDevicesItem3,
    OrganizationsEox,
    OrganizationsErrorsItem,
    OrganizationsFile,
    OrganizationsFree,
    OrganizationsFromVersion,
    OrganizationsHelpSettings,
    OrganizationsHighAvailability,
    OrganizationsHost,
    OrganizationsImage,
    OrganizationsInitiator,
    OrganizationsIntervalsItem,
    OrganizationsJobsItem,
    OrganizationsLicenseTypesCounts,
    OrganizationsLicensing,
    OrganizationsLimitToItem,
    OrganizationsLldp,
    OrganizationsManagement,
    OrganizationsMemory,
    OrganizationsNameservers,
    OrganizationsNetwork,
    OrganizationsNetwork2,
    OrganizationsNetwork3,
    OrganizationsNetworksItem,
    OrganizationsOld,
    OrganizationsOldestActivation,
    OrganizationsOptOutEligibilityHelp,
    OrganizationsOrganizations,
    OrganizationsPercentages,
    OrganizationsPermanentlyQueuedLicensesItem,
    OrganizationsPoe,
    OrganizationsPolicyObjectsItem,
    OrganizationsPowerSuppliesItem,
    OrganizationsPreview,
    OrganizationsPublic,
    OrganizationsRanging,
    OrganizationsRecipients,
    OrganizationsRecordsClientVpnConnectionsItem,
    OrganizationsRecordsNetwork,
    OrganizationsRegion,
    OrganizationsResult,
    OrganizationsRoaming,
    OrganizationsRootCertificate,
    OrganizationsRulesItem,
    OrganizationsSchedule,
    OrganizationsScope,
    OrganizationsSeats,
    OrganizationsSecret,
    OrganizationsSeveritiesItem,
    OrganizationsSeverityCountsItem,
    OrganizationsShippingPending,
    OrganizationsShippingShipmentsItem,
    OrganizationsSignalStat,
    OrganizationsSlotsItem,
    OrganizationsSoonestActivation,
    OrganizationsSourceGroup,
    OrganizationsSsidsItem,
    OrganizationsStaged,
    OrganizationsStatesActive,
    OrganizationsStatesExpiring,
    OrganizationsStatesUnused,
    OrganizationsStatesUnusedActive,
    OrganizationsStatus,
    OrganizationsStatuses,
    OrganizationsSubscriptionsCounts,
    OrganizationsSwapsDevices,
    OrganizationsSystemsManagerCounts,
    OrganizationsTagsItem,
    OrganizationsTimeSeriesItem,
    OrganizationsTotals,
    OrganizationsToVersion,
    OrganizationsTunnel,
    OrganizationsUpgrade,
    OrganizationsUplinksItem,
    OrganizationsUplinksItem2,
    OrganizationsUsage,
    OrganizationsUsage2,
    OrganizationsUsage3,
    OrganizationsUsage4,
    OrganizationsUsage5,
    OrganizationsUsageOverall,
    OrganizationsUsed,
    OrganizationsUsed2,
    OrganizationsUser,
    OrganizationsUtilization,
    PreviewOrganizationInventoryOrdersResponse,
    PreviewOrganizationInventoryOrdersResponseShipping,
    ReleaseFromOrganizationInventoryResponse,
    RenewOrganizationLicensesSeatsResponse,
    ReorderOrganizationDevicesPacketCaptureSchedulesOrderItem,
    ReorderOrganizationDevicesPacketCaptureSchedulesResponse,
    ReorderOrganizationDevicesPacketCaptureSchedulesResponseUpdatedPrioritiesItem,
    StopOrganizationDevicesPacketCaptureCaptureResponse,
    UpdateOrganizationActionBatchResponse,
    UpdateOrganizationAdaptivePolicyAclResponse,
    UpdateOrganizationAdaptivePolicyAclRulesItem,
    UpdateOrganizationAdaptivePolicyGroupPolicyObjectsItem,
    UpdateOrganizationAdaptivePolicyGroupResponse,
    UpdateOrganizationAdaptivePolicyPolicyAclsItem,
    UpdateOrganizationAdaptivePolicyPolicyDestinationGroup,
    UpdateOrganizationAdaptivePolicyPolicyResponse,
    UpdateOrganizationAdaptivePolicyPolicySourceGroup,
    UpdateOrganizationAdaptivePolicySettingsResponse,
    UpdateOrganizationAdminNetworksItem,
    UpdateOrganizationAdminResponse,
    UpdateOrganizationAdminTagsItem,
    UpdateOrganizationAlertsProfileAlertCondition,
    UpdateOrganizationAlertsProfileRecipients,
    UpdateOrganizationAlertsProfileResponse,
    UpdateOrganizationApi,
    UpdateOrganizationBrandingPoliciesPrioritiesResponse,
    UpdateOrganizationBrandingPolicyAdminSettings,
    UpdateOrganizationBrandingPolicyCustomLogo,
    UpdateOrganizationBrandingPolicyHelpSettings,
    UpdateOrganizationBrandingPolicyResponse,
    UpdateOrganizationConfigTemplateResponse,
    UpdateOrganizationDevicesPacketCaptureScheduleDevicesItem,
    UpdateOrganizationDevicesPacketCaptureScheduleResponse,
    UpdateOrganizationDevicesPacketCaptureScheduleSchedule,
    UpdateOrganizationEarlyAccessFeaturesOptInResponse,
    UpdateOrganizationLicenseResponse,
    UpdateOrganizationLoginSecurityApiAuthentication,
    UpdateOrganizationLoginSecurityResponse,
    UpdateOrganizationManagement,
    UpdateOrganizationPolicyObjectResponse,
    UpdateOrganizationPolicyObjectsGroupResponse,
    UpdateOrganizationResponse,
    UpdateOrganizationSamlIdpResponse,
    UpdateOrganizationSamlIdpResponseItem,
    UpdateOrganizationSamlResponse,
    UpdateOrganizationSamlRoleNetworksItem,
    UpdateOrganizationSamlRoleResponse,
    UpdateOrganizationSamlRoleTagsItem,
    UpdateOrganizationSamlSpInitiated,
    UpdateOrganizationSnmpResponse,
)
from meraki_client.schemas._sensor import (
    CreateDeviceSensorCommandResponse,
    CreateNetworkSensorAlertsProfileConditionsItem,
    CreateNetworkSensorAlertsProfileRecipients,
    CreateNetworkSensorAlertsProfileResponse,
    CreateNetworkSensorAlertsProfileSchedule,
    GetDeviceSensorCommandResponse,
    GetDeviceSensorCommandsResponse,
    GetDeviceSensorCommandsResponseItem,
    GetDeviceSensorRelationshipsResponse,
    GetDeviceSensorRelationshipsResponseLivestream,
    GetNetworkSensorAlertsCurrentOverviewByMetricResponse,
    GetNetworkSensorAlertsCurrentOverviewByMetricResponseCounts,
    GetNetworkSensorAlertsOverviewByMetricResponse,
    GetNetworkSensorAlertsOverviewByMetricResponseItem,
    GetNetworkSensorAlertsProfileResponse,
    GetNetworkSensorAlertsProfilesResponse,
    GetNetworkSensorAlertsProfilesResponseItem,
    GetNetworkSensorMqttBrokerResponse,
    GetNetworkSensorMqttBrokersResponse,
    GetNetworkSensorMqttBrokersResponseItem,
    GetNetworkSensorRelationshipsResponse,
    GetNetworkSensorRelationshipsResponseItem,
    GetOrganizationSensorGatewaysConnectionsLatestResponseItemsItem,
    GetOrganizationSensorReadingsHistoryResponse,
    GetOrganizationSensorReadingsHistoryResponseItem,
    GetOrganizationSensorReadingsLatestResponse,
    GetOrganizationSensorReadingsLatestResponseItem,
    SensorAmbient,
    SensorAmbient2,
    SensorApparentPower,
    SensorBattery,
    SensorButton,
    SensorCo2,
    SensorConditionsItem,
    SensorCountsNoise,
    SensorCreatedBy,
    SensorDevice,
    SensorDoor,
    SensorDoor2,
    SensorDownstreamPower,
    SensorFrequency,
    SensorHumidity,
    SensorHumidity2,
    SensorIndoorAirQuality,
    SensorIndoorAirQuality2,
    SensorLivestreamRelatedDevicesItem,
    SensorNetwork,
    SensorNoise,
    SensorNoise2,
    SensorPowerFactor,
    SensorReadingsItem,
    SensorRealPower,
    SensorRecipients,
    SensorRelationships,
    SensorRemoteLockoutSwitch,
    SensorSchedule,
    SensorSensor,
    SensorTemperature,
    SensorTemperature2,
    SensorThreshold,
    SensorTvoc,
    SensorUpstreamPower,
    SensorVoltage,
    SensorWater,
    SensorWater2,
    UpdateDeviceSensorRelationshipsLivestream,
    UpdateDeviceSensorRelationshipsLivestreamRelatedDevicesItem,
    UpdateDeviceSensorRelationshipsResponse,
    UpdateNetworkSensorAlertsProfileConditionsItem,
    UpdateNetworkSensorAlertsProfileRecipients,
    UpdateNetworkSensorAlertsProfileResponse,
    UpdateNetworkSensorAlertsProfileSchedule,
    UpdateNetworkSensorMqttBrokerResponse,
)
from meraki_client.schemas._sm import (
    CheckinNetworkSmDevicesResponse,
    CreateNetworkSmTargetGroupResponse,
    CreateOrganizationSmAdminsRoleResponse,
    GetNetworkSmDeviceCellularUsageHistoryResponse,
    GetNetworkSmDeviceCellularUsageHistoryResponseItem,
    GetNetworkSmDeviceCertsResponse,
    GetNetworkSmDeviceCertsResponseItem,
    GetNetworkSmDeviceConnectivityResponse,
    GetNetworkSmDeviceConnectivityResponseItem,
    GetNetworkSmDeviceDesktopLogsResponse,
    GetNetworkSmDeviceDesktopLogsResponseItem,
    GetNetworkSmDeviceDeviceCommandLogsResponse,
    GetNetworkSmDeviceDeviceCommandLogsResponseItem,
    GetNetworkSmDeviceDeviceProfilesResponse,
    GetNetworkSmDeviceDeviceProfilesResponseItem,
    GetNetworkSmDeviceNetworkAdaptersResponse,
    GetNetworkSmDeviceNetworkAdaptersResponseItem,
    GetNetworkSmDevicePerformanceHistoryResponse,
    GetNetworkSmDevicePerformanceHistoryResponseItem,
    GetNetworkSmDeviceRestrictionsResponse,
    GetNetworkSmDeviceRestrictionsResponseRestrictionsItem,
    GetNetworkSmDeviceSecurityCentersResponse,
    GetNetworkSmDeviceSecurityCentersResponseItem,
    GetNetworkSmDeviceSoftwaresResponse,
    GetNetworkSmDeviceSoftwaresResponseItem,
    GetNetworkSmDevicesResponse,
    GetNetworkSmDevicesResponseItem,
    GetNetworkSmDeviceWlanListsResponse,
    GetNetworkSmDeviceWlanListsResponseItem,
    GetNetworkSmProfilesResponse,
    GetNetworkSmProfilesResponseItem,
    GetNetworkSmTargetGroupResponse,
    GetNetworkSmTargetGroupsResponse,
    GetNetworkSmTargetGroupsResponseItem,
    GetNetworkSmTrustedAccessConfigsResponse,
    GetNetworkSmTrustedAccessConfigsResponseItem,
    GetNetworkSmUserAccessDevicesResponse,
    GetNetworkSmUserAccessDevicesResponseItem,
    GetNetworkSmUserDeviceProfilesResponse,
    GetNetworkSmUserDeviceProfilesResponseItem,
    GetNetworkSmUserSoftwaresResponse,
    GetNetworkSmUserSoftwaresResponseItem,
    GetNetworkSmUsersResponse,
    GetNetworkSmUsersResponseItem,
    GetOrganizationSmAdminsRoleResponse,
    GetOrganizationSmAdminsRolesResponseItemsItem,
    GetOrganizationSmApnsCertResponse,
    GetOrganizationSmSentryPoliciesAssignmentsByNetworkResponse,
    GetOrganizationSmSentryPoliciesAssignmentsByNetworkResponseItem,
    GetOrganizationSmVppAccountResponse,
    GetOrganizationSmVppAccountsResponse,
    GetOrganizationSmVppAccountsResponseItem,
    LockNetworkSmDevicesResponse,
    ModifyNetworkSmDevicesTagsResponse,
    ModifyNetworkSmDevicesTagsResponseItem,
    MoveNetworkSmDevicesResponse,
    RebootNetworkSmDevicesResponse,
    ShutdownNetworkSmDevicesResponse,
    SmC,
    SmDiskUsage,
    SmParsedToken,
    SmPoliciesItem,
    SmTrustedAccessConnectionsItem,
    UnenrollNetworkSmDeviceResponse,
    UpdateNetworkSmDevicesFieldsDeviceFields,
    UpdateNetworkSmDevicesFieldsResponse,
    UpdateNetworkSmDevicesFieldsResponseItem,
    UpdateNetworkSmTargetGroupResponse,
    UpdateOrganizationSmAdminsRoleResponse,
    UpdateOrganizationSmSentryPoliciesAssignmentsItemsItem,
    UpdateOrganizationSmSentryPoliciesAssignmentsItemsItemPoliciesItem,
    UpdateOrganizationSmSentryPoliciesAssignmentsResponse,
    UpdateOrganizationSmSentryPoliciesAssignmentsResponseItemsItem,
    WipeNetworkSmDevicesResponse,
)
from meraki_client.schemas._spaces import (
    GetOrganizationSpacesIntegrateStatusResponse,
    RemoveOrganizationSpacesIntegrationResponse,
)
from meraki_client.schemas._switch import (
    AddNetworkSwitchStackResponse,
    CloneOrganizationSwitchDevicesResponse,
    CreateDeviceSwitchRoutingInterfaceIpv6,
    CreateDeviceSwitchRoutingInterfaceOspfSettings,
    CreateDeviceSwitchRoutingInterfaceResponse,
    CreateDeviceSwitchRoutingInterfaceVrf,
    CreateDeviceSwitchRoutingStaticRouteResponse,
    CreateDeviceSwitchRoutingStaticRouteVrf,
    CreateNetworkSwitchAccessPolicyDot1x,
    CreateNetworkSwitchAccessPolicyRadius,
    CreateNetworkSwitchAccessPolicyRadiusAccountingServersItem,
    CreateNetworkSwitchAccessPolicyRadiusAuthentication,
    CreateNetworkSwitchAccessPolicyRadiusServersItem,
    CreateNetworkSwitchAccessPolicyResponse,
    CreateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerIpv4,
    CreateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerResponse,
    CreateNetworkSwitchLinkAggregationResponse,
    CreateNetworkSwitchLinkAggregationSwitchPortsItem,
    CreateNetworkSwitchLinkAggregationSwitchProfilePortsItem,
    CreateNetworkSwitchPortSchedulePortSchedule,
    CreateNetworkSwitchPortScheduleResponse,
    CreateNetworkSwitchQosRuleResponse,
    CreateNetworkSwitchRoutingMulticastRendezvousPointResponse,
    CreateNetworkSwitchRoutingMulticastRendezvousPointVrf,
    CreateNetworkSwitchStackResponse,
    CreateNetworkSwitchStackRoutingInterfaceIpv6,
    CreateNetworkSwitchStackRoutingInterfaceOspfSettings,
    CreateNetworkSwitchStackRoutingInterfaceResponse,
    CreateNetworkSwitchStackRoutingInterfaceVrf,
    CreateNetworkSwitchStackRoutingStaticRouteResponse,
    CreateNetworkSwitchStackRoutingStaticRouteVrf,
    CycleDeviceSwitchPortsResponse,
    GetDeviceSwitchPortResponse,
    GetDeviceSwitchPortsResponse,
    GetDeviceSwitchPortsResponseItem,
    GetDeviceSwitchPortsStatusesPacketsResponse,
    GetDeviceSwitchPortsStatusesPacketsResponseItem,
    GetDeviceSwitchPortsStatusesResponse,
    GetDeviceSwitchPortsStatusesResponseItem,
    GetDeviceSwitchRoutingInterfaceDhcpResponse,
    GetDeviceSwitchRoutingInterfaceDhcpResponseDhcpOptionsItem,
    GetDeviceSwitchRoutingInterfaceDhcpResponseFixedIpAssignmentsItem,
    GetDeviceSwitchRoutingInterfaceDhcpResponseReservedIpRangesItem,
    GetDeviceSwitchRoutingInterfaceResponse,
    GetDeviceSwitchRoutingInterfacesResponse,
    GetDeviceSwitchRoutingInterfacesResponseItem,
    GetDeviceSwitchRoutingStaticRouteResponse,
    GetDeviceSwitchRoutingStaticRoutesResponse,
    GetDeviceSwitchRoutingStaticRoutesResponseItem,
    GetDeviceSwitchWarmSpareResponse,
    GetNetworkSwitchAccessControlListsResponse,
    GetNetworkSwitchAccessControlListsResponseRulesItem,
    GetNetworkSwitchAccessPoliciesResponse,
    GetNetworkSwitchAccessPoliciesResponseItem,
    GetNetworkSwitchAccessPolicyResponse,
    GetNetworkSwitchAlternateManagementInterfaceResponse,
    GetNetworkSwitchAlternateManagementInterfaceResponseSwitchesItem,
    GetNetworkSwitchDhcpServerPolicyArpInspectionTrustedServersResponse,
    GetNetworkSwitchDhcpServerPolicyArpInspectionTrustedServersResponseItem,
    GetNetworkSwitchDhcpServerPolicyArpInspectionWarningsByDeviceResponse,
    GetNetworkSwitchDhcpServerPolicyArpInspectionWarningsByDeviceResponseItem,
    GetNetworkSwitchDhcpServerPolicyResponse,
    GetNetworkSwitchDhcpServerPolicyResponseAlerts,
    GetNetworkSwitchDhcpServerPolicyResponseArpInspection,
    GetNetworkSwitchDhcpV4ServersSeenResponse,
    GetNetworkSwitchDhcpV4ServersSeenResponseItem,
    GetNetworkSwitchDscpToCosMappingsResponse,
    GetNetworkSwitchDscpToCosMappingsResponseMappingsItem,
    GetNetworkSwitchLinkAggregationsResponse,
    GetNetworkSwitchLinkAggregationsResponseItem,
    GetNetworkSwitchMtuResponse,
    GetNetworkSwitchMtuResponseOverridesItem,
    GetNetworkSwitchPortSchedulesResponse,
    GetNetworkSwitchPortSchedulesResponseItem,
    GetNetworkSwitchQosRuleResponse,
    GetNetworkSwitchQosRulesOrderResponse,
    GetNetworkSwitchQosRulesResponse,
    GetNetworkSwitchQosRulesResponseItem,
    GetNetworkSwitchRoutingMulticastRendezvousPointResponse,
    GetNetworkSwitchRoutingMulticastRendezvousPointsResponse,
    GetNetworkSwitchRoutingMulticastRendezvousPointsResponseItem,
    GetNetworkSwitchRoutingMulticastResponse,
    GetNetworkSwitchRoutingMulticastResponseDefaultSettings,
    GetNetworkSwitchRoutingMulticastResponseOverridesItem,
    GetNetworkSwitchRoutingOspfResponse,
    GetNetworkSwitchRoutingOspfResponseAreasItem,
    GetNetworkSwitchRoutingOspfResponseMd5AuthenticationKey,
    GetNetworkSwitchRoutingOspfResponseV3,
    GetNetworkSwitchSettingsResponse,
    GetNetworkSwitchSettingsResponsePowerExceptionsItem,
    GetNetworkSwitchSettingsResponseUplinkSelection,
    GetNetworkSwitchStackResponse,
    GetNetworkSwitchStackRoutingInterfaceDhcpResponse,
    GetNetworkSwitchStackRoutingInterfaceResponse,
    GetNetworkSwitchStackRoutingInterfacesResponse,
    GetNetworkSwitchStackRoutingInterfacesResponseItem,
    GetNetworkSwitchStackRoutingStaticRouteResponse,
    GetNetworkSwitchStackRoutingStaticRoutesResponse,
    GetNetworkSwitchStackRoutingStaticRoutesResponseItem,
    GetNetworkSwitchStacksResponse,
    GetNetworkSwitchStacksResponseItem,
    GetNetworkSwitchStormControlResponse,
    GetNetworkSwitchStpResponse,
    GetNetworkSwitchStpResponseStpBridgePriorityItem,
    GetOrganizationConfigTemplateSwitchProfilePortResponse,
    GetOrganizationConfigTemplateSwitchProfilePortsResponse,
    GetOrganizationConfigTemplateSwitchProfilePortsResponseItem,
    GetOrganizationConfigTemplateSwitchProfilesResponse,
    GetOrganizationConfigTemplateSwitchProfilesResponseItem,
    GetOrganizationSummarySwitchPowerHistoryResponse,
    GetOrganizationSummarySwitchPowerHistoryResponseItem,
    GetOrganizationSwitchPortsBySwitchResponse,
    GetOrganizationSwitchPortsBySwitchResponsePortsItem,
    GetOrganizationSwitchPortsClientsOverviewByDeviceResponseItemsItem,
    GetOrganizationSwitchPortsOverviewResponse,
    GetOrganizationSwitchPortsOverviewResponseCounts,
    GetOrganizationSwitchPortsStatusesBySwitchResponseItemsItem,
    GetOrganizationSwitchPortsTopologyDiscoveryByDeviceResponseItemsItem,
    GetOrganizationSwitchPortsUsageHistoryByDeviceByIntervalResponseItemsItem,
    RemoveNetworkSwitchStackResponse,
    SwitchActive,
    SwitchAuthentication,
    SwitchBandwidth,
    SwitchByMedia,
    SwitchByMediaAndLinkSpeed,
    SwitchByStatus,
    SwitchCache,
    SwitchCdp,
    SwitchConfigOverrides,
    SwitchCounts,
    SwitchCounts2,
    SwitchCountsByStatus,
    SwitchCriticalAuth,
    SwitchData,
    SwitchDevice,
    SwitchDot1x,
    SwitchDot3az,
    SwitchDscp,
    SwitchEnergy,
    SwitchEthernet,
    SwitchFields,
    SwitchInactive,
    SwitchInterface,
    SwitchIntervalsItem,
    SwitchIp,
    SwitchIpv4,
    SwitchIpv6,
    SwitchIpv42,
    SwitchLastAck,
    SwitchLastPacket,
    SwitchLldp,
    SwitchMembersItem,
    SwitchMirror,
    SwitchModule,
    SwitchMonday,
    SwitchOptionsItem,
    SwitchOspfSettings,
    SwitchPacketsItem,
    SwitchPoe,
    SwitchPorts,
    SwitchPortSchedule,
    SwitchPortsItem,
    SwitchPortsItem2,
    SwitchPortsItem3,
    SwitchPortsItem4,
    SwitchProfile,
    SwitchRadius,
    SwitchRadiusServersItem,
    SwitchRj45,
    SwitchRj452,
    SwitchSchedule,
    SwitchSecurePort,
    SwitchSecurePort2,
    SwitchSeenByItem,
    SwitchSfp,
    SwitchSource,
    SwitchSpanningTree,
    SwitchSwitchPortsItem,
    SwitchTrafficInKbps,
    SwitchUdp,
    SwitchUsage,
    SwitchUsage2,
    SwitchUsage3,
    SwitchUsageInKb,
    SwitchVrf,
    SwitchVrf2,
    UpdateDeviceSwitchPortDot3az,
    UpdateDeviceSwitchPortHighSpeed,
    UpdateDeviceSwitchPortProfile,
    UpdateDeviceSwitchPortResponse,
    UpdateDeviceSwitchRoutingInterfaceDhcpDhcpOptionsItem,
    UpdateDeviceSwitchRoutingInterfaceDhcpFixedIpAssignmentsItem,
    UpdateDeviceSwitchRoutingInterfaceDhcpReservedIpRangesItem,
    UpdateDeviceSwitchRoutingInterfaceDhcpResponse,
    UpdateDeviceSwitchRoutingInterfaceIpv6,
    UpdateDeviceSwitchRoutingInterfaceOspfSettings,
    UpdateDeviceSwitchRoutingInterfaceResponse,
    UpdateDeviceSwitchRoutingInterfaceVrf,
    UpdateDeviceSwitchRoutingStaticRouteResponse,
    UpdateDeviceSwitchRoutingStaticRouteVrf,
    UpdateDeviceSwitchWarmSpareResponse,
    UpdateNetworkSwitchAccessControlListsResponse,
    UpdateNetworkSwitchAccessControlListsRulesItem,
    UpdateNetworkSwitchAccessPolicyDot1x,
    UpdateNetworkSwitchAccessPolicyRadius,
    UpdateNetworkSwitchAccessPolicyRadiusAccountingServersItem,
    UpdateNetworkSwitchAccessPolicyRadiusServersItem,
    UpdateNetworkSwitchAccessPolicyResponse,
    UpdateNetworkSwitchAlternateManagementInterfaceResponse,
    UpdateNetworkSwitchAlternateManagementInterfaceSwitchesItem,
    UpdateNetworkSwitchDhcpServerPolicyAlerts,
    UpdateNetworkSwitchDhcpServerPolicyArpInspection,
    UpdateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerIpv4,
    UpdateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerResponse,
    UpdateNetworkSwitchDhcpServerPolicyResponse,
    UpdateNetworkSwitchDscpToCosMappingsMappingsItem,
    UpdateNetworkSwitchDscpToCosMappingsResponse,
    UpdateNetworkSwitchLinkAggregationResponse,
    UpdateNetworkSwitchLinkAggregationSwitchPortsItem,
    UpdateNetworkSwitchLinkAggregationSwitchProfilePortsItem,
    UpdateNetworkSwitchMtuOverridesItem,
    UpdateNetworkSwitchMtuResponse,
    UpdateNetworkSwitchPortSchedulePortSchedule,
    UpdateNetworkSwitchPortScheduleResponse,
    UpdateNetworkSwitchQosRuleResponse,
    UpdateNetworkSwitchQosRulesOrderResponse,
    UpdateNetworkSwitchRoutingMulticastDefaultSettings,
    UpdateNetworkSwitchRoutingMulticastOverridesItem,
    UpdateNetworkSwitchRoutingMulticastRendezvousPointResponse,
    UpdateNetworkSwitchRoutingMulticastRendezvousPointVrf,
    UpdateNetworkSwitchRoutingMulticastResponse,
    UpdateNetworkSwitchRoutingOspfAreasItem,
    UpdateNetworkSwitchRoutingOspfMd5AuthenticationKey,
    UpdateNetworkSwitchRoutingOspfResponse,
    UpdateNetworkSwitchRoutingOspfV3,
    UpdateNetworkSwitchRoutingOspfV3AreasItem,
    UpdateNetworkSwitchSettingsMacBlocklist,
    UpdateNetworkSwitchSettingsPowerExceptionsItem,
    UpdateNetworkSwitchSettingsResponse,
    UpdateNetworkSwitchSettingsUplinkClientSampling,
    UpdateNetworkSwitchSettingsUplinkSelection,
    UpdateNetworkSwitchSettingsUplinkSelectionFailback,
    UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpOptionsItem,
    UpdateNetworkSwitchStackRoutingInterfaceDhcpFixedIpAssignmentsItem,
    UpdateNetworkSwitchStackRoutingInterfaceDhcpReservedIpRangesItem,
    UpdateNetworkSwitchStackRoutingInterfaceDhcpResponse,
    UpdateNetworkSwitchStackRoutingInterfaceIpv6,
    UpdateNetworkSwitchStackRoutingInterfaceOspfSettings,
    UpdateNetworkSwitchStackRoutingInterfaceResponse,
    UpdateNetworkSwitchStackRoutingInterfaceVrf,
    UpdateNetworkSwitchStackRoutingStaticRouteResponse,
    UpdateNetworkSwitchStackRoutingStaticRouteVrf,
    UpdateNetworkSwitchStormControlResponse,
    UpdateNetworkSwitchStpResponse,
    UpdateNetworkSwitchStpStpBridgePriorityItem,
    UpdateOrganizationConfigTemplateSwitchProfilePortDot3az,
    UpdateOrganizationConfigTemplateSwitchProfilePortHighSpeed,
    UpdateOrganizationConfigTemplateSwitchProfilePortProfile,
    UpdateOrganizationConfigTemplateSwitchProfilePortResponse,
)
from meraki_client.schemas._wireless import (
    AssignNetworkWirelessEthernetPortsProfilesResponse,
    CreateDeviceWirelessZigbeeEnrollmentResponse,
    CreateDeviceWirelessZigbeeEnrollmentResponseRequest,
    CreateNetworkWirelessAirMarshalRuleMatch,
    CreateNetworkWirelessAirMarshalRuleResponse,
    CreateNetworkWirelessAirMarshalRuleResponseMatch,
    CreateNetworkWirelessEthernetPortsProfilePortsItem,
    CreateNetworkWirelessEthernetPortsProfileResponse,
    CreateNetworkWirelessEthernetPortsProfileUsbPortsItem,
    CreateNetworkWirelessRfProfileApBandSettings,
    CreateNetworkWirelessRfProfileApBandSettingsBands,
    CreateNetworkWirelessRfProfileFiveGhzSettings,
    CreateNetworkWirelessRfProfileFlexRadios,
    CreateNetworkWirelessRfProfileFlexRadiosByModelItem,
    CreateNetworkWirelessRfProfilePerSsidSettings,
    CreateNetworkWirelessRfProfilePerSsidSettings0,
    CreateNetworkWirelessRfProfileResponse,
    CreateNetworkWirelessRfProfileSixGhzSettings,
    CreateNetworkWirelessRfProfileTransmission,
    CreateNetworkWirelessRfProfileTwoFourGhzSettings,
    CreateNetworkWirelessSsidIdentityPskResponse,
    CreateOrganizationWirelessDevicesRadsecCertificatesAuthorityResponse,
    CreateOrganizationWirelessLocationScanningReceiverNetwork,
    CreateOrganizationWirelessLocationScanningReceiverRadio,
    CreateOrganizationWirelessLocationScanningReceiverResponse,
    CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryClient,
    CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryNetwork,
    CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryResponse,
    CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntrySsid,
    CreateOrganizationWirelessZigbeeDisenrollmentResponse,
    CreateOrganizationWirelessZigbeeDisenrollmentResponseRequest,
    GetDeviceWirelessBluetoothSettingsResponse,
    GetDeviceWirelessConnectionStatsResponse,
    GetDeviceWirelessConnectionStatsResponseConnectionStats,
    GetDeviceWirelessElectronicShelfLabelResponse,
    GetDeviceWirelessRadioSettingsResponse,
    GetDeviceWirelessRadioSettingsResponseFiveGhzSettings,
    GetDeviceWirelessRadioSettingsResponseTwoFourGhzSettings,
    GetDeviceWirelessStatusResponse,
    GetDeviceWirelessStatusResponseBasicServiceSetsItem,
    GetDeviceWirelessZigbeeEnrollmentResponse,
    GetDeviceWirelessZigbeeEnrollmentResponseDoorLocksItem,
    GetNetworkWirelessAirMarshalResponse,
    GetNetworkWirelessAirMarshalResponseItem,
    GetNetworkWirelessBillingResponse,
    GetNetworkWirelessBillingResponsePlansItem,
    GetNetworkWirelessBluetoothSettingsResponse,
    GetNetworkWirelessChannelUtilizationHistoryResponse,
    GetNetworkWirelessChannelUtilizationHistoryResponseItem,
    GetNetworkWirelessClientConnectionStatsResponse,
    GetNetworkWirelessClientConnectionStatsResponseConnectionStats,
    GetNetworkWirelessClientConnectivityEventsResponse,
    GetNetworkWirelessClientConnectivityEventsResponseItem,
    GetNetworkWirelessClientCountHistoryResponse,
    GetNetworkWirelessClientCountHistoryResponseItem,
    GetNetworkWirelessClientLatencyHistoryResponse,
    GetNetworkWirelessClientLatencyHistoryResponseItem,
    GetNetworkWirelessClientsConnectionStatsResponse,
    GetNetworkWirelessClientsLatencyStatsResponse,
    GetNetworkWirelessConnectionStatsResponse,
    GetNetworkWirelessDataRateHistoryResponse,
    GetNetworkWirelessDataRateHistoryResponseItem,
    GetNetworkWirelessDevicesConnectionStatsResponse,
    GetNetworkWirelessDevicesConnectionStatsResponseItem,
    GetNetworkWirelessDevicesLatencyStatsResponse,
    GetNetworkWirelessElectronicShelfLabelConfiguredDevicesResponse,
    GetNetworkWirelessElectronicShelfLabelConfiguredDevicesResponseItem,
    GetNetworkWirelessElectronicShelfLabelResponse,
    GetNetworkWirelessEthernetPortsProfileResponse,
    GetNetworkWirelessEthernetPortsProfilesResponse,
    GetNetworkWirelessEthernetPortsProfilesResponseItem,
    GetNetworkWirelessFailedConnectionsResponse,
    GetNetworkWirelessFailedConnectionsResponseItem,
    GetNetworkWirelessLatencyHistoryResponse,
    GetNetworkWirelessLatencyHistoryResponseItem,
    GetNetworkWirelessMeshStatusesResponse,
    GetNetworkWirelessMeshStatusesResponseItem,
    GetNetworkWirelessRfProfileResponse,
    GetNetworkWirelessRfProfilesResponse,
    GetNetworkWirelessRfProfilesResponseApBandSettings,
    GetNetworkWirelessRfProfilesResponseFiveGhzSettings,
    GetNetworkWirelessRfProfilesResponsePerSsidSettings,
    GetNetworkWirelessRfProfilesResponseTwoFourGhzSettings,
    GetNetworkWirelessSettingsResponse,
    GetNetworkWirelessSettingsResponseNamedVlans,
    GetNetworkWirelessSettingsResponseRegulatoryDomain,
    GetNetworkWirelessSignalQualityHistoryResponse,
    GetNetworkWirelessSignalQualityHistoryResponseItem,
    GetNetworkWirelessSsidBonjourForwardingResponse,
    GetNetworkWirelessSsidBonjourForwardingResponseRulesItem,
    GetNetworkWirelessSsidEapOverrideResponse,
    GetNetworkWirelessSsidEapOverrideResponseEapolKey,
    GetNetworkWirelessSsidEapOverrideResponseIdentity,
    GetNetworkWirelessSsidFirewallL3FirewallRulesResponse,
    GetNetworkWirelessSsidFirewallL3FirewallRulesResponseRulesItem,
    GetNetworkWirelessSsidFirewallL7FirewallRulesResponse,
    GetNetworkWirelessSsidFirewallL7FirewallRulesResponseRulesItem,
    GetNetworkWirelessSsidHotspot20Response,
    GetNetworkWirelessSsidHotspot20ResponseMccMncsItem,
    GetNetworkWirelessSsidHotspot20ResponseNaiRealmsItem,
    GetNetworkWirelessSsidHotspot20ResponseOperator,
    GetNetworkWirelessSsidHotspot20ResponseVenue,
    GetNetworkWirelessSsidIdentityPskResponse,
    GetNetworkWirelessSsidIdentityPsksResponse,
    GetNetworkWirelessSsidIdentityPsksResponseItem,
    GetNetworkWirelessSsidResponse,
    GetNetworkWirelessSsidSchedulesResponse,
    GetNetworkWirelessSsidSchedulesResponseRangesInSecondsItem,
    GetNetworkWirelessSsidSchedulesResponseRangesItem,
    GetNetworkWirelessSsidSplashSettingsResponse,
    GetNetworkWirelessSsidSplashSettingsResponseBilling,
    GetNetworkWirelessSsidSplashSettingsResponseGuestSponsorship,
    GetNetworkWirelessSsidSplashSettingsResponseSelfRegistration,
    GetNetworkWirelessSsidSplashSettingsResponseSentryEnrollment,
    GetNetworkWirelessSsidSplashSettingsResponseSplashLogo,
    GetNetworkWirelessSsidsResponse,
    GetNetworkWirelessSsidsResponseItem,
    GetNetworkWirelessSsidTrafficShapingRulesResponse,
    GetNetworkWirelessSsidTrafficShapingRulesResponseRulesItem,
    GetNetworkWirelessUsageHistoryResponse,
    GetNetworkWirelessUsageHistoryResponseItem,
    GetOrganizationWirelessAirMarshalRulesResponseItemsItem,
    GetOrganizationWirelessAirMarshalSettingsByNetworkResponseItemsItem,
    GetOrganizationWirelessClientsOverviewByDeviceResponseItemsItem,
    GetOrganizationWirelessDevicesChannelUtilizationByDeviceResponse,
    GetOrganizationWirelessDevicesChannelUtilizationByDeviceResponseItem,
    GetOrganizationWirelessDevicesChannelUtilizationByNetworkResponse,
    GetOrganizationWirelessDevicesChannelUtilizationByNetworkResponseItem,
    GetOrganizationWirelessDevicesChannelUtilizationHistoryByDeviceByIntervalResponse,
    GetOrganizationWirelessDevicesChannelUtilizationHistoryByDeviceByIntervalResponseItem,
    GetOrganizationWirelessDevicesChannelUtilizationHistoryByNetworkByIntervalResponse,
    GetOrganizationWirelessDevicesChannelUtilizationHistoryByNetworkByIntervalResponseItem,
    GetOrganizationWirelessDevicesEthernetStatusesResponse,
    GetOrganizationWirelessDevicesEthernetStatusesResponseItem,
    GetOrganizationWirelessDevicesPacketLossByClientResponse,
    GetOrganizationWirelessDevicesPacketLossByClientResponseItem,
    GetOrganizationWirelessDevicesPacketLossByDeviceResponse,
    GetOrganizationWirelessDevicesPacketLossByDeviceResponseItem,
    GetOrganizationWirelessDevicesPacketLossByNetworkResponse,
    GetOrganizationWirelessDevicesPacketLossByNetworkResponseItem,
    GetOrganizationWirelessDevicesPowerModeHistoryResponseItemsItem,
    GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesCrlsDeltasResponseItemsItem,
    GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesCrlsResponseItemsItem,
    GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponse,
    GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponseItem,
    GetOrganizationWirelessDevicesSystemCpuLoadHistoryResponseItemsItem,
    GetOrganizationWirelessDevicesWirelessControllersByDeviceResponseItemsItem,
    GetOrganizationWirelessLocationScanningByNetworkResponseItemsItem,
    GetOrganizationWirelessLocationScanningReceiversResponseItemsItem,
    GetOrganizationWirelessMqttSettingsResponseItemsItem,
    GetOrganizationWirelessRadioRrmByNetworkResponseItemsItem,
    GetOrganizationWirelessRfProfilesAssignmentsByDeviceResponse,
    GetOrganizationWirelessRfProfilesAssignmentsByDeviceResponseItem,
    GetOrganizationWirelessSsidsFirewallIsolationAllowlistEntriesResponseItemsItem,
    GetOrganizationWirelessSsidsOpenRoamingByNetworkResponseItemsItem,
    GetOrganizationWirelessSsidsStatusesByDeviceResponseItemsItem,
    GetOrganizationWirelessZigbeeByNetworkResponse,
    GetOrganizationWirelessZigbeeByNetworkResponseItem,
    GetOrganizationWirelessZigbeeDevicesResponse,
    GetOrganizationWirelessZigbeeDevicesResponseItem,
    GetOrganizationWirelessZigbeeDisenrollmentResponse,
    GetOrganizationWirelessZigbeeDisenrollmentResponseDoorLocksItem,
    GetOrganizationWirelessZigbeeDoorLocksResponse,
    GetOrganizationWirelessZigbeeDoorLocksResponseItem,
    RecalculateOrganizationWirelessRadioAutoRfChannelsResponse,
    SetNetworkWirelessEthernetPortsProfilesDefaultResponse,
    UpdateDeviceWirelessAlternateManagementInterfaceIpv6AddressesItem,
    UpdateDeviceWirelessAlternateManagementInterfaceIpv6Response,
    UpdateDeviceWirelessAlternateManagementInterfaceIpv6ResponseAddressesItem,
    UpdateDeviceWirelessBluetoothSettingsResponse,
    UpdateDeviceWirelessElectronicShelfLabelResponse,
    UpdateDeviceWirelessRadioSettingsFiveGhzSettings,
    UpdateDeviceWirelessRadioSettingsResponse,
    UpdateDeviceWirelessRadioSettingsTwoFourGhzSettings,
    UpdateNetworkWirelessAirMarshalRuleMatch,
    UpdateNetworkWirelessAirMarshalRuleResponse,
    UpdateNetworkWirelessAirMarshalSettingsResponse,
    UpdateNetworkWirelessAlternateManagementInterfaceAccessPointsItem,
    UpdateNetworkWirelessBillingPlansItem,
    UpdateNetworkWirelessBillingResponse,
    UpdateNetworkWirelessBluetoothSettingsResponse,
    UpdateNetworkWirelessElectronicShelfLabelResponse,
    UpdateNetworkWirelessEthernetPortsProfilePortsItem,
    UpdateNetworkWirelessEthernetPortsProfileResponse,
    UpdateNetworkWirelessEthernetPortsProfileUsbPortsItem,
    UpdateNetworkWirelessLocationScanningApi,
    UpdateNetworkWirelessLocationScanningResponse,
    UpdateNetworkWirelessLocationScanningResponseApi,
    UpdateNetworkWirelessRadioRrmAi,
    UpdateNetworkWirelessRadioRrmBusyHour,
    UpdateNetworkWirelessRadioRrmBusyHourSchedule,
    UpdateNetworkWirelessRadioRrmChannel,
    UpdateNetworkWirelessRadioRrmFra,
    UpdateNetworkWirelessRadioRrmResponse,
    UpdateNetworkWirelessRadioRrmResponseAi,
    UpdateNetworkWirelessRadioRrmResponseBusyHour,
    UpdateNetworkWirelessRadioRrmResponseChannel,
    UpdateNetworkWirelessRfProfileApBandSettings,
    UpdateNetworkWirelessRfProfileFiveGhzSettings,
    UpdateNetworkWirelessRfProfileFlexRadios,
    UpdateNetworkWirelessRfProfilePerSsidSettings,
    UpdateNetworkWirelessRfProfileResponse,
    UpdateNetworkWirelessRfProfileSixGhzSettings,
    UpdateNetworkWirelessRfProfileTransmission,
    UpdateNetworkWirelessRfProfileTwoFourGhzSettings,
    UpdateNetworkWirelessSettingsMulticastToUnicastConversion,
    UpdateNetworkWirelessSettingsNamedVlans,
    UpdateNetworkWirelessSettingsResponse,
    UpdateNetworkWirelessSsidActiveDirectory,
    UpdateNetworkWirelessSsidActiveDirectoryCredentials,
    UpdateNetworkWirelessSsidActiveDirectoryServersItem,
    UpdateNetworkWirelessSsidApTagsAndVlanIdsItem,
    UpdateNetworkWirelessSsidBonjourForwardingException,
    UpdateNetworkWirelessSsidBonjourForwardingResponse,
    UpdateNetworkWirelessSsidBonjourForwardingRulesItem,
    UpdateNetworkWirelessSsidDeviceTypeGroupPoliciesDeviceTypePoliciesItem,
    UpdateNetworkWirelessSsidDnsRewrite,
    UpdateNetworkWirelessSsidDot11r,
    UpdateNetworkWirelessSsidDot11w,
    UpdateNetworkWirelessSsidEapOverrideEapolKey,
    UpdateNetworkWirelessSsidEapOverrideIdentity,
    UpdateNetworkWirelessSsidEapOverrideResponse,
    UpdateNetworkWirelessSsidFirewallL3FirewallRulesResponse,
    UpdateNetworkWirelessSsidFirewallL3FirewallRulesRulesItem,
    UpdateNetworkWirelessSsidFirewallL7FirewallRulesResponse,
    UpdateNetworkWirelessSsidFirewallL7FirewallRulesRulesItem,
    UpdateNetworkWirelessSsidGre,
    UpdateNetworkWirelessSsidGreConcentrator,
    UpdateNetworkWirelessSsidHotspot20MccMncsItem,
    UpdateNetworkWirelessSsidHotspot20NaiRealmsItem,
    UpdateNetworkWirelessSsidHotspot20Operator,
    UpdateNetworkWirelessSsidHotspot20Response,
    UpdateNetworkWirelessSsidHotspot20Venue,
    UpdateNetworkWirelessSsidIdentityPskResponse,
    UpdateNetworkWirelessSsidLdap,
    UpdateNetworkWirelessSsidLdapCredentials,
    UpdateNetworkWirelessSsidLdapServersItem,
    UpdateNetworkWirelessSsidLocalAuthFallback,
    UpdateNetworkWirelessSsidLocalRadius,
    UpdateNetworkWirelessSsidLocalRadiusCertificateAuthentication,
    UpdateNetworkWirelessSsidNamedVlans,
    UpdateNetworkWirelessSsidNamedVlansRadius,
    UpdateNetworkWirelessSsidNamedVlansTagging,
    UpdateNetworkWirelessSsidOauth,
    UpdateNetworkWirelessSsidOpenRoamingResponse,
    UpdateNetworkWirelessSsidRadiusAccountingServersItem,
    UpdateNetworkWirelessSsidRadiusRadsec,
    UpdateNetworkWirelessSsidRadiusRadsecTlsTunnel,
    UpdateNetworkWirelessSsidRadiusServersItem,
    UpdateNetworkWirelessSsidResponse,
    UpdateNetworkWirelessSsidSchedulesRangesInSecondsItem,
    UpdateNetworkWirelessSsidSchedulesRangesItem,
    UpdateNetworkWirelessSsidSchedulesResponse,
    UpdateNetworkWirelessSsidSpeedBurst,
    UpdateNetworkWirelessSsidSplashSettingsBilling,
    UpdateNetworkWirelessSsidSplashSettingsGuestSponsorship,
    UpdateNetworkWirelessSsidSplashSettingsResponse,
    UpdateNetworkWirelessSsidSplashSettingsSelfRegistration,
    UpdateNetworkWirelessSsidSplashSettingsSentryEnrollment,
    UpdateNetworkWirelessSsidSplashSettingsSentryEnrollmentSystemsManagerNetwork,
    UpdateNetworkWirelessSsidSplashSettingsSplashImage,
    UpdateNetworkWirelessSsidSplashSettingsSplashLogo,
    UpdateNetworkWirelessSsidSplashSettingsSplashLogoImage,
    UpdateNetworkWirelessSsidSplashSettingsSplashPrepaidFront,
    UpdateNetworkWirelessSsidTrafficShapingRulesResponse,
    UpdateNetworkWirelessSsidTrafficShapingRulesRulesItem,
    UpdateNetworkWirelessSsidVpnConcentrator,
    UpdateNetworkWirelessSsidVpnFailover,
    UpdateNetworkWirelessSsidVpnSplitTunnel,
    UpdateNetworkWirelessSsidVpnSplitTunnelRulesItem,
    UpdateNetworkWirelessZigbeeDefaults,
    UpdateNetworkWirelessZigbeeIotController,
    UpdateNetworkWirelessZigbeeLockManagement,
    UpdateNetworkWirelessZigbeeResponse,
    UpdateNetworkWirelessZigbeeResponseDefaults,
    UpdateNetworkWirelessZigbeeResponseIotController,
    UpdateNetworkWirelessZigbeeResponseLockManagement,
    UpdateOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponse,
    UpdateOrganizationWirelessLocationScanningReceiverRadio,
    UpdateOrganizationWirelessLocationScanningReceiverResponse,
    UpdateOrganizationWirelessMqttSettingsBle,
    UpdateOrganizationWirelessMqttSettingsMqtt,
    UpdateOrganizationWirelessMqttSettingsNetwork,
    UpdateOrganizationWirelessMqttSettingsResponse,
    UpdateOrganizationWirelessMqttSettingsWifi,
    UpdateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryClient,
    UpdateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryResponse,
    UpdateOrganizationWirelessZigbeeDeviceResponse,
    UpdateOrganizationWirelessZigbeeDoorLockResponse,
    WirelessAc,
    WirelessAddressesNameservers,
    WirelessAggregation,
    WirelessAllowLists,
    WirelessAllowLists2,
    WirelessApBandSettingsBands,
    WirelessApiValidator,
    WirelessAuthenticationTypes,
    WirelessAutomatic,
    WirelessBackgroundTraffic,
    WirelessBasicServiceSetsItem,
    WirelessBillingFreeAccess,
    WirelessBle,
    WirelessBssidsItem,
    WirelessBusyHourMinimizeChanges,
    WirelessBusyHourSchedule,
    WirelessByApTagsItem,
    WirelessByBandItem,
    WirelessByStatus,
    WirelessByStatus2,
    WirelessClient,
    WirelessClient2,
    WirelessClientRootCaCertificate,
    WirelessCounts,
    WirelessCounts2,
    WirelessDetailsItem,
    WirelessDetectedByItem,
    WirelessDevice,
    WirelessDoorLocks,
    WirelessDoorLocksGateway,
    WirelessDoorLocksNetwork,
    WirelessDownstream,
    WirelessEventsItem,
    WirelessFlush,
    WirelessGateway,
    WirelessGuestVlan,
    WirelessHysteresis,
    WirelessLatencyBinsByCategory,
    WirelessLatestMeshPerformance,
    WirelessLinkNegotiation,
    WirelessMqtt,
    WirelessNaiRealmsMethodsItem,
    WirelessNamedVlansPoolDhcpMonitoring,
    WirelessNetwork,
    WirelessNetwork2,
    WirelessOpenRoaming,
    WirelessPerSsidSettings0,
    WirelessPlansBandwidthLimits,
    WirelessPoe,
    WirelessPortsItem,
    WirelessPortsItem2,
    WirelessPower,
    WirelessPublishing,
    WirelessRadio,
    WirelessRadio2,
    WirelessRadiusServersItem,
    WirelessRfProfile,
    WirelessRulesDefinitionsItem,
    WirelessRulesPerClientBandwidthLimits,
    WirelessSentryEnrollmentSystemsManagerNetwork,
    WirelessSeriesItem,
    WirelessSsid,
    WirelessSsid2,
    WirelessSsidItem,
    WirelessTagsItem,
    WirelessUsbPortsItem,
    WirelessWifi,
    WirelessWifi2,
)
from meraki_client.schemas._wireless_controller import (
    GetOrganizationWirelessControllerAvailabilitiesChangeHistoryResponseItemsItem,
    GetOrganizationWirelessControllerClientsOverviewHistoryByDeviceByIntervalResponseItemsItem,
    GetOrganizationWirelessControllerConnectionsResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL2ByDeviceResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL2StatusesChangeHistoryByDeviceResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL2UsageHistoryByIntervalResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL3ByDeviceResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL3StatusesChangeHistoryByDeviceResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesL3UsageHistoryByIntervalResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesPacketsOverviewByDeviceResponseItemsItem,
    GetOrganizationWirelessControllerDevicesInterfacesUsageHistoryByIntervalResponseItemsItem,
    GetOrganizationWirelessControllerDevicesRedundancyFailoverHistoryResponse,
    GetOrganizationWirelessControllerDevicesRedundancyFailoverHistoryResponseItem,
    GetOrganizationWirelessControllerDevicesRedundancyStatusesResponseItemsItem,
    GetOrganizationWirelessControllerDevicesSystemUtilizationHistoryByIntervalResponseItemsItem,
    GetOrganizationWirelessControllerOverviewByDeviceResponseItemsItem,
    WirelessControllerAddressesItem,
    WirelessControllerAddressesItem2,
    WirelessControllerAverage,
    WirelessControllerByCoreItem,
    WirelessControllerByInterfaceItem,
    WirelessControllerByStatus,
    WirelessControllerByStatus2,
    WirelessControllerChangesItem,
    WirelessControllerChangesItem2,
    WirelessControllerChannelGroup,
    WirelessControllerConnections,
    WirelessControllerController,
    WirelessControllerCounts,
    WirelessControllerCounts2,
    WirelessControllerCounts3,
    WirelessControllerFailed,
    WirelessControllerFailover,
    WirelessControllerFirmware,
    WirelessControllerInterfacesItem,
    WirelessControllerInterfacesItem2,
    WirelessControllerInterfacesItem3,
    WirelessControllerInterfacesItem4,
    WirelessControllerIntervalsItem,
    WirelessControllerIntervalsItem2,
    WirelessControllerLast,
    WirelessControllerManagement,
    WirelessControllerModule,
    WirelessControllerNetwork,
    WirelessControllerNetwork2,
    WirelessControllerOverall,
    WirelessControllerRate,
    WirelessControllerReadingsItem,
    WirelessControllerReadingsItem2,
    WirelessControllerReadingsItem3,
    WirelessControllerRedundancy,
    WirelessControllerUsage,
    WirelessControllerVersion,
    WirelessControllerVrf,
)

__all__ = [
    "AddNetworkSwitchStackResponse",
    "AdministeredAuthenticationApi",
    "AdministeredAuthenticationTwoFactor",
    "AdministeredKey",
    "Appliance1",
    "ApplianceApplicationCategoriesItem",
    "ApplianceApplicationsItem",
    "ApplianceAssignedFiveGhzSettings",
    "ApplianceAssignedPerSsidSettings",
    "ApplianceAssignedTwoFourGhzSettings",
    "ApplianceAuthentication",
    "ApplianceAuthentication2",
    "ApplianceBandwidthLimits",
    "ApplianceByInterfaceItem",
    "ApplianceByUplinkItem",
    "ApplianceCountsByStatus",
    "ApplianceDestination",
    "ApplianceDestination2",
    "ApplianceDestination3",
    "ApplianceDhcpOptionsItem",
    "ApplianceExportedSubnetsItem",
    "ApplianceFailover",
    "ApplianceFailoverAndFailbackImmediate",
    "ApplianceHighAvailability",
    "ApplianceInterfacesWan1",
    "ApplianceIpsec",
    "ApplianceIpv4",
    "ApplianceIpv6PrefixAssignmentsItem",
    "ApplianceItems",
    "ApplianceJitterSummariesItem",
    "ApplianceLatencySummariesItem",
    "ApplianceLossPercentageSummariesItem",
    "ApplianceMerakiVpnPeersItem",
    "ApplianceMerakiVpnPeersItem2",
    "ApplianceMetaCounts",
    "ApplianceMosSummariesItem",
    "ApplianceNameservers",
    "ApplianceNeighborsAuthentication",
    "ApplianceNeighborsIpv6",
    "ApplianceNetwork",
    "ApplianceOrigin",
    "ApplianceOrigin2",
    "ApplianceOrigin3",
    "AppliancePeersEbgpNeighbor",
    "AppliancePeersGroup",
    "AppliancePeersIpsecPolicies",
    "AppliancePeersNetwork",
    "AppliancePerformanceClass",
    "AppliancePerformanceClass2",
    "AppliancePppoe",
    "AppliancePppoe2",
    "ApplianceRadiusServersItem",
    "ApplianceReservedIpRangesItem",
    "ApplianceSource",
    "ApplianceSource2",
    "ApplianceSubnetNat",
    "ApplianceSubnetsNat",
    "ApplianceSvis",
    "ApplianceThirdPartyVpnPeersItem",
    "ApplianceTrafficFiltersItem",
    "ApplianceTrafficFiltersItem2",
    "ApplianceTrafficFiltersItem3",
    "ApplianceTrafficFiltersItem4",
    "ApplianceUplinksItem",
    "ApplianceUplinksItem2",
    "ApplianceUsageSummary",
    "ApplianceValue",
    "ApplianceValue2",
    "ApplianceValue3",
    "ApplianceVlanTagging",
    "ApplianceVpnTrafficUplinkPreferencesItem",
    "ApplianceWanTrafficUplinkPreferencesItem",
    "ApplianceWanTrafficUplinkPreferencesItem2",
    "AssignNetworkWirelessEthernetPortsProfilesResponse",
    "AssignOrganizationLicensesSeatsResponse",
    "AssignOrganizationLicensesSeatsResponseResultingLicensesItem",
    "BatchNetworkFloorPlansAutoLocateJobsJobsItem",
    "BatchNetworkFloorPlansAutoLocateJobsResponse",
    "BatchNetworkFloorPlansAutoLocateJobsResponseJobsItem",
    "BatchNetworkFloorPlansDevicesUpdateAssignmentsItem",
    "BatchNetworkFloorPlansDevicesUpdateResponse",
    "BindAdministeredLicensingSubscriptionSubscriptionResponse",
    "BindAdministeredLicensingSubscriptionSubscriptionResponseNetworksItem",
    "BindNetworkResponse",
    "BlinkDeviceLedsResponse",
    "BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateItemsItem",
    "BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateResponse",
    "BulkOrganizationApplianceDnsLocalProfilesAssignmentsCreateResponseItemsItem",
    "BulkOrganizationDevicesPacketCaptureCapturesCreateAdvanced",
    "BulkOrganizationDevicesPacketCaptureCapturesCreateDevicesItem",
    "BulkOrganizationDevicesPacketCaptureCapturesCreateResponse",
    "BulkOrganizationDevicesPacketCaptureCapturesCreateResponseItemsItem",
    "BulkUpdateOrganizationDevicesDetailsDetailsItem",
    "BulkUpdateOrganizationDevicesDetailsResponse",
    "CameraAppliedOnDevicesItem",
    "CameraAppliedOrgWideItem",
    "CameraBoundaries",
    "CameraBoundaries2",
    "CameraIdentity",
    "CameraRegionOfInterest",
    "CameraResults",
    "CameraSmartRetention",
    "CameraSsid",
    "CameraStatus",
    "CameraVerticesItem",
    "CameraZonesZoneId",
    "CampusGatewayAddressesItem",
    "CampusGatewayAddressesItem2",
    "CampusGatewayAddressesItem3",
    "CampusGatewayAddressesItem4",
    "CampusGatewayDevicesUplinksItem",
    "CampusGatewayNetwork",
    "CampusGatewayTunnelsAddressesItem",
    "CampusGatewayTunnelsUplink",
    "CampusGatewayUplink",
    "CampusGatewayUplinksAddressesItem",
    "CellularGatewayApnsItem",
    "CellularGatewayDestinationsItem",
    "CellularGatewayDevice",
    "CellularGatewayLogo",
    "CellularGatewayNetwork",
    "CellularGatewayPlansItem",
    "CellularGatewayProfilesItem",
    "CellularGatewayRoaming",
    "CellularGatewayServiceProvider",
    "CellularGatewayServiceProvider2",
    "CellularGatewaySignalStat",
    "CellularGatewayTerms",
    "CellularGatewayUplinksItem",
    "CheckinNetworkSmDevicesResponse",
    "ClaimAdministeredLicensingSubscriptionSubscriptionsResponse",
    "ClaimIntoOrganizationInventoryLicensesItem",
    "ClaimIntoOrganizationInventoryResponse",
    "ClaimIntoOrganizationLicensesItem",
    "ClaimIntoOrganizationResponse",
    "ClaimIntoOrganizationResponseLicensesItem",
    "ClaimNetworkDevicesDetailsByDeviceItem",
    "ClaimNetworkDevicesDetailsByDeviceItemDetailsItem",
    "ClaimNetworkDevicesResponse",
    "ClaimNetworkDevicesResponseErrorsItem",
    "ClaimOrganizationInventoryOrdersResponse",
    "ClaimOrganizationInventoryOrdersResponseSubscriptionsItem",
    "ClaimOrganizationInventoryOrdersSubscriptionsItem",
    "CloneOrganizationResponse",
    "CloneOrganizationSwitchDevicesResponse",
    "CombineOrganizationNetworksResponse",
    "CreateDeviceApplianceVmxAuthenticationTokenResponse",
    "CreateDeviceLiveToolsArpTableCallback",
    "CreateDeviceLiveToolsArpTableCallbackHttpServer",
    "CreateDeviceLiveToolsArpTableResponse",
    "CreateDeviceLiveToolsArpTableResponseCallback",
    "CreateDeviceLiveToolsArpTableResponseRequest",
    "CreateDeviceLiveToolsCableTestCallback",
    "CreateDeviceLiveToolsCableTestResponse",
    "CreateDeviceLiveToolsCableTestResponseRequest",
    "CreateDeviceLiveToolsLedsBlinkCallback",
    "CreateDeviceLiveToolsLedsBlinkResponse",
    "CreateDeviceLiveToolsLedsBlinkResponseRequest",
    "CreateDeviceLiveToolsMacTableCallback",
    "CreateDeviceLiveToolsMacTableResponse",
    "CreateDeviceLiveToolsMulticastRoutingCallback",
    "CreateDeviceLiveToolsMulticastRoutingResponse",
    "CreateDeviceLiveToolsPingCallback",
    "CreateDeviceLiveToolsPingDeviceCallback",
    "CreateDeviceLiveToolsPingDeviceResponse",
    "CreateDeviceLiveToolsPingDeviceResponseRequest",
    "CreateDeviceLiveToolsPingResponse",
    "CreateDeviceLiveToolsPingResponseRequest",
    "CreateDeviceLiveToolsThroughputTestCallback",
    "CreateDeviceLiveToolsThroughputTestResponse",
    "CreateDeviceLiveToolsThroughputTestResponseResult",
    "CreateDeviceLiveToolsWakeOnLanCallback",
    "CreateDeviceLiveToolsWakeOnLanResponse",
    "CreateDeviceLiveToolsWakeOnLanResponseRequest",
    "CreateDeviceSensorCommandResponse",
    "CreateDeviceSwitchRoutingInterfaceIpv6",
    "CreateDeviceSwitchRoutingInterfaceOspfSettings",
    "CreateDeviceSwitchRoutingInterfaceResponse",
    "CreateDeviceSwitchRoutingInterfaceVrf",
    "CreateDeviceSwitchRoutingStaticRouteResponse",
    "CreateDeviceSwitchRoutingStaticRouteVrf",
    "CreateDeviceWirelessZigbeeEnrollmentResponse",
    "CreateDeviceWirelessZigbeeEnrollmentResponseRequest",
    "CreateNetworkAppliancePrefixesDelegatedStaticOrigin",
    "CreateNetworkApplianceRfProfileFiveGhzSettings",
    "CreateNetworkApplianceRfProfilePerSsidSettings",
    "CreateNetworkApplianceRfProfilePerSsidSettings1",
    "CreateNetworkApplianceRfProfileResponse",
    "CreateNetworkApplianceRfProfileTwoFourGhzSettings",
    "CreateNetworkApplianceStaticRouteResponse",
    "CreateNetworkApplianceTrafficShapingCustomPerformanceClassResponse",
    "CreateNetworkApplianceVlanDhcpOptionsItem",
    "CreateNetworkApplianceVlanIpv6",
    "CreateNetworkApplianceVlanMandatoryDhcp",
    "CreateNetworkApplianceVlanResponse",
    "CreateNetworkCameraQualityRetentionProfileResponse",
    "CreateNetworkCameraQualityRetentionProfileSmartRetention",
    "CreateNetworkCameraQualityRetentionProfileVideoSettings",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV12MV22MV72",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV13",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV21MV71",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV22XMV72X",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV32",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV33",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV52",
    "CreateNetworkCameraQualityRetentionProfileVideoSettingsMV84X",
    "CreateNetworkCameraWirelessProfileIdentity",
    "CreateNetworkCameraWirelessProfileResponse",
    "CreateNetworkCameraWirelessProfileSsid",
    "CreateNetworkCampusGatewayClusterDevicesItem",
    "CreateNetworkCampusGatewayClusterDevicesItemUplinksItem",
    "CreateNetworkCampusGatewayClusterNameservers",
    "CreateNetworkCampusGatewayClusterPortChannelsItem",
    "CreateNetworkCampusGatewayClusterResponse",
    "CreateNetworkCampusGatewayClusterResponseDevicesItem",
    "CreateNetworkCampusGatewayClusterResponseNameservers",
    "CreateNetworkCampusGatewayClusterResponsePortChannelsItem",
    "CreateNetworkCampusGatewayClusterResponseTunnelsItem",
    "CreateNetworkCampusGatewayClusterResponseUplinksItem",
    "CreateNetworkCampusGatewayClusterTunnelsItem",
    "CreateNetworkCampusGatewayClusterTunnelsItemAddressesItem",
    "CreateNetworkCampusGatewayClusterTunnelsItemUplink",
    "CreateNetworkCampusGatewayClusterUplinksItem",
    "CreateNetworkCampusGatewayClusterUplinksItemAddressesItem",
    "CreateNetworkFirmwareUpgradesRollbackReasonsItem",
    "CreateNetworkFirmwareUpgradesRollbackResponse",
    "CreateNetworkFirmwareUpgradesRollbackResponseReasonsItem",
    "CreateNetworkFirmwareUpgradesRollbackToVersion",
    "CreateNetworkFirmwareUpgradesStagedEventProducts",
    "CreateNetworkFirmwareUpgradesStagedEventProductsSwitch",
    "CreateNetworkFirmwareUpgradesStagedEventResponse",
    "CreateNetworkFirmwareUpgradesStagedEventStagesItem",
    "CreateNetworkFirmwareUpgradesStagedGroupAssignedDevices",
    "CreateNetworkFirmwareUpgradesStagedGroupAssignedDevicesDevicesItem",
    "CreateNetworkFirmwareUpgradesStagedGroupAssignedDevicesSwitchStacksItem",
    "CreateNetworkFirmwareUpgradesStagedGroupResponse",
    "CreateNetworkFloorPlanBottomLeftCorner",
    "CreateNetworkFloorPlanBottomRightCorner",
    "CreateNetworkFloorPlanCenter",
    "CreateNetworkFloorPlanResponse",
    "CreateNetworkFloorPlanTopLeftCorner",
    "CreateNetworkFloorPlanTopRightCorner",
    "CreateNetworkGroupPolicyBandwidth",
    "CreateNetworkGroupPolicyBonjourForwarding",
    "CreateNetworkGroupPolicyContentFiltering",
    "CreateNetworkGroupPolicyFirewallAndTrafficShaping",
    "CreateNetworkGroupPolicyResponse",
    "CreateNetworkGroupPolicyScheduling",
    "CreateNetworkGroupPolicyVlanTagging",
    "CreateNetworkMerakiAuthUserAuthorizationsItem",
    "CreateNetworkMerakiAuthUserResponse",
    "CreateNetworkMoveNetwork",
    "CreateNetworkMoveOrganizations",
    "CreateNetworkMoveOrganizationsTarget",
    "CreateNetworkMoveResponse",
    "CreateNetworkMqttBrokerAuthentication",
    "CreateNetworkMqttBrokerResponse",
    "CreateNetworkMqttBrokerSecurity",
    "CreateNetworkMqttBrokerSecurityTls",
    "CreateNetworkPiiRequestResponse",
    "CreateNetworkSensorAlertsProfileConditionsItem",
    "CreateNetworkSensorAlertsProfileRecipients",
    "CreateNetworkSensorAlertsProfileResponse",
    "CreateNetworkSensorAlertsProfileSchedule",
    "CreateNetworkSmTargetGroupResponse",
    "CreateNetworkSwitchAccessPolicyDot1x",
    "CreateNetworkSwitchAccessPolicyRadius",
    "CreateNetworkSwitchAccessPolicyRadiusAccountingServersItem",
    "CreateNetworkSwitchAccessPolicyRadiusAuthentication",
    "CreateNetworkSwitchAccessPolicyRadiusServersItem",
    "CreateNetworkSwitchAccessPolicyResponse",
    "CreateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerIpv4",
    "CreateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerResponse",
    "CreateNetworkSwitchLinkAggregationResponse",
    "CreateNetworkSwitchLinkAggregationSwitchPortsItem",
    "CreateNetworkSwitchLinkAggregationSwitchProfilePortsItem",
    "CreateNetworkSwitchPortSchedulePortSchedule",
    "CreateNetworkSwitchPortScheduleResponse",
    "CreateNetworkSwitchQosRuleResponse",
    "CreateNetworkSwitchRoutingMulticastRendezvousPointResponse",
    "CreateNetworkSwitchRoutingMulticastRendezvousPointVrf",
    "CreateNetworkSwitchStackResponse",
    "CreateNetworkSwitchStackRoutingInterfaceIpv6",
    "CreateNetworkSwitchStackRoutingInterfaceOspfSettings",
    "CreateNetworkSwitchStackRoutingInterfaceResponse",
    "CreateNetworkSwitchStackRoutingInterfaceVrf",
    "CreateNetworkSwitchStackRoutingStaticRouteResponse",
    "CreateNetworkSwitchStackRoutingStaticRouteVrf",
    "CreateNetworkVlanProfileResponse",
    "CreateNetworkVlanProfileVlanGroupsItem",
    "CreateNetworkVlanProfileVlanNamesItem",
    "CreateNetworkWebhooksHttpServerPayloadTemplate",
    "CreateNetworkWebhooksHttpServerResponse",
    "CreateNetworkWebhooksPayloadTemplateHeadersItem",
    "CreateNetworkWebhooksPayloadTemplateResponse",
    "CreateNetworkWebhooksWebhookTestResponse",
    "CreateNetworkWirelessAirMarshalRuleMatch",
    "CreateNetworkWirelessAirMarshalRuleResponse",
    "CreateNetworkWirelessAirMarshalRuleResponseMatch",
    "CreateNetworkWirelessEthernetPortsProfilePortsItem",
    "CreateNetworkWirelessEthernetPortsProfileResponse",
    "CreateNetworkWirelessEthernetPortsProfileUsbPortsItem",
    "CreateNetworkWirelessRfProfileApBandSettings",
    "CreateNetworkWirelessRfProfileApBandSettingsBands",
    "CreateNetworkWirelessRfProfileFiveGhzSettings",
    "CreateNetworkWirelessRfProfileFlexRadios",
    "CreateNetworkWirelessRfProfileFlexRadiosByModelItem",
    "CreateNetworkWirelessRfProfilePerSsidSettings",
    "CreateNetworkWirelessRfProfilePerSsidSettings0",
    "CreateNetworkWirelessRfProfileResponse",
    "CreateNetworkWirelessRfProfileSixGhzSettings",
    "CreateNetworkWirelessRfProfileTransmission",
    "CreateNetworkWirelessRfProfileTwoFourGhzSettings",
    "CreateNetworkWirelessSsidIdentityPskResponse",
    "CreateOrganizationActionBatchActionsItem",
    "CreateOrganizationActionBatchCallback",
    "CreateOrganizationActionBatchCallbackHttpServer",
    "CreateOrganizationActionBatchResponse",
    "CreateOrganizationActionBatchResponseCallback",
    "CreateOrganizationAdaptivePolicyAclResponse",
    "CreateOrganizationAdaptivePolicyAclRulesItem",
    "CreateOrganizationAdaptivePolicyGroupPolicyObjectsItem",
    "CreateOrganizationAdaptivePolicyGroupResponse",
    "CreateOrganizationAdaptivePolicyPolicyAclsItem",
    "CreateOrganizationAdaptivePolicyPolicyDestinationGroup",
    "CreateOrganizationAdaptivePolicyPolicyResponse",
    "CreateOrganizationAdaptivePolicyPolicySourceGroup",
    "CreateOrganizationAdminNetworksItem",
    "CreateOrganizationAdminResponse",
    "CreateOrganizationAdminTagsItem",
    "CreateOrganizationAlertsProfileAlertCondition",
    "CreateOrganizationAlertsProfileRecipients",
    "CreateOrganizationAlertsProfileResponse",
    "CreateOrganizationApplianceDnsLocalProfileResponse",
    "CreateOrganizationApplianceDnsLocalProfilesAssignmentsBulkDeleteItemsItem",
    "CreateOrganizationApplianceDnsLocalProfilesAssignmentsBulkDeleteResponse",
    "CreateOrganizationApplianceDnsLocalRecordProfile",
    "CreateOrganizationApplianceDnsLocalRecordResponse",
    "CreateOrganizationApplianceDnsLocalRecordResponseItem",
    "CreateOrganizationApplianceDnsSplitProfileNameservers",
    "CreateOrganizationApplianceDnsSplitProfileResponse",
    "CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkCreateItemsItem",
    "CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkCreateResponse",
    "CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkDeleteItemsItem",
    "CreateOrganizationApplianceDnsSplitProfilesAssignmentsBulkDeleteResponse",
    "CreateOrganizationBrandingPolicyAdminSettings",
    "CreateOrganizationBrandingPolicyCustomLogo",
    "CreateOrganizationBrandingPolicyCustomLogoImage",
    "CreateOrganizationBrandingPolicyHelpSettings",
    "CreateOrganizationBrandingPolicyResponse",
    "CreateOrganizationCameraCustomAnalyticsArtifactResponse",
    "CreateOrganizationCameraRoleAppliedOnDevicesItem",
    "CreateOrganizationCameraRoleAppliedOnNetworksItem",
    "CreateOrganizationCameraRoleAppliedOrgWideItem",
    "CreateOrganizationCameraRoleResponse",
    "CreateOrganizationCellularGatewayEsimsServiceProvidersAccountResponse",
    "CreateOrganizationCellularGatewayEsimsServiceProvidersAccountServiceProvider",
    "CreateOrganizationCellularGatewayEsimsSwapResponse",
    "CreateOrganizationCellularGatewayEsimsSwapSwapsItem",
    "CreateOrganizationCellularGatewayEsimsSwapSwapsItemTarget",
    "CreateOrganizationConfigTemplateResponse",
    "CreateOrganizationDevicesControllerMigrationResponse",
    "CreateOrganizationDevicesControllerMigrationResponseItem",
    "CreateOrganizationDevicesPacketCaptureCaptureAdvanced",
    "CreateOrganizationDevicesPacketCaptureCaptureResponse",
    "CreateOrganizationDevicesPacketCaptureScheduleDevicesItem",
    "CreateOrganizationDevicesPacketCaptureScheduleResponse",
    "CreateOrganizationDevicesPacketCaptureScheduleSchedule",
    "CreateOrganizationEarlyAccessFeaturesOptInResponse",
    "CreateOrganizationInsightMonitoredMediaServerResponse",
    "CreateOrganizationInventoryDevicesSwapsBulkResponse",
    "CreateOrganizationInventoryDevicesSwapsBulkResponseSwapsItem",
    "CreateOrganizationInventoryDevicesSwapsBulkSwapsItem",
    "CreateOrganizationInventoryDevicesSwapsBulkSwapsItemDevices",
    "CreateOrganizationInventoryOnboardingCloudMonitoringImportDevicesItem",
    "CreateOrganizationInventoryOnboardingCloudMonitoringImportResponse",
    "CreateOrganizationInventoryOnboardingCloudMonitoringImportResponseItem",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItem",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemTunnel",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemUser",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareDevicesItemVty",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareOptions",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareResponse",
    "CreateOrganizationInventoryOnboardingCloudMonitoringPrepareResponseItem",
    "CreateOrganizationManagement",
    "CreateOrganizationNetworkResponse",
    "CreateOrganizationPolicyObjectResponse",
    "CreateOrganizationPolicyObjectsGroupResponse",
    "CreateOrganizationResponse",
    "CreateOrganizationSamlIdpResponse",
    "CreateOrganizationSamlIdpResponseItem",
    "CreateOrganizationSamlRoleNetworksItem",
    "CreateOrganizationSamlRoleResponse",
    "CreateOrganizationSamlRoleTagsItem",
    "CreateOrganizationSmAdminsRoleResponse",
    "CreateOrganizationSplashThemeAssetResponse",
    "CreateOrganizationSplashThemeResponse",
    "CreateOrganizationWirelessDevicesRadsecCertificatesAuthorityResponse",
    "CreateOrganizationWirelessLocationScanningReceiverNetwork",
    "CreateOrganizationWirelessLocationScanningReceiverRadio",
    "CreateOrganizationWirelessLocationScanningReceiverResponse",
    "CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryClient",
    "CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryNetwork",
    "CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryResponse",
    "CreateOrganizationWirelessSsidsFirewallIsolationAllowlistEntrySsid",
    "CreateOrganizationWirelessZigbeeDisenrollmentResponse",
    "CreateOrganizationWirelessZigbeeDisenrollmentResponseRequest",
    "CycleDeviceSwitchPortsResponse",
    "DeferNetworkFirmwareUpgradesStagedEventsResponse",
    "DeleteNetworkFloorPlanResponse",
    "DevicesAuthentication",
    "DevicesResultSpeeds",
    "DevicesResultsLatencies",
    "DevicesResultsLoss",
    "DevicesResultsPairsItem",
    "DevicesResultsRepliesItem",
    "DevicesSimsApnsItem",
    "DevicesUsage",
    "DevicesWan1Vrf",
    "DictResponse",
    "DisableOrganizationIntegrationsXdrNetworksNetworksItem",
    "DisableOrganizationIntegrationsXdrNetworksResponse",
    "DisableOrganizationIntegrationsXdrNetworksResponseNetworksItem",
    "EnableOrganizationIntegrationsXdrNetworksNetworksItem",
    "EnableOrganizationIntegrationsXdrNetworksResponse",
    "GenerateAdministeredIdentitiesMeApiKeysResponse",
    "GenerateDeviceCameraSnapshotResponse",
    "GenerateOrganizationDevicesPacketCaptureCaptureDownloadUrlResponse",
    "GetAdministeredIdentitiesMeApiKeysResponse",
    "GetAdministeredIdentitiesMeApiKeysResponseItem",
    "GetAdministeredIdentitiesMeResponse",
    "GetAdministeredIdentitiesMeResponseAuthentication",
    "GetAdministeredLicensingSubscriptionEntitlementsResponse",
    "GetAdministeredLicensingSubscriptionEntitlementsResponseItem",
    "GetAdministeredLicensingSubscriptionSubscriptionsComplianceStatusesResponse",
    "GetAdministeredLicensingSubscriptionSubscriptionsComplianceStatusesResponseItem",
    "GetAdministeredLicensingSubscriptionSubscriptionsResponse",
    "GetAdministeredLicensingSubscriptionSubscriptionsResponseItem",
    "GetDeviceApplianceDhcpSubnetsResponse",
    "GetDeviceApplianceDhcpSubnetsResponseItem",
    "GetDeviceAppliancePerformanceResponse",
    "GetDeviceAppliancePrefixesDelegatedResponse",
    "GetDeviceAppliancePrefixesDelegatedVlanAssignmentsResponse",
    "GetDeviceApplianceRadioSettingsResponse",
    "GetDeviceApplianceRadioSettingsResponseFiveGhzSettings",
    "GetDeviceApplianceRadioSettingsResponseTwoFourGhzSettings",
    "GetDeviceApplianceUplinksSettingsResponse",
    "GetDeviceApplianceUplinksSettingsResponseInterfaces",
    "GetDeviceCameraAnalyticsLiveResponse",
    "GetDeviceCameraAnalyticsLiveResponseZones",
    "GetDeviceCameraAnalyticsOverviewResponse",
    "GetDeviceCameraAnalyticsOverviewResponseItem",
    "GetDeviceCameraAnalyticsRecentResponse",
    "GetDeviceCameraAnalyticsRecentResponseItem",
    "GetDeviceCameraAnalyticsZoneHistoryResponse",
    "GetDeviceCameraAnalyticsZoneHistoryResponseItem",
    "GetDeviceCameraAnalyticsZonesResponse",
    "GetDeviceCameraAnalyticsZonesResponseItem",
    "GetDeviceCameraCustomAnalyticsResponse",
    "GetDeviceCameraCustomAnalyticsResponseParametersItem",
    "GetDeviceCameraSenseObjectDetectionModelsResponse",
    "GetDeviceCameraVideoSettingsResponse",
    "GetDeviceCellularGatewayLanResponse",
    "GetDeviceCellularGatewayLanResponseFixedIpAssignmentsItem",
    "GetDeviceCellularGatewayLanResponseReservedIpRangesItem",
    "GetDeviceCellularGatewayPortForwardingRulesResponse",
    "GetDeviceCellularGatewayPortForwardingRulesResponseRulesItem",
    "GetDeviceCellularSimsResponse",
    "GetDeviceCellularSimsResponseSimFailover",
    "GetDeviceCellularSimsResponseSimsItem",
    "GetDeviceClientsResponse",
    "GetDeviceClientsResponseItem",
    "GetDeviceLiveToolsArpTableResponse",
    "GetDeviceLiveToolsArpTableResponseEntriesItem",
    "GetDeviceLiveToolsCableTestResponse",
    "GetDeviceLiveToolsCableTestResponseResultsItem",
    "GetDeviceLiveToolsLedsBlinkResponse",
    "GetDeviceLiveToolsMacTableResponse",
    "GetDeviceLiveToolsMacTableResponseEntriesItem",
    "GetDeviceLiveToolsMulticastRoutingResponse",
    "GetDeviceLiveToolsMulticastRoutingResponseInterfacesItem",
    "GetDeviceLiveToolsMulticastRoutingResponseRoutesItem",
    "GetDeviceLiveToolsPingDeviceResponse",
    "GetDeviceLiveToolsPingResponse",
    "GetDeviceLiveToolsPingResponseResults",
    "GetDeviceLiveToolsThroughputTestResponse",
    "GetDeviceLiveToolsWakeOnLanResponse",
    "GetDeviceLldpCdpResponse",
    "GetDeviceLossAndLatencyHistoryResponse",
    "GetDeviceLossAndLatencyHistoryResponseItem",
    "GetDeviceManagementInterfaceResponse",
    "GetDeviceManagementInterfaceResponseDdnsHostnames",
    "GetDeviceManagementInterfaceResponseWan1",
    "GetDeviceResponse",
    "GetDeviceResponseBeaconIdParams",
    "GetDeviceResponseDetailsItem",
    "GetDeviceSensorCommandResponse",
    "GetDeviceSensorCommandsResponse",
    "GetDeviceSensorCommandsResponseItem",
    "GetDeviceSensorRelationshipsResponse",
    "GetDeviceSensorRelationshipsResponseLivestream",
    "GetDeviceSwitchPortResponse",
    "GetDeviceSwitchPortsResponse",
    "GetDeviceSwitchPortsResponseItem",
    "GetDeviceSwitchPortsStatusesPacketsResponse",
    "GetDeviceSwitchPortsStatusesPacketsResponseItem",
    "GetDeviceSwitchPortsStatusesResponse",
    "GetDeviceSwitchPortsStatusesResponseItem",
    "GetDeviceSwitchRoutingInterfaceDhcpResponse",
    "GetDeviceSwitchRoutingInterfaceDhcpResponseDhcpOptionsItem",
    "GetDeviceSwitchRoutingInterfaceDhcpResponseFixedIpAssignmentsItem",
    "GetDeviceSwitchRoutingInterfaceDhcpResponseReservedIpRangesItem",
    "GetDeviceSwitchRoutingInterfaceResponse",
    "GetDeviceSwitchRoutingInterfacesResponse",
    "GetDeviceSwitchRoutingInterfacesResponseItem",
    "GetDeviceSwitchRoutingStaticRouteResponse",
    "GetDeviceSwitchRoutingStaticRoutesResponse",
    "GetDeviceSwitchRoutingStaticRoutesResponseItem",
    "GetDeviceSwitchWarmSpareResponse",
    "GetDeviceWirelessBluetoothSettingsResponse",
    "GetDeviceWirelessConnectionStatsResponse",
    "GetDeviceWirelessConnectionStatsResponseConnectionStats",
    "GetDeviceWirelessElectronicShelfLabelResponse",
    "GetDeviceWirelessRadioSettingsResponse",
    "GetDeviceWirelessRadioSettingsResponseFiveGhzSettings",
    "GetDeviceWirelessRadioSettingsResponseTwoFourGhzSettings",
    "GetDeviceWirelessStatusResponse",
    "GetDeviceWirelessStatusResponseBasicServiceSetsItem",
    "GetDeviceWirelessZigbeeEnrollmentResponse",
    "GetDeviceWirelessZigbeeEnrollmentResponseDoorLocksItem",
    "GetNetworkAlertsHistoryResponse",
    "GetNetworkAlertsHistoryResponseItem",
    "GetNetworkAlertsSettingsResponse",
    "GetNetworkAlertsSettingsResponseAlertsItem",
    "GetNetworkAlertsSettingsResponseDefaultDestinations",
    "GetNetworkAlertsSettingsResponseMuting",
    "GetNetworkApplianceClientSecurityEventsResponse",
    "GetNetworkApplianceConnectivityMonitoringDestinationsResponse",
    "GetNetworkApplianceConnectivityMonitoringDestinationsResponseDestinationsItem",
    "GetNetworkApplianceContentFilteringResponse",
    "GetNetworkApplianceContentFilteringResponseBlockedUrlCategoriesItem",
    "GetNetworkApplianceFirewallFirewalledServiceResponse",
    "GetNetworkApplianceFirewallFirewalledServicesResponse",
    "GetNetworkApplianceFirewallFirewalledServicesResponseItem",
    "GetNetworkApplianceFirewallInboundCellularFirewallRulesResponse",
    "GetNetworkApplianceFirewallInboundCellularFirewallRulesResponseRulesItem",
    "GetNetworkApplianceFirewallInboundFirewallRulesResponse",
    "GetNetworkApplianceFirewallL7FirewallRulesApplicationCategoriesResponse",
    "GetNetworkApplianceFirewallPortForwardingRulesResponse",
    "GetNetworkApplianceFirewallPortForwardingRulesResponseRulesItem",
    "GetNetworkAppliancePortResponse",
    "GetNetworkAppliancePortsResponse",
    "GetNetworkAppliancePortsResponseItem",
    "GetNetworkAppliancePrefixesDelegatedStaticResponse",
    "GetNetworkAppliancePrefixesDelegatedStaticsResponse",
    "GetNetworkAppliancePrefixesDelegatedStaticsResponseItem",
    "GetNetworkApplianceRfProfileResponse",
    "GetNetworkApplianceRfProfilesResponse",
    "GetNetworkApplianceRfProfilesResponseAssignedItem",
    "GetNetworkApplianceSecurityEventsResponse",
    "GetNetworkApplianceSecurityIntrusionResponse",
    "GetNetworkApplianceSecurityIntrusionResponseProtectedNetworks",
    "GetNetworkApplianceSecurityMalwareResponse",
    "GetNetworkApplianceSecurityMalwareResponseAllowedFilesItem",
    "GetNetworkApplianceSecurityMalwareResponseAllowedUrlsItem",
    "GetNetworkApplianceSettingsResponse",
    "GetNetworkApplianceSettingsResponseDynamicDns",
    "GetNetworkApplianceSingleLanResponse",
    "GetNetworkApplianceSingleLanResponseIpv6",
    "GetNetworkApplianceSingleLanResponseMandatoryDhcp",
    "GetNetworkApplianceSsidResponse",
    "GetNetworkApplianceSsidsResponse",
    "GetNetworkApplianceSsidsResponseItem",
    "GetNetworkApplianceStaticRouteResponse",
    "GetNetworkApplianceStaticRoutesResponse",
    "GetNetworkApplianceStaticRoutesResponseItem",
    "GetNetworkApplianceTrafficShapingCustomPerformanceClassResponse",
    "GetNetworkApplianceTrafficShapingCustomPerformanceClassesResponse",
    "GetNetworkApplianceTrafficShapingCustomPerformanceClassesResponseItem",
    "GetNetworkApplianceTrafficShapingUplinkBandwidthResponse",
    "GetNetworkApplianceTrafficShapingUplinkBandwidthResponseBandwidthLimits",
    "GetNetworkApplianceTrafficShapingUplinkSelectionResponse",
    "GetNetworkApplianceTrafficShapingUplinkSelectionResponseFailoverAndFailback",
    "GetNetworkApplianceUplinksUsageHistoryResponse",
    "GetNetworkApplianceUplinksUsageHistoryResponseItem",
    "GetNetworkApplianceVlanResponse",
    "GetNetworkApplianceVlansResponse",
    "GetNetworkApplianceVlansResponseItem",
    "GetNetworkApplianceVlansSettingsResponse",
    "GetNetworkApplianceVpnBgpResponse",
    "GetNetworkApplianceVpnBgpResponseNeighborsItem",
    "GetNetworkApplianceVpnSiteToSiteVpnResponse",
    "GetNetworkApplianceVpnSiteToSiteVpnResponseHubsItem",
    "GetNetworkApplianceVpnSiteToSiteVpnResponseSubnet",
    "GetNetworkApplianceVpnSiteToSiteVpnResponseSubnetsItem",
    "GetNetworkApplianceWarmSpareResponse",
    "GetNetworkApplianceWarmSpareResponseWan1",
    "GetNetworkBluetoothClientResponse",
    "GetNetworkBluetoothClientsResponse",
    "GetNetworkBluetoothClientsResponseItem",
    "GetNetworkCameraQualityRetentionProfileResponse",
    "GetNetworkCameraQualityRetentionProfilesResponse",
    "GetNetworkCameraQualityRetentionProfilesResponseItem",
    "GetNetworkCameraSchedulesResponse",
    "GetNetworkCameraSchedulesResponseItem",
    "GetNetworkCameraWirelessProfileResponse",
    "GetNetworkCameraWirelessProfilesResponse",
    "GetNetworkCameraWirelessProfilesResponseItem",
    "GetNetworkCellularGatewayConnectivityMonitoringDestinationsResponse",
    "GetNetworkCellularGatewayDhcpResponse",
    "GetNetworkCellularGatewaySubnetPoolResponse",
    "GetNetworkCellularGatewaySubnetPoolResponseSubnetsItem",
    "GetNetworkCellularGatewayUplinkResponse",
    "GetNetworkCellularGatewayUplinkResponseBandwidthLimits",
    "GetNetworkClientPolicyResponse",
    "GetNetworkClientPolicyResponsePoliciesBySsidItem",
    "GetNetworkClientResponse",
    "GetNetworkClientResponseClientVpnConnectionsItem",
    "GetNetworkClientTrafficHistoryResponse",
    "GetNetworkClientTrafficHistoryResponseItem",
    "GetNetworkClientUsageHistoryResponse",
    "GetNetworkClientUsageHistoryResponseItem",
    "GetNetworkClientsApplicationUsageResponse",
    "GetNetworkClientsApplicationUsageResponseItem",
    "GetNetworkClientsBandwidthUsageHistoryResponse",
    "GetNetworkClientsBandwidthUsageHistoryResponseItem",
    "GetNetworkClientsOverviewResponse",
    "GetNetworkClientsOverviewResponseCounts",
    "GetNetworkClientsOverviewResponseUsages",
    "GetNetworkClientsResponse",
    "GetNetworkClientsResponseItem",
    "GetNetworkClientsUsageHistoriesResponse",
    "GetNetworkClientsUsageHistoriesResponseItem",
    "GetNetworkDevicesResponse",
    "GetNetworkDevicesResponseItem",
    "GetNetworkEventsEventTypesResponse",
    "GetNetworkEventsEventTypesResponseItem",
    "GetNetworkEventsResponse",
    "GetNetworkEventsResponseEventsItem",
    "GetNetworkFirmwareUpgradesResponse",
    "GetNetworkFirmwareUpgradesResponseProducts",
    "GetNetworkFirmwareUpgradesResponseUpgradeWindow",
    "GetNetworkFirmwareUpgradesStagedEventsResponse",
    "GetNetworkFirmwareUpgradesStagedEventsResponseProducts",
    "GetNetworkFirmwareUpgradesStagedEventsResponseStagesItem",
    "GetNetworkFirmwareUpgradesStagedGroupResponse",
    "GetNetworkFirmwareUpgradesStagedGroupsResponse",
    "GetNetworkFirmwareUpgradesStagedGroupsResponseItem",
    "GetNetworkFirmwareUpgradesStagedStagesResponse",
    "GetNetworkFirmwareUpgradesStagedStagesResponseItem",
    "GetNetworkFloorPlanResponse",
    "GetNetworkFloorPlansResponse",
    "GetNetworkFloorPlansResponseItem",
    "GetNetworkGroupPoliciesResponse",
    "GetNetworkGroupPoliciesResponseItem",
    "GetNetworkGroupPolicyResponse",
    "GetNetworkHealthAlertsResponse",
    "GetNetworkHealthAlertsResponseItem",
    "GetNetworkInsightApplicationHealthByTimeResponse",
    "GetNetworkInsightApplicationHealthByTimeResponseItem",
    "GetNetworkMerakiAuthUserResponse",
    "GetNetworkMerakiAuthUsersResponse",
    "GetNetworkMerakiAuthUsersResponseItem",
    "GetNetworkMovesResponseItemsItem",
    "GetNetworkMqttBrokerResponse",
    "GetNetworkMqttBrokersResponse",
    "GetNetworkMqttBrokersResponseItem",
    "GetNetworkNetflowResponse",
    "GetNetworkNetworkHealthChannelUtilizationResponse",
    "GetNetworkNetworkHealthChannelUtilizationResponseItem",
    "GetNetworkPiiPiiKeysResponse",
    "GetNetworkPiiPiiKeysResponseValue",
    "GetNetworkPiiRequestResponse",
    "GetNetworkPiiRequestsResponse",
    "GetNetworkPiiRequestsResponseItem",
    "GetNetworkPiiSmDevicesForKeyResponse",
    "GetNetworkPiiSmOwnersForKeyResponse",
    "GetNetworkPoliciesByClientResponse",
    "GetNetworkPoliciesByClientResponseItem",
    "GetNetworkResponse",
    "GetNetworkSensorAlertsCurrentOverviewByMetricResponse",
    "GetNetworkSensorAlertsCurrentOverviewByMetricResponseCounts",
    "GetNetworkSensorAlertsOverviewByMetricResponse",
    "GetNetworkSensorAlertsOverviewByMetricResponseItem",
    "GetNetworkSensorAlertsProfileResponse",
    "GetNetworkSensorAlertsProfilesResponse",
    "GetNetworkSensorAlertsProfilesResponseItem",
    "GetNetworkSensorMqttBrokerResponse",
    "GetNetworkSensorMqttBrokersResponse",
    "GetNetworkSensorMqttBrokersResponseItem",
    "GetNetworkSensorRelationshipsResponse",
    "GetNetworkSensorRelationshipsResponseItem",
    "GetNetworkSettingsResponse",
    "GetNetworkSettingsResponseLocalStatusPage",
    "GetNetworkSettingsResponseNamedVlans",
    "GetNetworkSmDeviceCellularUsageHistoryResponse",
    "GetNetworkSmDeviceCellularUsageHistoryResponseItem",
    "GetNetworkSmDeviceCertsResponse",
    "GetNetworkSmDeviceCertsResponseItem",
    "GetNetworkSmDeviceConnectivityResponse",
    "GetNetworkSmDeviceConnectivityResponseItem",
    "GetNetworkSmDeviceDesktopLogsResponse",
    "GetNetworkSmDeviceDesktopLogsResponseItem",
    "GetNetworkSmDeviceDeviceCommandLogsResponse",
    "GetNetworkSmDeviceDeviceCommandLogsResponseItem",
    "GetNetworkSmDeviceDeviceProfilesResponse",
    "GetNetworkSmDeviceDeviceProfilesResponseItem",
    "GetNetworkSmDeviceNetworkAdaptersResponse",
    "GetNetworkSmDeviceNetworkAdaptersResponseItem",
    "GetNetworkSmDevicePerformanceHistoryResponse",
    "GetNetworkSmDevicePerformanceHistoryResponseItem",
    "GetNetworkSmDeviceRestrictionsResponse",
    "GetNetworkSmDeviceRestrictionsResponseRestrictionsItem",
    "GetNetworkSmDeviceSecurityCentersResponse",
    "GetNetworkSmDeviceSecurityCentersResponseItem",
    "GetNetworkSmDeviceSoftwaresResponse",
    "GetNetworkSmDeviceSoftwaresResponseItem",
    "GetNetworkSmDeviceWlanListsResponse",
    "GetNetworkSmDeviceWlanListsResponseItem",
    "GetNetworkSmDevicesResponse",
    "GetNetworkSmDevicesResponseItem",
    "GetNetworkSmProfilesResponse",
    "GetNetworkSmProfilesResponseItem",
    "GetNetworkSmTargetGroupResponse",
    "GetNetworkSmTargetGroupsResponse",
    "GetNetworkSmTargetGroupsResponseItem",
    "GetNetworkSmTrustedAccessConfigsResponse",
    "GetNetworkSmTrustedAccessConfigsResponseItem",
    "GetNetworkSmUserAccessDevicesResponse",
    "GetNetworkSmUserAccessDevicesResponseItem",
    "GetNetworkSmUserDeviceProfilesResponse",
    "GetNetworkSmUserDeviceProfilesResponseItem",
    "GetNetworkSmUserSoftwaresResponse",
    "GetNetworkSmUserSoftwaresResponseItem",
    "GetNetworkSmUsersResponse",
    "GetNetworkSmUsersResponseItem",
    "GetNetworkSnmpResponse",
    "GetNetworkSnmpResponseUsersItem",
    "GetNetworkSplashLoginAttemptsResponse",
    "GetNetworkSplashLoginAttemptsResponseItem",
    "GetNetworkSwitchAccessControlListsResponse",
    "GetNetworkSwitchAccessControlListsResponseRulesItem",
    "GetNetworkSwitchAccessPoliciesResponse",
    "GetNetworkSwitchAccessPoliciesResponseItem",
    "GetNetworkSwitchAccessPolicyResponse",
    "GetNetworkSwitchAlternateManagementInterfaceResponse",
    "GetNetworkSwitchAlternateManagementInterfaceResponseSwitchesItem",
    "GetNetworkSwitchDhcpServerPolicyArpInspectionTrustedServersResponse",
    "GetNetworkSwitchDhcpServerPolicyArpInspectionTrustedServersResponseItem",
    "GetNetworkSwitchDhcpServerPolicyArpInspectionWarningsByDeviceResponse",
    "GetNetworkSwitchDhcpServerPolicyArpInspectionWarningsByDeviceResponseItem",
    "GetNetworkSwitchDhcpServerPolicyResponse",
    "GetNetworkSwitchDhcpServerPolicyResponseAlerts",
    "GetNetworkSwitchDhcpServerPolicyResponseArpInspection",
    "GetNetworkSwitchDhcpV4ServersSeenResponse",
    "GetNetworkSwitchDhcpV4ServersSeenResponseItem",
    "GetNetworkSwitchDscpToCosMappingsResponse",
    "GetNetworkSwitchDscpToCosMappingsResponseMappingsItem",
    "GetNetworkSwitchLinkAggregationsResponse",
    "GetNetworkSwitchLinkAggregationsResponseItem",
    "GetNetworkSwitchMtuResponse",
    "GetNetworkSwitchMtuResponseOverridesItem",
    "GetNetworkSwitchPortSchedulesResponse",
    "GetNetworkSwitchPortSchedulesResponseItem",
    "GetNetworkSwitchQosRuleResponse",
    "GetNetworkSwitchQosRulesOrderResponse",
    "GetNetworkSwitchQosRulesResponse",
    "GetNetworkSwitchQosRulesResponseItem",
    "GetNetworkSwitchRoutingMulticastRendezvousPointResponse",
    "GetNetworkSwitchRoutingMulticastRendezvousPointsResponse",
    "GetNetworkSwitchRoutingMulticastRendezvousPointsResponseItem",
    "GetNetworkSwitchRoutingMulticastResponse",
    "GetNetworkSwitchRoutingMulticastResponseDefaultSettings",
    "GetNetworkSwitchRoutingMulticastResponseOverridesItem",
    "GetNetworkSwitchRoutingOspfResponse",
    "GetNetworkSwitchRoutingOspfResponseAreasItem",
    "GetNetworkSwitchRoutingOspfResponseMd5AuthenticationKey",
    "GetNetworkSwitchRoutingOspfResponseV3",
    "GetNetworkSwitchSettingsResponse",
    "GetNetworkSwitchSettingsResponsePowerExceptionsItem",
    "GetNetworkSwitchSettingsResponseUplinkSelection",
    "GetNetworkSwitchStackResponse",
    "GetNetworkSwitchStackRoutingInterfaceDhcpResponse",
    "GetNetworkSwitchStackRoutingInterfaceResponse",
    "GetNetworkSwitchStackRoutingInterfacesResponse",
    "GetNetworkSwitchStackRoutingInterfacesResponseItem",
    "GetNetworkSwitchStackRoutingStaticRouteResponse",
    "GetNetworkSwitchStackRoutingStaticRoutesResponse",
    "GetNetworkSwitchStackRoutingStaticRoutesResponseItem",
    "GetNetworkSwitchStacksResponse",
    "GetNetworkSwitchStacksResponseItem",
    "GetNetworkSwitchStormControlResponse",
    "GetNetworkSwitchStpResponse",
    "GetNetworkSwitchStpResponseStpBridgePriorityItem",
    "GetNetworkSyslogServersResponse",
    "GetNetworkSyslogServersResponseServersItem",
    "GetNetworkTopologyLinkLayerResponse",
    "GetNetworkTopologyLinkLayerResponseLinksItem",
    "GetNetworkTopologyLinkLayerResponseNodesItem",
    "GetNetworkTrafficAnalysisResponse",
    "GetNetworkTrafficAnalysisResponseCustomPieChartItemsItem",
    "GetNetworkTrafficResponse",
    "GetNetworkTrafficResponseItem",
    "GetNetworkTrafficShapingDscpTaggingOptionsResponse",
    "GetNetworkVlanProfileResponse",
    "GetNetworkVlanProfilesAssignmentsByDeviceResponse",
    "GetNetworkVlanProfilesAssignmentsByDeviceResponseItem",
    "GetNetworkVlanProfilesResponse",
    "GetNetworkVlanProfilesResponseItem",
    "GetNetworkWebhooksHttpServerResponse",
    "GetNetworkWebhooksHttpServersResponse",
    "GetNetworkWebhooksHttpServersResponseItem",
    "GetNetworkWebhooksPayloadTemplateResponse",
    "GetNetworkWebhooksPayloadTemplatesResponse",
    "GetNetworkWebhooksPayloadTemplatesResponseItem",
    "GetNetworkWebhooksWebhookTestResponse",
    "GetNetworkWirelessAirMarshalResponse",
    "GetNetworkWirelessAirMarshalResponseItem",
    "GetNetworkWirelessBillingResponse",
    "GetNetworkWirelessBillingResponsePlansItem",
    "GetNetworkWirelessBluetoothSettingsResponse",
    "GetNetworkWirelessChannelUtilizationHistoryResponse",
    "GetNetworkWirelessChannelUtilizationHistoryResponseItem",
    "GetNetworkWirelessClientConnectionStatsResponse",
    "GetNetworkWirelessClientConnectionStatsResponseConnectionStats",
    "GetNetworkWirelessClientConnectivityEventsResponse",
    "GetNetworkWirelessClientConnectivityEventsResponseItem",
    "GetNetworkWirelessClientCountHistoryResponse",
    "GetNetworkWirelessClientCountHistoryResponseItem",
    "GetNetworkWirelessClientLatencyHistoryResponse",
    "GetNetworkWirelessClientLatencyHistoryResponseItem",
    "GetNetworkWirelessClientsConnectionStatsResponse",
    "GetNetworkWirelessClientsLatencyStatsResponse",
    "GetNetworkWirelessConnectionStatsResponse",
    "GetNetworkWirelessDataRateHistoryResponse",
    "GetNetworkWirelessDataRateHistoryResponseItem",
    "GetNetworkWirelessDevicesConnectionStatsResponse",
    "GetNetworkWirelessDevicesConnectionStatsResponseItem",
    "GetNetworkWirelessDevicesLatencyStatsResponse",
    "GetNetworkWirelessElectronicShelfLabelConfiguredDevicesResponse",
    "GetNetworkWirelessElectronicShelfLabelConfiguredDevicesResponseItem",
    "GetNetworkWirelessElectronicShelfLabelResponse",
    "GetNetworkWirelessEthernetPortsProfileResponse",
    "GetNetworkWirelessEthernetPortsProfilesResponse",
    "GetNetworkWirelessEthernetPortsProfilesResponseItem",
    "GetNetworkWirelessFailedConnectionsResponse",
    "GetNetworkWirelessFailedConnectionsResponseItem",
    "GetNetworkWirelessLatencyHistoryResponse",
    "GetNetworkWirelessLatencyHistoryResponseItem",
    "GetNetworkWirelessMeshStatusesResponse",
    "GetNetworkWirelessMeshStatusesResponseItem",
    "GetNetworkWirelessRfProfileResponse",
    "GetNetworkWirelessRfProfilesResponse",
    "GetNetworkWirelessRfProfilesResponseApBandSettings",
    "GetNetworkWirelessRfProfilesResponseFiveGhzSettings",
    "GetNetworkWirelessRfProfilesResponsePerSsidSettings",
    "GetNetworkWirelessRfProfilesResponseTwoFourGhzSettings",
    "GetNetworkWirelessSettingsResponse",
    "GetNetworkWirelessSettingsResponseNamedVlans",
    "GetNetworkWirelessSettingsResponseRegulatoryDomain",
    "GetNetworkWirelessSignalQualityHistoryResponse",
    "GetNetworkWirelessSignalQualityHistoryResponseItem",
    "GetNetworkWirelessSsidBonjourForwardingResponse",
    "GetNetworkWirelessSsidBonjourForwardingResponseRulesItem",
    "GetNetworkWirelessSsidEapOverrideResponse",
    "GetNetworkWirelessSsidEapOverrideResponseEapolKey",
    "GetNetworkWirelessSsidEapOverrideResponseIdentity",
    "GetNetworkWirelessSsidFirewallL3FirewallRulesResponse",
    "GetNetworkWirelessSsidFirewallL3FirewallRulesResponseRulesItem",
    "GetNetworkWirelessSsidFirewallL7FirewallRulesResponse",
    "GetNetworkWirelessSsidFirewallL7FirewallRulesResponseRulesItem",
    "GetNetworkWirelessSsidHotspot20Response",
    "GetNetworkWirelessSsidHotspot20ResponseMccMncsItem",
    "GetNetworkWirelessSsidHotspot20ResponseNaiRealmsItem",
    "GetNetworkWirelessSsidHotspot20ResponseOperator",
    "GetNetworkWirelessSsidHotspot20ResponseVenue",
    "GetNetworkWirelessSsidIdentityPskResponse",
    "GetNetworkWirelessSsidIdentityPsksResponse",
    "GetNetworkWirelessSsidIdentityPsksResponseItem",
    "GetNetworkWirelessSsidResponse",
    "GetNetworkWirelessSsidSchedulesResponse",
    "GetNetworkWirelessSsidSchedulesResponseRangesInSecondsItem",
    "GetNetworkWirelessSsidSchedulesResponseRangesItem",
    "GetNetworkWirelessSsidSplashSettingsResponse",
    "GetNetworkWirelessSsidSplashSettingsResponseBilling",
    "GetNetworkWirelessSsidSplashSettingsResponseGuestSponsorship",
    "GetNetworkWirelessSsidSplashSettingsResponseSelfRegistration",
    "GetNetworkWirelessSsidSplashSettingsResponseSentryEnrollment",
    "GetNetworkWirelessSsidSplashSettingsResponseSplashLogo",
    "GetNetworkWirelessSsidTrafficShapingRulesResponse",
    "GetNetworkWirelessSsidTrafficShapingRulesResponseRulesItem",
    "GetNetworkWirelessSsidsResponse",
    "GetNetworkWirelessSsidsResponseItem",
    "GetNetworkWirelessUsageHistoryResponse",
    "GetNetworkWirelessUsageHistoryResponseItem",
    "GetOrganizationActionBatchResponse",
    "GetOrganizationActionBatchesResponse",
    "GetOrganizationActionBatchesResponseItem",
    "GetOrganizationAdaptivePolicyAclResponse",
    "GetOrganizationAdaptivePolicyAclsResponse",
    "GetOrganizationAdaptivePolicyAclsResponseItem",
    "GetOrganizationAdaptivePolicyGroupResponse",
    "GetOrganizationAdaptivePolicyGroupsResponse",
    "GetOrganizationAdaptivePolicyGroupsResponseItem",
    "GetOrganizationAdaptivePolicyOverviewResponse",
    "GetOrganizationAdaptivePolicyOverviewResponseCounts",
    "GetOrganizationAdaptivePolicyOverviewResponseLimits",
    "GetOrganizationAdaptivePolicyPoliciesResponse",
    "GetOrganizationAdaptivePolicyPoliciesResponseItem",
    "GetOrganizationAdaptivePolicyPolicyResponse",
    "GetOrganizationAdaptivePolicySettingsResponse",
    "GetOrganizationAdminsResponse",
    "GetOrganizationAdminsResponseItem",
    "GetOrganizationAlertsProfilesResponse",
    "GetOrganizationAlertsProfilesResponseItem",
    "GetOrganizationApiRequestsOverviewResponse",
    "GetOrganizationApiRequestsOverviewResponseCodesByIntervalResponse",
    "GetOrganizationApiRequestsOverviewResponseCodesByIntervalResponseItem",
    "GetOrganizationApiRequestsOverviewResponseResponseCodeCounts",
    "GetOrganizationApiRequestsResponse",
    "GetOrganizationApiRequestsResponseItem",
    "GetOrganizationApplianceDnsLocalProfilesAssignmentsResponseItemsItem",
    "GetOrganizationApplianceDnsLocalProfilesResponse",
    "GetOrganizationApplianceDnsLocalProfilesResponseItem",
    "GetOrganizationApplianceDnsLocalRecordsResponse",
    "GetOrganizationApplianceDnsLocalRecordsResponseItem",
    "GetOrganizationApplianceDnsSplitProfilesAssignmentsResponseItemsItem",
    "GetOrganizationApplianceDnsSplitProfilesResponse",
    "GetOrganizationApplianceDnsSplitProfilesResponseItem",
    "GetOrganizationApplianceFirewallMulticastForwardingByNetworkResponseItemsItem",
    "GetOrganizationApplianceSecurityEventsResponse",
    "GetOrganizationApplianceTrafficShapingVpnExclusionsByNetworkResponseItemsItem",
    "GetOrganizationApplianceUplinkStatusesResponse",
    "GetOrganizationApplianceUplinkStatusesResponseItem",
    "GetOrganizationApplianceUplinksStatusesOverviewResponse",
    "GetOrganizationApplianceUplinksStatusesOverviewResponseCounts",
    "GetOrganizationApplianceUplinksUsageByNetworkResponse",
    "GetOrganizationApplianceUplinksUsageByNetworkResponseItem",
    "GetOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseItemsItem",
    "GetOrganizationApplianceVpnStatsResponse",
    "GetOrganizationApplianceVpnStatsResponseItem",
    "GetOrganizationApplianceVpnStatusesResponse",
    "GetOrganizationApplianceVpnStatusesResponseItem",
    "GetOrganizationApplianceVpnThirdPartyVPNPeersResponse",
    "GetOrganizationApplianceVpnThirdPartyVPNPeersResponsePeersItem",
    "GetOrganizationApplianceVpnVpnFirewallRulesResponse",
    "GetOrganizationAssuranceAlertResponse",
    "GetOrganizationAssuranceAlertsOverviewByNetworkResponseItemsItem",
    "GetOrganizationAssuranceAlertsOverviewByTypeResponseItemsItem",
    "GetOrganizationAssuranceAlertsOverviewHistoricalResponseItemsItem",
    "GetOrganizationAssuranceAlertsOverviewResponse",
    "GetOrganizationAssuranceAlertsOverviewResponseCounts",
    "GetOrganizationAssuranceAlertsResponse",
    "GetOrganizationAssuranceAlertsResponseItem",
    "GetOrganizationAssuranceAlertsTaxonomyCategoriesResponse",
    "GetOrganizationAssuranceAlertsTaxonomyCategoriesResponseItem",
    "GetOrganizationAssuranceAlertsTaxonomyTypesResponse",
    "GetOrganizationAssuranceAlertsTaxonomyTypesResponseItem",
    "GetOrganizationBrandingPoliciesPrioritiesResponse",
    "GetOrganizationBrandingPoliciesResponse",
    "GetOrganizationBrandingPoliciesResponseItem",
    "GetOrganizationBrandingPolicyResponse",
    "GetOrganizationCameraBoundariesAreasByDeviceResponse",
    "GetOrganizationCameraBoundariesAreasByDeviceResponseItem",
    "GetOrganizationCameraBoundariesLinesByDeviceResponse",
    "GetOrganizationCameraBoundariesLinesByDeviceResponseItem",
    "GetOrganizationCameraCustomAnalyticsArtifactResponse",
    "GetOrganizationCameraCustomAnalyticsArtifactsResponse",
    "GetOrganizationCameraCustomAnalyticsArtifactsResponseItem",
    "GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalResponse",
    "GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalResponseItem",
    "GetOrganizationCameraOnboardingStatusesResponse",
    "GetOrganizationCameraPermissionResponse",
    "GetOrganizationCameraPermissionsResponse",
    "GetOrganizationCameraPermissionsResponseItem",
    "GetOrganizationCameraRoleResponse",
    "GetOrganizationCameraRolesResponse",
    "GetOrganizationCameraRolesResponseItem",
    "GetOrganizationCampusGatewayClustersResponseItemsItem",
    "GetOrganizationCampusGatewayDevicesUplinksLocalOverridesByDeviceResponseItemsItem",
    "GetOrganizationCellularGatewayEsimsInventoryResponseItemsItem",
    "GetOrganizationCellularGatewayEsimsServiceProvidersAccountsCommunicationPlansResponseItemsItem",
    "GetOrganizationCellularGatewayEsimsServiceProvidersAccountsRatePlansResponseItemsItem",
    "GetOrganizationCellularGatewayEsimsServiceProvidersAccountsResponse",
    "GetOrganizationCellularGatewayEsimsServiceProvidersAccountsResponseItem",
    "GetOrganizationCellularGatewayEsimsServiceProvidersResponseItemsItem",
    "GetOrganizationCellularGatewayUplinkStatusesResponse",
    "GetOrganizationCellularGatewayUplinkStatusesResponseItem",
    "GetOrganizationClientsBandwidthUsageHistoryResponse",
    "GetOrganizationClientsBandwidthUsageHistoryResponseItem",
    "GetOrganizationClientsOverviewResponse",
    "GetOrganizationClientsOverviewResponseCounts",
    "GetOrganizationClientsOverviewResponseUsage",
    "GetOrganizationClientsSearchResponse",
    "GetOrganizationClientsSearchResponseRecordsItem",
    "GetOrganizationConfigTemplateResponse",
    "GetOrganizationConfigTemplateSwitchProfilePortResponse",
    "GetOrganizationConfigTemplateSwitchProfilePortsResponse",
    "GetOrganizationConfigTemplateSwitchProfilePortsResponseItem",
    "GetOrganizationConfigTemplateSwitchProfilesResponse",
    "GetOrganizationConfigTemplateSwitchProfilesResponseItem",
    "GetOrganizationConfigTemplatesResponse",
    "GetOrganizationConfigTemplatesResponseItem",
    "GetOrganizationConfigurationChangesResponse",
    "GetOrganizationConfigurationChangesResponseItem",
    "GetOrganizationDevicesAvailabilitiesChangeHistoryResponse",
    "GetOrganizationDevicesAvailabilitiesChangeHistoryResponseItem",
    "GetOrganizationDevicesAvailabilitiesResponse",
    "GetOrganizationDevicesAvailabilitiesResponseItem",
    "GetOrganizationDevicesControllerMigrationsResponseItemsItem",
    "GetOrganizationDevicesOverviewByModelResponse",
    "GetOrganizationDevicesOverviewByModelResponseCountsItem",
    "GetOrganizationDevicesPacketCaptureCapturesResponseItemsItem",
    "GetOrganizationDevicesPacketCaptureSchedulesResponseItemsItem",
    "GetOrganizationDevicesPowerModulesStatusesByDeviceResponse",
    "GetOrganizationDevicesPowerModulesStatusesByDeviceResponseItem",
    "GetOrganizationDevicesProvisioningStatusesResponse",
    "GetOrganizationDevicesProvisioningStatusesResponseItem",
    "GetOrganizationDevicesResponse",
    "GetOrganizationDevicesResponseItem",
    "GetOrganizationDevicesStatusesOverviewResponse",
    "GetOrganizationDevicesStatusesOverviewResponseCounts",
    "GetOrganizationDevicesStatusesResponse",
    "GetOrganizationDevicesStatusesResponseItem",
    "GetOrganizationDevicesSystemMemoryUsageHistoryByIntervalResponseItemsItem",
    "GetOrganizationDevicesUplinksAddressesByDeviceResponse",
    "GetOrganizationDevicesUplinksAddressesByDeviceResponseItem",
    "GetOrganizationDevicesUplinksLossAndLatencyResponse",
    "GetOrganizationDevicesUplinksLossAndLatencyResponseItem",
    "GetOrganizationEarlyAccessFeaturesOptInResponse",
    "GetOrganizationEarlyAccessFeaturesOptInsResponse",
    "GetOrganizationEarlyAccessFeaturesOptInsResponseOptOutEligibility",
    "GetOrganizationEarlyAccessFeaturesResponse",
    "GetOrganizationEarlyAccessFeaturesResponseItem",
    "GetOrganizationFirmwareUpgradesByDeviceResponse",
    "GetOrganizationFirmwareUpgradesByDeviceResponseItem",
    "GetOrganizationFirmwareUpgradesResponse",
    "GetOrganizationFirmwareUpgradesResponseItem",
    "GetOrganizationFloorPlansAutoLocateDevicesResponse",
    "GetOrganizationFloorPlansAutoLocateDevicesResponseItem",
    "GetOrganizationFloorPlansAutoLocateStatusesResponse",
    "GetOrganizationFloorPlansAutoLocateStatusesResponseItem",
    "GetOrganizationInsightApplicationsResponse",
    "GetOrganizationInsightApplicationsResponseItem",
    "GetOrganizationInsightMonitoredMediaServerResponse",
    "GetOrganizationInsightMonitoredMediaServersResponse",
    "GetOrganizationInsightMonitoredMediaServersResponseItem",
    "GetOrganizationIntegrationsXdrNetworksResponseItemsItem",
    "GetOrganizationInventoryDeviceResponse",
    "GetOrganizationInventoryDevicesEoxOverviewResponse",
    "GetOrganizationInventoryDevicesEoxOverviewResponseCounts",
    "GetOrganizationInventoryDevicesResponse",
    "GetOrganizationInventoryDevicesResponseItem",
    "GetOrganizationInventoryDevicesSwapsBulkResponse",
    "GetOrganizationInventoryOnboardingCloudMonitoringImportsResponse",
    "GetOrganizationInventoryOnboardingCloudMonitoringImportsResponseItem",
    "GetOrganizationInventoryOnboardingCloudMonitoringNetworksResponse",
    "GetOrganizationInventoryOnboardingCloudMonitoringNetworksResponseItem",
    "GetOrganizationLicenseResponse",
    "GetOrganizationLicensesOverviewResponse",
    "GetOrganizationLicensesOverviewResponseLicenseTypesItem",
    "GetOrganizationLicensesOverviewResponseStates",
    "GetOrganizationLicensesOverviewResponseSystemsManager",
    "GetOrganizationLicensesResponse",
    "GetOrganizationLicensesResponseItem",
    "GetOrganizationLicensingCotermLicensesResponse",
    "GetOrganizationLicensingCotermLicensesResponseItem",
    "GetOrganizationLoginSecurityResponse",
    "GetOrganizationLoginSecurityResponseApiAuthentication",
    "GetOrganizationNetworksResponse",
    "GetOrganizationNetworksResponseItem",
    "GetOrganizationPoliciesAssignmentsByClientResponse",
    "GetOrganizationPoliciesAssignmentsByClientResponseItem",
    "GetOrganizationPolicyObjectResponse",
    "GetOrganizationPolicyObjectsGroupResponse",
    "GetOrganizationPolicyObjectsGroupsResponse",
    "GetOrganizationPolicyObjectsGroupsResponseItem",
    "GetOrganizationPolicyObjectsResponse",
    "GetOrganizationPolicyObjectsResponseItem",
    "GetOrganizationResponse",
    "GetOrganizationSamlIdpResponse",
    "GetOrganizationSamlIdpsResponse",
    "GetOrganizationSamlIdpsResponseItem",
    "GetOrganizationSamlResponse",
    "GetOrganizationSamlResponseSpInitiated",
    "GetOrganizationSamlRoleResponse",
    "GetOrganizationSamlRolesResponse",
    "GetOrganizationSamlRolesResponseItem",
    "GetOrganizationSensorGatewaysConnectionsLatestResponseItemsItem",
    "GetOrganizationSensorReadingsHistoryResponse",
    "GetOrganizationSensorReadingsHistoryResponseItem",
    "GetOrganizationSensorReadingsLatestResponse",
    "GetOrganizationSensorReadingsLatestResponseItem",
    "GetOrganizationSmAdminsRoleResponse",
    "GetOrganizationSmAdminsRolesResponseItemsItem",
    "GetOrganizationSmApnsCertResponse",
    "GetOrganizationSmSentryPoliciesAssignmentsByNetworkResponse",
    "GetOrganizationSmSentryPoliciesAssignmentsByNetworkResponseItem",
    "GetOrganizationSmVppAccountResponse",
    "GetOrganizationSmVppAccountsResponse",
    "GetOrganizationSmVppAccountsResponseItem",
    "GetOrganizationSnmpResponse",
    "GetOrganizationSpacesIntegrateStatusResponse",
    "GetOrganizationSplashAssetResponse",
    "GetOrganizationSplashThemesResponse",
    "GetOrganizationSplashThemesResponseItem",
    "GetOrganizationSummarySwitchPowerHistoryResponse",
    "GetOrganizationSummarySwitchPowerHistoryResponseItem",
    "GetOrganizationSummaryTopAppliancesByUtilizationResponse",
    "GetOrganizationSummaryTopAppliancesByUtilizationResponseItem",
    "GetOrganizationSummaryTopApplicationsByUsageResponse",
    "GetOrganizationSummaryTopApplicationsByUsageResponseItem",
    "GetOrganizationSummaryTopApplicationsCategoriesByUsageResponse",
    "GetOrganizationSummaryTopApplicationsCategoriesByUsageResponseItem",
    "GetOrganizationSummaryTopClientsByUsageResponse",
    "GetOrganizationSummaryTopClientsByUsageResponseItem",
    "GetOrganizationSummaryTopClientsManufacturersByUsageResponse",
    "GetOrganizationSummaryTopClientsManufacturersByUsageResponseItem",
    "GetOrganizationSummaryTopDevicesByUsageResponse",
    "GetOrganizationSummaryTopDevicesByUsageResponseItem",
    "GetOrganizationSummaryTopDevicesModelsByUsageResponse",
    "GetOrganizationSummaryTopDevicesModelsByUsageResponseItem",
    "GetOrganizationSummaryTopNetworksByStatusResponse",
    "GetOrganizationSummaryTopNetworksByStatusResponseItem",
    "GetOrganizationSummaryTopSsidsByUsageResponse",
    "GetOrganizationSummaryTopSsidsByUsageResponseItem",
    "GetOrganizationSummaryTopSwitchesByEnergyUsageResponse",
    "GetOrganizationSummaryTopSwitchesByEnergyUsageResponseItem",
    "GetOrganizationSwitchPortsBySwitchResponse",
    "GetOrganizationSwitchPortsBySwitchResponsePortsItem",
    "GetOrganizationSwitchPortsClientsOverviewByDeviceResponseItemsItem",
    "GetOrganizationSwitchPortsOverviewResponse",
    "GetOrganizationSwitchPortsOverviewResponseCounts",
    "GetOrganizationSwitchPortsStatusesBySwitchResponseItemsItem",
    "GetOrganizationSwitchPortsTopologyDiscoveryByDeviceResponseItemsItem",
    "GetOrganizationSwitchPortsUsageHistoryByDeviceByIntervalResponseItemsItem",
    "GetOrganizationUplinksStatusesResponse",
    "GetOrganizationUplinksStatusesResponseItem",
    "GetOrganizationWebhooksAlertTypesResponse",
    "GetOrganizationWebhooksAlertTypesResponseExample",
    "GetOrganizationWebhooksCallbacksStatusResponse",
    "GetOrganizationWebhooksCallbacksStatusResponseCreatedBy",
    "GetOrganizationWebhooksCallbacksStatusResponseWebhook",
    "GetOrganizationWebhooksLogsResponse",
    "GetOrganizationWebhooksLogsResponseItem",
    "GetOrganizationWirelessAirMarshalRulesResponseItemsItem",
    "GetOrganizationWirelessAirMarshalSettingsByNetworkResponseItemsItem",
    "GetOrganizationWirelessClientsOverviewByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerAvailabilitiesChangeHistoryResponseItemsItem",
    "GetOrganizationWirelessControllerClientsOverviewHistoryByDeviceByIntervalResponseItemsItem",
    "GetOrganizationWirelessControllerConnectionsResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL2ByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL2StatusesChangeHistoryByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL2UsageHistoryByIntervalResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL3ByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL3StatusesChangeHistoryByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesL3UsageHistoryByIntervalResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesPacketsOverviewByDeviceResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesInterfacesUsageHistoryByIntervalResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesRedundancyFailoverHistoryResponse",
    "GetOrganizationWirelessControllerDevicesRedundancyFailoverHistoryResponseItem",
    "GetOrganizationWirelessControllerDevicesRedundancyStatusesResponseItemsItem",
    "GetOrganizationWirelessControllerDevicesSystemUtilizationHistoryByIntervalResponseItemsItem",
    "GetOrganizationWirelessControllerOverviewByDeviceResponseItemsItem",
    "GetOrganizationWirelessDevicesChannelUtilizationByDeviceResponse",
    "GetOrganizationWirelessDevicesChannelUtilizationByDeviceResponseItem",
    "GetOrganizationWirelessDevicesChannelUtilizationByNetworkResponse",
    "GetOrganizationWirelessDevicesChannelUtilizationByNetworkResponseItem",
    "GetOrganizationWirelessDevicesChannelUtilizationHistoryByDeviceByIntervalResponse",
    "GetOrganizationWirelessDevicesChannelUtilizationHistoryByDeviceByIntervalResponseItem",
    "GetOrganizationWirelessDevicesChannelUtilizationHistoryByNetworkByIntervalResponse",
    "GetOrganizationWirelessDevicesChannelUtilizationHistoryByNetworkByIntervalResponseItem",
    "GetOrganizationWirelessDevicesEthernetStatusesResponse",
    "GetOrganizationWirelessDevicesEthernetStatusesResponseItem",
    "GetOrganizationWirelessDevicesPacketLossByClientResponse",
    "GetOrganizationWirelessDevicesPacketLossByClientResponseItem",
    "GetOrganizationWirelessDevicesPacketLossByDeviceResponse",
    "GetOrganizationWirelessDevicesPacketLossByDeviceResponseItem",
    "GetOrganizationWirelessDevicesPacketLossByNetworkResponse",
    "GetOrganizationWirelessDevicesPacketLossByNetworkResponseItem",
    "GetOrganizationWirelessDevicesPowerModeHistoryResponseItemsItem",
    "GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesCrlsDeltasResponseItemsItem",
    "GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesCrlsResponseItemsItem",
    "GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponse",
    "GetOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponseItem",
    "GetOrganizationWirelessDevicesSystemCpuLoadHistoryResponseItemsItem",
    "GetOrganizationWirelessDevicesWirelessControllersByDeviceResponseItemsItem",
    "GetOrganizationWirelessLocationScanningByNetworkResponseItemsItem",
    "GetOrganizationWirelessLocationScanningReceiversResponseItemsItem",
    "GetOrganizationWirelessMqttSettingsResponseItemsItem",
    "GetOrganizationWirelessRadioRrmByNetworkResponseItemsItem",
    "GetOrganizationWirelessRfProfilesAssignmentsByDeviceResponse",
    "GetOrganizationWirelessRfProfilesAssignmentsByDeviceResponseItem",
    "GetOrganizationWirelessSsidsFirewallIsolationAllowlistEntriesResponseItemsItem",
    "GetOrganizationWirelessSsidsOpenRoamingByNetworkResponseItemsItem",
    "GetOrganizationWirelessSsidsStatusesByDeviceResponseItemsItem",
    "GetOrganizationWirelessZigbeeByNetworkResponse",
    "GetOrganizationWirelessZigbeeByNetworkResponseItem",
    "GetOrganizationWirelessZigbeeDevicesResponse",
    "GetOrganizationWirelessZigbeeDevicesResponseItem",
    "GetOrganizationWirelessZigbeeDisenrollmentResponse",
    "GetOrganizationWirelessZigbeeDisenrollmentResponseDoorLocksItem",
    "GetOrganizationWirelessZigbeeDoorLocksResponse",
    "GetOrganizationWirelessZigbeeDoorLocksResponseItem",
    "GetOrganizationsResponse",
    "GetOrganizationsResponseItem",
    "InsightByNetworkItem",
    "InsightThresholds",
    "LicensingAccount",
    "LicensingByProductClassItem",
    "LicensingCounts",
    "LicensingCountsItem",
    "LicensingEditionsItem",
    "LicensingEnterpriseAgreement",
    "LicensingEntitlementsItem",
    "LicensingEntitlementsItem2",
    "LicensingMissing",
    "LicensingSeats",
    "LicensingSmartAccount",
    "LicensingSubscription",
    "LicensingViolations",
    "LockNetworkSmDevicesResponse",
    "ModifyNetworkSmDevicesTagsResponse",
    "ModifyNetworkSmDevicesTagsResponseItem",
    "MoveNetworkSmDevicesResponse",
    "MoveOrganizationLicensesResponse",
    "MoveOrganizationLicensesSeatsResponse",
    "MoveOrganizationLicensingCotermLicensesDestination",
    "MoveOrganizationLicensingCotermLicensesLicensesItem",
    "MoveOrganizationLicensingCotermLicensesLicensesItemCountsItem",
    "MoveOrganizationLicensingCotermLicensesResponse",
    "MoveOrganizationLicensingCotermLicensesResponseRemainderLicensesItem",
    "NetworksAlertsAlertDestinations",
    "NetworksAlertsFilters",
    "NetworksAllowedUrlPatterns",
    "NetworksApplicationUsageItem",
    "NetworksApplicationsItem",
    "NetworksAssignedDevices",
    "NetworksAssignedItem",
    "NetworksAuthentication",
    "NetworksAuthorizationsItem",
    "NetworksBandwidth",
    "NetworksBandwidthLimits",
    "NetworksBeaconIdParams",
    "NetworksBlockedUrlCategories",
    "NetworksBonjourForwarding",
    "NetworksByNetwork",
    "NetworksCdp",
    "NetworksCdp2",
    "NetworksCenter",
    "NetworksClients",
    "NetworksClientsItem",
    "NetworksConditionsItem",
    "NetworksContentFiltering",
    "NetworksCounts",
    "NetworksCurrentVersion",
    "NetworksDefinitionsItem",
    "NetworksDestinations",
    "NetworksDetailsItem",
    "NetworksDevice",
    "NetworksDevicesItem",
    "NetworksDevicesItem2",
    "NetworksDevicesItem3",
    "NetworksDiscovered",
    "NetworksEmail",
    "NetworksEventsEventData",
    "NetworksFirewallAndTrafficShaping",
    "NetworksHeadersItem",
    "NetworksJobsCompleted",
    "NetworksJobsErrorsItem",
    "NetworksJobsRanging",
    "NetworksL3FirewallRulesItem",
    "NetworksL7FirewallRulesItem",
    "NetworksLastUpgrade",
    "NetworksLinksEndsItem",
    "NetworksLldp",
    "NetworksLldp2",
    "NetworksLldp3",
    "NetworksLocalStatusPageAuthentication",
    "NetworksMonday",
    "NetworksMutingByPortSchedules",
    "NetworksNextUpgrade",
    "NetworksNextUpgrade2",
    "NetworksNextUpgrade3",
    "NetworksNextUpgrade4",
    "NetworksNode",
    "NetworksNodesDevice",
    "NetworksNodesDiscovered",
    "NetworksNodesStack",
    "NetworksPayloadTemplate",
    "NetworksPeersItem",
    "NetworksPerClientBandwidthLimits",
    "NetworksProductsSwitch",
    "NetworksProductsWireless",
    "NetworksRulesItem",
    "NetworksScheduling",
    "NetworksScope",
    "NetworksSecurity",
    "NetworksSharing",
    "NetworksSsidItem",
    "NetworksStagesGroup",
    "NetworksStagesMilestones",
    "NetworksSwitchStacksItem",
    "NetworksTls",
    "NetworksToVersion",
    "NetworksToVersion2",
    "NetworksTrafficShapingRulesItem",
    "NetworksUplinksItem",
    "NetworksUsage",
    "NetworksUsageHistoryItem",
    "NetworksVlanGroupsItem",
    "NetworksVlanNamesItem",
    "NetworksVlanProfile",
    "NetworksVlanTagging",
    "NetworksWifi0Item",
    "OrganizationsAccessList",
    "OrganizationsActionsItem",
    "OrganizationsAddressesItem",
    "OrganizationsAdminSettings",
    "OrganizationsAlertCondition",
    "OrganizationsApi",
    "OrganizationsApiAuthenticationIpRestrictionsForKeys",
    "OrganizationsAssignedItem",
    "OrganizationsAuthentication",
    "OrganizationsAutoLocate",
    "OrganizationsAverage",
    "OrganizationsByAlertTypeItem",
    "OrganizationsByProductTypeItem",
    "OrganizationsByProductTypeItem2",
    "OrganizationsCameraItem",
    "OrganizationsClient",
    "OrganizationsClient2",
    "OrganizationsClient3",
    "OrganizationsClients",
    "OrganizationsClients2",
    "OrganizationsCloud",
    "OrganizationsCodesByIntervalResponseCountsItem",
    "OrganizationsCompleted",
    "OrganizationsComponents",
    "OrganizationsConfigParams",
    "OrganizationsCounts",
    "OrganizationsCounts2",
    "OrganizationsCountsBySeverityItem",
    "OrganizationsCountsByStatus",
    "OrganizationsCountsByStatus2",
    "OrganizationsCreatedResourcesItem",
    "OrganizationsCritical",
    "OrganizationsCustomLogo",
    "OrganizationsDescriptions",
    "OrganizationsDetails",
    "OrganizationsDetailsItem",
    "OrganizationsDetailsItem2",
    "OrganizationsDevice",
    "OrganizationsDevice2",
    "OrganizationsDevice3",
    "OrganizationsDevice4",
    "OrganizationsDevices",
    "OrganizationsDevicesItem",
    "OrganizationsDevicesItem2",
    "OrganizationsDevicesItem3",
    "OrganizationsEox",
    "OrganizationsErrorsItem",
    "OrganizationsFile",
    "OrganizationsFree",
    "OrganizationsFromVersion",
    "OrganizationsHelpSettings",
    "OrganizationsHighAvailability",
    "OrganizationsHost",
    "OrganizationsImage",
    "OrganizationsInitiator",
    "OrganizationsIntervalsItem",
    "OrganizationsJobsItem",
    "OrganizationsLicenseTypesCounts",
    "OrganizationsLicensing",
    "OrganizationsLimitToItem",
    "OrganizationsLldp",
    "OrganizationsManagement",
    "OrganizationsMemory",
    "OrganizationsNameservers",
    "OrganizationsNetwork",
    "OrganizationsNetwork2",
    "OrganizationsNetwork3",
    "OrganizationsNetworksItem",
    "OrganizationsOld",
    "OrganizationsOldestActivation",
    "OrganizationsOptOutEligibilityHelp",
    "OrganizationsOrganizations",
    "OrganizationsPercentages",
    "OrganizationsPermanentlyQueuedLicensesItem",
    "OrganizationsPoe",
    "OrganizationsPolicyObjectsItem",
    "OrganizationsPowerSuppliesItem",
    "OrganizationsPreview",
    "OrganizationsPublic",
    "OrganizationsRanging",
    "OrganizationsRecipients",
    "OrganizationsRecordsClientVpnConnectionsItem",
    "OrganizationsRecordsNetwork",
    "OrganizationsRegion",
    "OrganizationsResult",
    "OrganizationsRoaming",
    "OrganizationsRootCertificate",
    "OrganizationsRulesItem",
    "OrganizationsSchedule",
    "OrganizationsScope",
    "OrganizationsSeats",
    "OrganizationsSecret",
    "OrganizationsSeveritiesItem",
    "OrganizationsSeverityCountsItem",
    "OrganizationsShippingPending",
    "OrganizationsShippingShipmentsItem",
    "OrganizationsSignalStat",
    "OrganizationsSlotsItem",
    "OrganizationsSoonestActivation",
    "OrganizationsSourceGroup",
    "OrganizationsSsidsItem",
    "OrganizationsStaged",
    "OrganizationsStatesActive",
    "OrganizationsStatesExpiring",
    "OrganizationsStatesUnused",
    "OrganizationsStatesUnusedActive",
    "OrganizationsStatus",
    "OrganizationsStatuses",
    "OrganizationsSubscriptionsCounts",
    "OrganizationsSwapsDevices",
    "OrganizationsSystemsManagerCounts",
    "OrganizationsTagsItem",
    "OrganizationsTimeSeriesItem",
    "OrganizationsToVersion",
    "OrganizationsTotals",
    "OrganizationsTunnel",
    "OrganizationsUpgrade",
    "OrganizationsUplinksItem",
    "OrganizationsUplinksItem2",
    "OrganizationsUsage",
    "OrganizationsUsage2",
    "OrganizationsUsage3",
    "OrganizationsUsage4",
    "OrganizationsUsage5",
    "OrganizationsUsageOverall",
    "OrganizationsUsed",
    "OrganizationsUsed2",
    "OrganizationsUser",
    "OrganizationsUtilization",
    "PreviewOrganizationInventoryOrdersResponse",
    "PreviewOrganizationInventoryOrdersResponseShipping",
    "ProvisionNetworkClientsClientsItem",
    "ProvisionNetworkClientsPoliciesBySecurityAppliance",
    "ProvisionNetworkClientsPoliciesBySsid",
    "ProvisionNetworkClientsPoliciesBySsid0",
    "ProvisionNetworkClientsResponse",
    "ProvisionNetworkClientsResponseClientsItem",
    "PublishNetworkFloorPlansAutoLocateJobDevicesItem",
    "PublishNetworkFloorPlansAutoLocateJobDevicesItemAutoLocate",
    "PublishNetworkFloorPlansAutoLocateJobResponse",
    "ReassignNetworkVlanProfilesAssignmentsResponse",
    "ReassignNetworkVlanProfilesAssignmentsResponseVlanProfile",
    "ReassignNetworkVlanProfilesAssignmentsVlanProfile",
    "RebootDeviceResponse",
    "RebootNetworkSmDevicesResponse",
    "RecalculateNetworkFloorPlansAutoLocateJobDevicesItem",
    "RecalculateNetworkFloorPlansAutoLocateJobDevicesItemAutoLocate",
    "RecalculateNetworkFloorPlansAutoLocateJobResponse",
    "RecalculateOrganizationWirelessRadioAutoRfChannelsResponse",
    "ReleaseFromOrganizationInventoryResponse",
    "RemoveNetworkSwitchStackResponse",
    "RemoveOrganizationSpacesIntegrationResponse",
    "RenewOrganizationLicensesSeatsResponse",
    "ReorderOrganizationDevicesPacketCaptureSchedulesOrderItem",
    "ReorderOrganizationDevicesPacketCaptureSchedulesResponse",
    "ReorderOrganizationDevicesPacketCaptureSchedulesResponseUpdatedPrioritiesItem",
    "RollbacksNetworkFirmwareUpgradesStagedEventsReasonsItem",
    "RollbacksNetworkFirmwareUpgradesStagedEventsResponse",
    "RollbacksNetworkFirmwareUpgradesStagedEventsStagesItem",
    "SensorAmbient",
    "SensorAmbient2",
    "SensorApparentPower",
    "SensorBattery",
    "SensorButton",
    "SensorCo2",
    "SensorConditionsItem",
    "SensorCountsNoise",
    "SensorCreatedBy",
    "SensorDevice",
    "SensorDoor",
    "SensorDoor2",
    "SensorDownstreamPower",
    "SensorFrequency",
    "SensorHumidity",
    "SensorHumidity2",
    "SensorIndoorAirQuality",
    "SensorIndoorAirQuality2",
    "SensorLivestreamRelatedDevicesItem",
    "SensorNetwork",
    "SensorNoise",
    "SensorNoise2",
    "SensorPowerFactor",
    "SensorReadingsItem",
    "SensorRealPower",
    "SensorRecipients",
    "SensorRelationships",
    "SensorRemoteLockoutSwitch",
    "SensorSchedule",
    "SensorSensor",
    "SensorTemperature",
    "SensorTemperature2",
    "SensorThreshold",
    "SensorTvoc",
    "SensorUpstreamPower",
    "SensorVoltage",
    "SensorWater",
    "SensorWater2",
    "SetNetworkWirelessEthernetPortsProfilesDefaultResponse",
    "ShutdownNetworkSmDevicesResponse",
    "SmC",
    "SmDiskUsage",
    "SmParsedToken",
    "SmPoliciesItem",
    "SmTrustedAccessConnectionsItem",
    "SplitNetworkResponse",
    "SplitNetworkResponseResultingNetworksItem",
    "StopOrganizationDevicesPacketCaptureCaptureResponse",
    "SwapNetworkApplianceWarmSpareResponse",
    "SwitchActive",
    "SwitchAuthentication",
    "SwitchBandwidth",
    "SwitchByMedia",
    "SwitchByMediaAndLinkSpeed",
    "SwitchByStatus",
    "SwitchCache",
    "SwitchCdp",
    "SwitchConfigOverrides",
    "SwitchCounts",
    "SwitchCounts2",
    "SwitchCountsByStatus",
    "SwitchCriticalAuth",
    "SwitchData",
    "SwitchDevice",
    "SwitchDot1x",
    "SwitchDot3az",
    "SwitchDscp",
    "SwitchEnergy",
    "SwitchEthernet",
    "SwitchFields",
    "SwitchInactive",
    "SwitchInterface",
    "SwitchIntervalsItem",
    "SwitchIp",
    "SwitchIpv4",
    "SwitchIpv6",
    "SwitchIpv42",
    "SwitchLastAck",
    "SwitchLastPacket",
    "SwitchLldp",
    "SwitchMembersItem",
    "SwitchMirror",
    "SwitchModule",
    "SwitchMonday",
    "SwitchOptionsItem",
    "SwitchOspfSettings",
    "SwitchPacketsItem",
    "SwitchPoe",
    "SwitchPortSchedule",
    "SwitchPorts",
    "SwitchPortsItem",
    "SwitchPortsItem2",
    "SwitchPortsItem3",
    "SwitchPortsItem4",
    "SwitchProfile",
    "SwitchRadius",
    "SwitchRadiusServersItem",
    "SwitchRj45",
    "SwitchRj452",
    "SwitchSchedule",
    "SwitchSecurePort",
    "SwitchSecurePort2",
    "SwitchSeenByItem",
    "SwitchSfp",
    "SwitchSource",
    "SwitchSpanningTree",
    "SwitchSwitchPortsItem",
    "SwitchTrafficInKbps",
    "SwitchUdp",
    "SwitchUsage",
    "SwitchUsage2",
    "SwitchUsage3",
    "SwitchUsageInKb",
    "SwitchVrf",
    "SwitchVrf2",
    "UnbindNetworkResponse",
    "UnenrollNetworkSmDeviceResponse",
    "UpdateDeviceApplianceRadioSettingsFiveGhzSettings",
    "UpdateDeviceApplianceRadioSettingsResponse",
    "UpdateDeviceApplianceRadioSettingsTwoFourGhzSettings",
    "UpdateDeviceApplianceUplinksSettingsInterfaces",
    "UpdateDeviceApplianceUplinksSettingsInterfacesWan1",
    "UpdateDeviceApplianceUplinksSettingsResponse",
    "UpdateDeviceCameraCustomAnalyticsParametersItem",
    "UpdateDeviceCameraCustomAnalyticsResponse",
    "UpdateDeviceCameraSenseAudioDetection",
    "UpdateDeviceCameraVideoSettingsResponse",
    "UpdateDeviceCameraWirelessProfilesIds",
    "UpdateDeviceCellularGatewayLanFixedIpAssignmentsItem",
    "UpdateDeviceCellularGatewayLanReservedIpRangesItem",
    "UpdateDeviceCellularGatewayLanResponse",
    "UpdateDeviceCellularGatewayPortForwardingRulesResponse",
    "UpdateDeviceCellularGatewayPortForwardingRulesRulesItem",
    "UpdateDeviceCellularSimsResponse",
    "UpdateDeviceCellularSimsSimFailover",
    "UpdateDeviceCellularSimsSimsItem",
    "UpdateDeviceManagementInterfaceResponse",
    "UpdateDeviceManagementInterfaceWan1",
    "UpdateDeviceManagementInterfaceWan2",
    "UpdateDeviceResponse",
    "UpdateDeviceSensorRelationshipsLivestream",
    "UpdateDeviceSensorRelationshipsLivestreamRelatedDevicesItem",
    "UpdateDeviceSensorRelationshipsResponse",
    "UpdateDeviceSwitchPortDot3az",
    "UpdateDeviceSwitchPortHighSpeed",
    "UpdateDeviceSwitchPortProfile",
    "UpdateDeviceSwitchPortResponse",
    "UpdateDeviceSwitchRoutingInterfaceDhcpDhcpOptionsItem",
    "UpdateDeviceSwitchRoutingInterfaceDhcpFixedIpAssignmentsItem",
    "UpdateDeviceSwitchRoutingInterfaceDhcpReservedIpRangesItem",
    "UpdateDeviceSwitchRoutingInterfaceDhcpResponse",
    "UpdateDeviceSwitchRoutingInterfaceIpv6",
    "UpdateDeviceSwitchRoutingInterfaceOspfSettings",
    "UpdateDeviceSwitchRoutingInterfaceResponse",
    "UpdateDeviceSwitchRoutingInterfaceVrf",
    "UpdateDeviceSwitchRoutingStaticRouteResponse",
    "UpdateDeviceSwitchRoutingStaticRouteVrf",
    "UpdateDeviceSwitchWarmSpareResponse",
    "UpdateDeviceWirelessAlternateManagementInterfaceIpv6AddressesItem",
    "UpdateDeviceWirelessAlternateManagementInterfaceIpv6Response",
    "UpdateDeviceWirelessAlternateManagementInterfaceIpv6ResponseAddressesItem",
    "UpdateDeviceWirelessBluetoothSettingsResponse",
    "UpdateDeviceWirelessElectronicShelfLabelResponse",
    "UpdateDeviceWirelessRadioSettingsFiveGhzSettings",
    "UpdateDeviceWirelessRadioSettingsResponse",
    "UpdateDeviceWirelessRadioSettingsTwoFourGhzSettings",
    "UpdateNetworkAlertsSettingsAlertsItem",
    "UpdateNetworkAlertsSettingsDefaultDestinations",
    "UpdateNetworkAlertsSettingsMuting",
    "UpdateNetworkAlertsSettingsResponse",
    "UpdateNetworkApplianceConnectivityMonitoringDestinationsDestinationsItem",
    "UpdateNetworkApplianceConnectivityMonitoringDestinationsResponse",
    "UpdateNetworkApplianceContentFilteringResponse",
    "UpdateNetworkApplianceFirewallCellularFirewallRulesRulesItem",
    "UpdateNetworkApplianceFirewallFirewalledServiceResponse",
    "UpdateNetworkApplianceFirewallInboundCellularFirewallRulesResponse",
    "UpdateNetworkApplianceFirewallInboundCellularFirewallRulesRulesItem",
    "UpdateNetworkApplianceFirewallInboundFirewallRulesResponse",
    "UpdateNetworkApplianceFirewallInboundFirewallRulesRulesItem",
    "UpdateNetworkApplianceFirewallL3FirewallRulesRulesItem",
    "UpdateNetworkApplianceFirewallL7FirewallRulesRulesItem",
    "UpdateNetworkApplianceFirewallMulticastForwardingResponse",
    "UpdateNetworkApplianceFirewallMulticastForwardingResponseNetwork",
    "UpdateNetworkApplianceFirewallMulticastForwardingResponseRulesItem",
    "UpdateNetworkApplianceFirewallMulticastForwardingRulesItem",
    "UpdateNetworkApplianceFirewallOneToManyNatRulesRulesItem",
    "UpdateNetworkApplianceFirewallOneToManyNatRulesRulesItemPortRulesItem",
    "UpdateNetworkApplianceFirewallOneToOneNatRulesRulesItem",
    "UpdateNetworkApplianceFirewallOneToOneNatRulesRulesItemAllowedInboundItem",
    "UpdateNetworkApplianceFirewallPortForwardingRulesResponse",
    "UpdateNetworkApplianceFirewallPortForwardingRulesRulesItem",
    "UpdateNetworkApplianceFirewallSettingsSpoofingProtection",
    "UpdateNetworkApplianceFirewallSettingsSpoofingProtectionIpSourceGuard",
    "UpdateNetworkAppliancePortResponse",
    "UpdateNetworkAppliancePrefixesDelegatedStaticOrigin",
    "UpdateNetworkApplianceRfProfileFiveGhzSettings",
    "UpdateNetworkApplianceRfProfilePerSsidSettings",
    "UpdateNetworkApplianceRfProfileResponse",
    "UpdateNetworkApplianceRfProfileTwoFourGhzSettings",
    "UpdateNetworkApplianceSdwanInternetPoliciesResponse",
    "UpdateNetworkApplianceSdwanInternetPoliciesWanTrafficUplinkPreferencesItem",
    "UpdateNetworkApplianceSecurityIntrusionProtectedNetworks",
    "UpdateNetworkApplianceSecurityIntrusionResponse",
    "UpdateNetworkApplianceSecurityMalwareAllowedFilesItem",
    "UpdateNetworkApplianceSecurityMalwareAllowedUrlsItem",
    "UpdateNetworkApplianceSecurityMalwareResponse",
    "UpdateNetworkApplianceSettingsDynamicDns",
    "UpdateNetworkApplianceSettingsResponse",
    "UpdateNetworkApplianceSingleLanIpv6",
    "UpdateNetworkApplianceSingleLanIpv6PrefixAssignmentsItem",
    "UpdateNetworkApplianceSingleLanMandatoryDhcp",
    "UpdateNetworkApplianceSingleLanResponse",
    "UpdateNetworkApplianceSsidDhcpEnforcedDeauthentication",
    "UpdateNetworkApplianceSsidDot11w",
    "UpdateNetworkApplianceSsidRadiusServersItem",
    "UpdateNetworkApplianceSsidResponse",
    "UpdateNetworkApplianceStaticRouteFixedIpAssignmentsValue",
    "UpdateNetworkApplianceStaticRouteReservedIpRangesItem",
    "UpdateNetworkApplianceStaticRouteResponse",
    "UpdateNetworkApplianceTrafficShapingCustomPerformanceClassResponse",
    "UpdateNetworkApplianceTrafficShapingGlobalBandwidthLimits",
    "UpdateNetworkApplianceTrafficShapingRulesRulesItem",
    "UpdateNetworkApplianceTrafficShapingRulesRulesItemDefinitionsItem",
    "UpdateNetworkApplianceTrafficShapingRulesRulesItemPerClientBandwidthLimits",
    "UpdateNetworkApplianceTrafficShapingUplinkBandwidthBandwidthLimits",
    "UpdateNetworkApplianceTrafficShapingUplinkSelectionFailoverAndFailback",
    "UpdateNetworkApplianceTrafficShapingUplinkSelectionResponse",
    "UpdateNetworkApplianceTrafficShapingUplinkSelectionVpnTrafficUplinkPreferencesItem",
    "UpdateNetworkApplianceTrafficShapingUplinkSelectionWanTrafficUplinkPreferencesItem",
    "UpdateNetworkApplianceTrafficShapingVpnExclusionsCustomItem",
    "UpdateNetworkApplianceTrafficShapingVpnExclusionsMajorApplicationsItem",
    "UpdateNetworkApplianceTrafficShapingVpnExclusionsResponse",
    "UpdateNetworkApplianceTrafficShapingVpnExclusionsResponseCustomItem",
    "UpdateNetworkApplianceTrafficShapingVpnExclusionsResponseMajorApplicationsItem",
    "UpdateNetworkApplianceVlanDhcpOptionsItem",
    "UpdateNetworkApplianceVlanIpv6",
    "UpdateNetworkApplianceVlanIpv6PrefixAssignmentsItem",
    "UpdateNetworkApplianceVlanMandatoryDhcp",
    "UpdateNetworkApplianceVlanReservedIpRangesItem",
    "UpdateNetworkApplianceVlanResponse",
    "UpdateNetworkApplianceVlansSettingsResponse",
    "UpdateNetworkApplianceVpnBgpNeighborsItem",
    "UpdateNetworkApplianceVpnBgpNeighborsItemIpv6",
    "UpdateNetworkApplianceVpnBgpResponse",
    "UpdateNetworkApplianceVpnSiteToSiteVpnHubsItem",
    "UpdateNetworkApplianceVpnSiteToSiteVpnResponse",
    "UpdateNetworkApplianceVpnSiteToSiteVpnSubnet",
    "UpdateNetworkApplianceVpnSiteToSiteVpnSubnetsItem",
    "UpdateNetworkApplianceWarmSpareResponse",
    "UpdateNetworkCameraQualityRetentionProfileResponse",
    "UpdateNetworkCameraQualityRetentionProfileSmartRetention",
    "UpdateNetworkCameraQualityRetentionProfileVideoSettings",
    "UpdateNetworkCameraWirelessProfileIdentity",
    "UpdateNetworkCameraWirelessProfileResponse",
    "UpdateNetworkCameraWirelessProfileSsid",
    "UpdateNetworkCampusGatewayClusterDevicesItem",
    "UpdateNetworkCampusGatewayClusterDevicesItemUplinksItem",
    "UpdateNetworkCampusGatewayClusterNameservers",
    "UpdateNetworkCampusGatewayClusterPortChannelsItem",
    "UpdateNetworkCampusGatewayClusterResponse",
    "UpdateNetworkCampusGatewayClusterTunnelsItem",
    "UpdateNetworkCampusGatewayClusterTunnelsItemAddressesItem",
    "UpdateNetworkCampusGatewayClusterUplinksItem",
    "UpdateNetworkCampusGatewayClusterUplinksItemAddressesItem",
    "UpdateNetworkCellularGatewayConnectivityMonitoringDestinationsDestinationsItem",
    "UpdateNetworkCellularGatewayConnectivityMonitoringDestinationsResponse",
    "UpdateNetworkCellularGatewayDhcpResponse",
    "UpdateNetworkCellularGatewaySubnetPoolResponse",
    "UpdateNetworkCellularGatewayUplinkBandwidthLimits",
    "UpdateNetworkCellularGatewayUplinkResponse",
    "UpdateNetworkClientPolicyResponse",
    "UpdateNetworkClientSplashAuthorizationStatusSsids",
    "UpdateNetworkClientSplashAuthorizationStatusSsids0",
    "UpdateNetworkFirmwareUpgradesProducts",
    "UpdateNetworkFirmwareUpgradesProductsWireless",
    "UpdateNetworkFirmwareUpgradesResponse",
    "UpdateNetworkFirmwareUpgradesStagedEventsResponse",
    "UpdateNetworkFirmwareUpgradesStagedEventsStagesItem",
    "UpdateNetworkFirmwareUpgradesStagedEventsStagesItemGroup",
    "UpdateNetworkFirmwareUpgradesStagedEventsStagesItemMilestones",
    "UpdateNetworkFirmwareUpgradesStagedGroupAssignedDevices",
    "UpdateNetworkFirmwareUpgradesStagedGroupResponse",
    "UpdateNetworkFirmwareUpgradesStagedStagesJsonItem",
    "UpdateNetworkFirmwareUpgradesStagedStagesResponse",
    "UpdateNetworkFirmwareUpgradesStagedStagesResponseItem",
    "UpdateNetworkFirmwareUpgradesUpgradeWindow",
    "UpdateNetworkFloorPlanBottomLeftCorner",
    "UpdateNetworkFloorPlanBottomRightCorner",
    "UpdateNetworkFloorPlanCenter",
    "UpdateNetworkFloorPlanResponse",
    "UpdateNetworkFloorPlanTopLeftCorner",
    "UpdateNetworkFloorPlanTopRightCorner",
    "UpdateNetworkGroupPolicyBandwidth",
    "UpdateNetworkGroupPolicyBonjourForwarding",
    "UpdateNetworkGroupPolicyContentFiltering",
    "UpdateNetworkGroupPolicyFirewallAndTrafficShaping",
    "UpdateNetworkGroupPolicyResponse",
    "UpdateNetworkGroupPolicyScheduling",
    "UpdateNetworkGroupPolicyVlanTagging",
    "UpdateNetworkMerakiAuthUserAuthorizationsItem",
    "UpdateNetworkMerakiAuthUserResponse",
    "UpdateNetworkMqttBrokerAuthentication",
    "UpdateNetworkMqttBrokerResponse",
    "UpdateNetworkMqttBrokerSecurity",
    "UpdateNetworkNetflowResponse",
    "UpdateNetworkResponse",
    "UpdateNetworkSensorAlertsProfileConditionsItem",
    "UpdateNetworkSensorAlertsProfileRecipients",
    "UpdateNetworkSensorAlertsProfileResponse",
    "UpdateNetworkSensorAlertsProfileSchedule",
    "UpdateNetworkSensorMqttBrokerResponse",
    "UpdateNetworkSettingsLocalStatusPage",
    "UpdateNetworkSettingsLocalStatusPageAuthentication",
    "UpdateNetworkSettingsNamedVlans",
    "UpdateNetworkSettingsResponse",
    "UpdateNetworkSettingsSecurePort",
    "UpdateNetworkSmDevicesFieldsDeviceFields",
    "UpdateNetworkSmDevicesFieldsResponse",
    "UpdateNetworkSmDevicesFieldsResponseItem",
    "UpdateNetworkSmTargetGroupResponse",
    "UpdateNetworkSnmpResponse",
    "UpdateNetworkSnmpUsersItem",
    "UpdateNetworkSwitchAccessControlListsResponse",
    "UpdateNetworkSwitchAccessControlListsRulesItem",
    "UpdateNetworkSwitchAccessPolicyDot1x",
    "UpdateNetworkSwitchAccessPolicyRadius",
    "UpdateNetworkSwitchAccessPolicyRadiusAccountingServersItem",
    "UpdateNetworkSwitchAccessPolicyRadiusServersItem",
    "UpdateNetworkSwitchAccessPolicyResponse",
    "UpdateNetworkSwitchAlternateManagementInterfaceResponse",
    "UpdateNetworkSwitchAlternateManagementInterfaceSwitchesItem",
    "UpdateNetworkSwitchDhcpServerPolicyAlerts",
    "UpdateNetworkSwitchDhcpServerPolicyArpInspection",
    "UpdateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerIpv4",
    "UpdateNetworkSwitchDhcpServerPolicyArpInspectionTrustedServerResponse",
    "UpdateNetworkSwitchDhcpServerPolicyResponse",
    "UpdateNetworkSwitchDscpToCosMappingsMappingsItem",
    "UpdateNetworkSwitchDscpToCosMappingsResponse",
    "UpdateNetworkSwitchLinkAggregationResponse",
    "UpdateNetworkSwitchLinkAggregationSwitchPortsItem",
    "UpdateNetworkSwitchLinkAggregationSwitchProfilePortsItem",
    "UpdateNetworkSwitchMtuOverridesItem",
    "UpdateNetworkSwitchMtuResponse",
    "UpdateNetworkSwitchPortSchedulePortSchedule",
    "UpdateNetworkSwitchPortScheduleResponse",
    "UpdateNetworkSwitchQosRuleResponse",
    "UpdateNetworkSwitchQosRulesOrderResponse",
    "UpdateNetworkSwitchRoutingMulticastDefaultSettings",
    "UpdateNetworkSwitchRoutingMulticastOverridesItem",
    "UpdateNetworkSwitchRoutingMulticastRendezvousPointResponse",
    "UpdateNetworkSwitchRoutingMulticastRendezvousPointVrf",
    "UpdateNetworkSwitchRoutingMulticastResponse",
    "UpdateNetworkSwitchRoutingOspfAreasItem",
    "UpdateNetworkSwitchRoutingOspfMd5AuthenticationKey",
    "UpdateNetworkSwitchRoutingOspfResponse",
    "UpdateNetworkSwitchRoutingOspfV3",
    "UpdateNetworkSwitchRoutingOspfV3AreasItem",
    "UpdateNetworkSwitchSettingsMacBlocklist",
    "UpdateNetworkSwitchSettingsPowerExceptionsItem",
    "UpdateNetworkSwitchSettingsResponse",
    "UpdateNetworkSwitchSettingsUplinkClientSampling",
    "UpdateNetworkSwitchSettingsUplinkSelection",
    "UpdateNetworkSwitchSettingsUplinkSelectionFailback",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpOptionsItem",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpFixedIpAssignmentsItem",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpReservedIpRangesItem",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpResponse",
    "UpdateNetworkSwitchStackRoutingInterfaceIpv6",
    "UpdateNetworkSwitchStackRoutingInterfaceOspfSettings",
    "UpdateNetworkSwitchStackRoutingInterfaceResponse",
    "UpdateNetworkSwitchStackRoutingInterfaceVrf",
    "UpdateNetworkSwitchStackRoutingStaticRouteResponse",
    "UpdateNetworkSwitchStackRoutingStaticRouteVrf",
    "UpdateNetworkSwitchStormControlResponse",
    "UpdateNetworkSwitchStpResponse",
    "UpdateNetworkSwitchStpStpBridgePriorityItem",
    "UpdateNetworkSyslogServersResponse",
    "UpdateNetworkSyslogServersServersItem",
    "UpdateNetworkTrafficAnalysisCustomPieChartItemsItem",
    "UpdateNetworkTrafficAnalysisResponse",
    "UpdateNetworkVlanProfileResponse",
    "UpdateNetworkVlanProfileVlanGroupsItem",
    "UpdateNetworkVlanProfileVlanNamesItem",
    "UpdateNetworkWebhooksHttpServerPayloadTemplate",
    "UpdateNetworkWebhooksHttpServerResponse",
    "UpdateNetworkWebhooksPayloadTemplateHeadersItem",
    "UpdateNetworkWebhooksPayloadTemplateResponse",
    "UpdateNetworkWirelessAirMarshalRuleMatch",
    "UpdateNetworkWirelessAirMarshalRuleResponse",
    "UpdateNetworkWirelessAirMarshalSettingsResponse",
    "UpdateNetworkWirelessAlternateManagementInterfaceAccessPointsItem",
    "UpdateNetworkWirelessBillingPlansItem",
    "UpdateNetworkWirelessBillingResponse",
    "UpdateNetworkWirelessBluetoothSettingsResponse",
    "UpdateNetworkWirelessElectronicShelfLabelResponse",
    "UpdateNetworkWirelessEthernetPortsProfilePortsItem",
    "UpdateNetworkWirelessEthernetPortsProfileResponse",
    "UpdateNetworkWirelessEthernetPortsProfileUsbPortsItem",
    "UpdateNetworkWirelessLocationScanningApi",
    "UpdateNetworkWirelessLocationScanningResponse",
    "UpdateNetworkWirelessLocationScanningResponseApi",
    "UpdateNetworkWirelessRadioRrmAi",
    "UpdateNetworkWirelessRadioRrmBusyHour",
    "UpdateNetworkWirelessRadioRrmBusyHourSchedule",
    "UpdateNetworkWirelessRadioRrmChannel",
    "UpdateNetworkWirelessRadioRrmFra",
    "UpdateNetworkWirelessRadioRrmResponse",
    "UpdateNetworkWirelessRadioRrmResponseAi",
    "UpdateNetworkWirelessRadioRrmResponseBusyHour",
    "UpdateNetworkWirelessRadioRrmResponseChannel",
    "UpdateNetworkWirelessRfProfileApBandSettings",
    "UpdateNetworkWirelessRfProfileFiveGhzSettings",
    "UpdateNetworkWirelessRfProfileFlexRadios",
    "UpdateNetworkWirelessRfProfilePerSsidSettings",
    "UpdateNetworkWirelessRfProfileResponse",
    "UpdateNetworkWirelessRfProfileSixGhzSettings",
    "UpdateNetworkWirelessRfProfileTransmission",
    "UpdateNetworkWirelessRfProfileTwoFourGhzSettings",
    "UpdateNetworkWirelessSettingsMulticastToUnicastConversion",
    "UpdateNetworkWirelessSettingsNamedVlans",
    "UpdateNetworkWirelessSettingsResponse",
    "UpdateNetworkWirelessSsidActiveDirectory",
    "UpdateNetworkWirelessSsidActiveDirectoryCredentials",
    "UpdateNetworkWirelessSsidActiveDirectoryServersItem",
    "UpdateNetworkWirelessSsidApTagsAndVlanIdsItem",
    "UpdateNetworkWirelessSsidBonjourForwardingException",
    "UpdateNetworkWirelessSsidBonjourForwardingResponse",
    "UpdateNetworkWirelessSsidBonjourForwardingRulesItem",
    "UpdateNetworkWirelessSsidDeviceTypeGroupPoliciesDeviceTypePoliciesItem",
    "UpdateNetworkWirelessSsidDnsRewrite",
    "UpdateNetworkWirelessSsidDot11r",
    "UpdateNetworkWirelessSsidDot11w",
    "UpdateNetworkWirelessSsidEapOverrideEapolKey",
    "UpdateNetworkWirelessSsidEapOverrideIdentity",
    "UpdateNetworkWirelessSsidEapOverrideResponse",
    "UpdateNetworkWirelessSsidFirewallL3FirewallRulesResponse",
    "UpdateNetworkWirelessSsidFirewallL3FirewallRulesRulesItem",
    "UpdateNetworkWirelessSsidFirewallL7FirewallRulesResponse",
    "UpdateNetworkWirelessSsidFirewallL7FirewallRulesRulesItem",
    "UpdateNetworkWirelessSsidGre",
    "UpdateNetworkWirelessSsidGreConcentrator",
    "UpdateNetworkWirelessSsidHotspot20MccMncsItem",
    "UpdateNetworkWirelessSsidHotspot20NaiRealmsItem",
    "UpdateNetworkWirelessSsidHotspot20Operator",
    "UpdateNetworkWirelessSsidHotspot20Response",
    "UpdateNetworkWirelessSsidHotspot20Venue",
    "UpdateNetworkWirelessSsidIdentityPskResponse",
    "UpdateNetworkWirelessSsidLdap",
    "UpdateNetworkWirelessSsidLdapCredentials",
    "UpdateNetworkWirelessSsidLdapServersItem",
    "UpdateNetworkWirelessSsidLocalAuthFallback",
    "UpdateNetworkWirelessSsidLocalRadius",
    "UpdateNetworkWirelessSsidLocalRadiusCertificateAuthentication",
    "UpdateNetworkWirelessSsidNamedVlans",
    "UpdateNetworkWirelessSsidNamedVlansRadius",
    "UpdateNetworkWirelessSsidNamedVlansTagging",
    "UpdateNetworkWirelessSsidOauth",
    "UpdateNetworkWirelessSsidOpenRoamingResponse",
    "UpdateNetworkWirelessSsidRadiusAccountingServersItem",
    "UpdateNetworkWirelessSsidRadiusRadsec",
    "UpdateNetworkWirelessSsidRadiusRadsecTlsTunnel",
    "UpdateNetworkWirelessSsidRadiusServersItem",
    "UpdateNetworkWirelessSsidResponse",
    "UpdateNetworkWirelessSsidSchedulesRangesInSecondsItem",
    "UpdateNetworkWirelessSsidSchedulesRangesItem",
    "UpdateNetworkWirelessSsidSchedulesResponse",
    "UpdateNetworkWirelessSsidSpeedBurst",
    "UpdateNetworkWirelessSsidSplashSettingsBilling",
    "UpdateNetworkWirelessSsidSplashSettingsGuestSponsorship",
    "UpdateNetworkWirelessSsidSplashSettingsResponse",
    "UpdateNetworkWirelessSsidSplashSettingsSelfRegistration",
    "UpdateNetworkWirelessSsidSplashSettingsSentryEnrollment",
    "UpdateNetworkWirelessSsidSplashSettingsSentryEnrollmentSystemsManagerNetwork",
    "UpdateNetworkWirelessSsidSplashSettingsSplashImage",
    "UpdateNetworkWirelessSsidSplashSettingsSplashLogo",
    "UpdateNetworkWirelessSsidSplashSettingsSplashLogoImage",
    "UpdateNetworkWirelessSsidSplashSettingsSplashPrepaidFront",
    "UpdateNetworkWirelessSsidTrafficShapingRulesResponse",
    "UpdateNetworkWirelessSsidTrafficShapingRulesRulesItem",
    "UpdateNetworkWirelessSsidVpnConcentrator",
    "UpdateNetworkWirelessSsidVpnFailover",
    "UpdateNetworkWirelessSsidVpnSplitTunnel",
    "UpdateNetworkWirelessSsidVpnSplitTunnelRulesItem",
    "UpdateNetworkWirelessZigbeeDefaults",
    "UpdateNetworkWirelessZigbeeIotController",
    "UpdateNetworkWirelessZigbeeLockManagement",
    "UpdateNetworkWirelessZigbeeResponse",
    "UpdateNetworkWirelessZigbeeResponseDefaults",
    "UpdateNetworkWirelessZigbeeResponseIotController",
    "UpdateNetworkWirelessZigbeeResponseLockManagement",
    "UpdateOrganizationActionBatchResponse",
    "UpdateOrganizationAdaptivePolicyAclResponse",
    "UpdateOrganizationAdaptivePolicyAclRulesItem",
    "UpdateOrganizationAdaptivePolicyGroupPolicyObjectsItem",
    "UpdateOrganizationAdaptivePolicyGroupResponse",
    "UpdateOrganizationAdaptivePolicyPolicyAclsItem",
    "UpdateOrganizationAdaptivePolicyPolicyDestinationGroup",
    "UpdateOrganizationAdaptivePolicyPolicyResponse",
    "UpdateOrganizationAdaptivePolicyPolicySourceGroup",
    "UpdateOrganizationAdaptivePolicySettingsResponse",
    "UpdateOrganizationAdminNetworksItem",
    "UpdateOrganizationAdminResponse",
    "UpdateOrganizationAdminTagsItem",
    "UpdateOrganizationAlertsProfileAlertCondition",
    "UpdateOrganizationAlertsProfileRecipients",
    "UpdateOrganizationAlertsProfileResponse",
    "UpdateOrganizationApi",
    "UpdateOrganizationApplianceDnsLocalProfileResponse",
    "UpdateOrganizationApplianceDnsLocalRecordProfile",
    "UpdateOrganizationApplianceDnsLocalRecordResponse",
    "UpdateOrganizationApplianceDnsSplitProfileNameservers",
    "UpdateOrganizationApplianceDnsSplitProfileResponse",
    "UpdateOrganizationApplianceSecurityIntrusionAllowedRulesItem",
    "UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasItemsItem",
    "UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponse",
    "UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseItemsItem",
    "UpdateOrganizationApplianceVpnSiteToSiteIpsecPeersSlasResponseMeta",
    "UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItem",
    "UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItemEbgpNeighbor",
    "UpdateOrganizationApplianceVpnThirdPartyVPNPeersPeersItemNetwork",
    "UpdateOrganizationApplianceVpnThirdPartyVPNPeersResponse",
    "UpdateOrganizationApplianceVpnVpnFirewallRulesResponse",
    "UpdateOrganizationApplianceVpnVpnFirewallRulesRulesItem",
    "UpdateOrganizationBrandingPoliciesPrioritiesResponse",
    "UpdateOrganizationBrandingPolicyAdminSettings",
    "UpdateOrganizationBrandingPolicyCustomLogo",
    "UpdateOrganizationBrandingPolicyHelpSettings",
    "UpdateOrganizationBrandingPolicyResponse",
    "UpdateOrganizationCameraRoleAppliedOnDevicesItem",
    "UpdateOrganizationCameraRoleAppliedOnNetworksItem",
    "UpdateOrganizationCameraRoleAppliedOrgWideItem",
    "UpdateOrganizationCameraRoleResponse",
    "UpdateOrganizationCellularGatewayEsimsInventoryResponse",
    "UpdateOrganizationCellularGatewayEsimsServiceProvidersAccountResponse",
    "UpdateOrganizationCellularGatewayEsimsSwapResponse",
    "UpdateOrganizationConfigTemplateResponse",
    "UpdateOrganizationConfigTemplateSwitchProfilePortDot3az",
    "UpdateOrganizationConfigTemplateSwitchProfilePortHighSpeed",
    "UpdateOrganizationConfigTemplateSwitchProfilePortProfile",
    "UpdateOrganizationConfigTemplateSwitchProfilePortResponse",
    "UpdateOrganizationDevicesPacketCaptureScheduleDevicesItem",
    "UpdateOrganizationDevicesPacketCaptureScheduleResponse",
    "UpdateOrganizationDevicesPacketCaptureScheduleSchedule",
    "UpdateOrganizationEarlyAccessFeaturesOptInResponse",
    "UpdateOrganizationInsightMonitoredMediaServerResponse",
    "UpdateOrganizationLicenseResponse",
    "UpdateOrganizationLoginSecurityApiAuthentication",
    "UpdateOrganizationLoginSecurityResponse",
    "UpdateOrganizationManagement",
    "UpdateOrganizationPolicyObjectResponse",
    "UpdateOrganizationPolicyObjectsGroupResponse",
    "UpdateOrganizationResponse",
    "UpdateOrganizationSamlIdpResponse",
    "UpdateOrganizationSamlIdpResponseItem",
    "UpdateOrganizationSamlResponse",
    "UpdateOrganizationSamlRoleNetworksItem",
    "UpdateOrganizationSamlRoleResponse",
    "UpdateOrganizationSamlRoleTagsItem",
    "UpdateOrganizationSamlSpInitiated",
    "UpdateOrganizationSmAdminsRoleResponse",
    "UpdateOrganizationSmSentryPoliciesAssignmentsItemsItem",
    "UpdateOrganizationSmSentryPoliciesAssignmentsItemsItemPoliciesItem",
    "UpdateOrganizationSmSentryPoliciesAssignmentsResponse",
    "UpdateOrganizationSmSentryPoliciesAssignmentsResponseItemsItem",
    "UpdateOrganizationSnmpResponse",
    "UpdateOrganizationWirelessDevicesRadsecCertificatesAuthoritiesResponse",
    "UpdateOrganizationWirelessLocationScanningReceiverRadio",
    "UpdateOrganizationWirelessLocationScanningReceiverResponse",
    "UpdateOrganizationWirelessMqttSettingsBle",
    "UpdateOrganizationWirelessMqttSettingsMqtt",
    "UpdateOrganizationWirelessMqttSettingsNetwork",
    "UpdateOrganizationWirelessMqttSettingsResponse",
    "UpdateOrganizationWirelessMqttSettingsWifi",
    "UpdateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryClient",
    "UpdateOrganizationWirelessSsidsFirewallIsolationAllowlistEntryResponse",
    "UpdateOrganizationWirelessZigbeeDeviceResponse",
    "UpdateOrganizationWirelessZigbeeDoorLockResponse",
    "ValidateAdministeredLicensingSubscriptionSubscriptionsClaimKeyResponse",
    "VmxNetworkDevicesClaimResponse",
    "WipeNetworkSmDevicesResponse",
    "WirelessAc",
    "WirelessAddressesNameservers",
    "WirelessAggregation",
    "WirelessAllowLists",
    "WirelessAllowLists2",
    "WirelessApBandSettingsBands",
    "WirelessApiValidator",
    "WirelessAuthenticationTypes",
    "WirelessAutomatic",
    "WirelessBackgroundTraffic",
    "WirelessBasicServiceSetsItem",
    "WirelessBillingFreeAccess",
    "WirelessBle",
    "WirelessBssidsItem",
    "WirelessBusyHourMinimizeChanges",
    "WirelessBusyHourSchedule",
    "WirelessByApTagsItem",
    "WirelessByBandItem",
    "WirelessByStatus",
    "WirelessByStatus2",
    "WirelessClient",
    "WirelessClient2",
    "WirelessClientRootCaCertificate",
    "WirelessControllerAddressesItem",
    "WirelessControllerAddressesItem2",
    "WirelessControllerAverage",
    "WirelessControllerByCoreItem",
    "WirelessControllerByInterfaceItem",
    "WirelessControllerByStatus",
    "WirelessControllerByStatus2",
    "WirelessControllerChangesItem",
    "WirelessControllerChangesItem2",
    "WirelessControllerChannelGroup",
    "WirelessControllerConnections",
    "WirelessControllerController",
    "WirelessControllerCounts",
    "WirelessControllerCounts2",
    "WirelessControllerCounts3",
    "WirelessControllerFailed",
    "WirelessControllerFailover",
    "WirelessControllerFirmware",
    "WirelessControllerInterfacesItem",
    "WirelessControllerInterfacesItem2",
    "WirelessControllerInterfacesItem3",
    "WirelessControllerInterfacesItem4",
    "WirelessControllerIntervalsItem",
    "WirelessControllerIntervalsItem2",
    "WirelessControllerLast",
    "WirelessControllerManagement",
    "WirelessControllerModule",
    "WirelessControllerNetwork",
    "WirelessControllerNetwork2",
    "WirelessControllerOverall",
    "WirelessControllerRate",
    "WirelessControllerReadingsItem",
    "WirelessControllerReadingsItem2",
    "WirelessControllerReadingsItem3",
    "WirelessControllerRedundancy",
    "WirelessControllerUsage",
    "WirelessControllerVersion",
    "WirelessControllerVrf",
    "WirelessCounts",
    "WirelessCounts2",
    "WirelessDetailsItem",
    "WirelessDetectedByItem",
    "WirelessDevice",
    "WirelessDoorLocks",
    "WirelessDoorLocksGateway",
    "WirelessDoorLocksNetwork",
    "WirelessDownstream",
    "WirelessEventsItem",
    "WirelessFlush",
    "WirelessGateway",
    "WirelessGuestVlan",
    "WirelessHysteresis",
    "WirelessLatencyBinsByCategory",
    "WirelessLatestMeshPerformance",
    "WirelessLinkNegotiation",
    "WirelessMqtt",
    "WirelessNaiRealmsMethodsItem",
    "WirelessNamedVlansPoolDhcpMonitoring",
    "WirelessNetwork",
    "WirelessNetwork2",
    "WirelessOpenRoaming",
    "WirelessPerSsidSettings0",
    "WirelessPlansBandwidthLimits",
    "WirelessPoe",
    "WirelessPortsItem",
    "WirelessPortsItem2",
    "WirelessPower",
    "WirelessPublishing",
    "WirelessRadio",
    "WirelessRadio2",
    "WirelessRadiusServersItem",
    "WirelessRfProfile",
    "WirelessRulesDefinitionsItem",
    "WirelessRulesPerClientBandwidthLimits",
    "WirelessSentryEnrollmentSystemsManagerNetwork",
    "WirelessSeriesItem",
    "WirelessSsid",
    "WirelessSsid2",
    "WirelessSsidItem",
    "WirelessTagsItem",
    "WirelessUsbPortsItem",
    "WirelessWifi",
    "WirelessWifi2",
]
